<?php

class Youzer_Posts_Reactions {

    private $textdomain = "youzer-activity-reactions";
    private $required_plugins = array( 'buddypress' => 'bp-loader', 'youzer' );

    function __construct() {

        if ( ! $this->have_required_plugins() ) {
            deactivate_plugins( plugin_basename( __FILE__ ) );
        }

        // Load Functions.
        $this->init_youzer_posts_reactions();

        // Load Global Variables.
        $this->globals();

        // Load Plugin Text Domain.
        load_plugin_textdomain( $this->textdomain, false, dirname( plugin_basename(__FILE__) ) . '/languages');

        // Add Plugin Links.
        add_filter(
            'plugin_action_links_' . YZPR_BASENAME,
            array( $this, 'plugin_action_links' )
        );

        // Add Plugin Links in Multisite..
        add_filter(
            'network_admin_plugin_action_links_' . YZPR_BASENAME,
            array( $this, 'plugin_action_links' )
        );
    }

    /**
     * Default Emojis List.
     */
    function get_default_emojis_list() {

        // Get Emoji Path
        $emoji_path = YZPR_ASSETS . 'emoji/';

        $emojis = array(
            'yz_emoji_1' => array(
                'visibility' => 'true',
                'image' => $emoji_path . 'like.png',
                'title' => __( 'Like', 'youzer-posts-reactions' ),
                'description' => __( 'Liked Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_2' => array(
                'visibility' => 'true',
                'image' => $emoji_path . 'love.png',
                'title' => __( 'Love', 'youzer-posts-reactions' ),
                'description' => __( 'Loved Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_3' => array(
                'visibility' => 'true',
                'image' => $emoji_path . 'wow.png',
                'title' => __( 'Wow', 'youzer-posts-reactions' ),
                'description' => __( 'Amazing Posts', 'youzer-posts-reactions' )
            ),      
            'yz_emoji_4' => array(
                'visibility' => 'false',
                'image' => $emoji_path . 'shy.png',
                'title' => __( 'Shy', 'youzer-posts-reactions' ),
                'description' => __( 'Shy Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_5' => array(
                'visibility' => 'true',
                'image' => $emoji_path . 'sad.png',
                'title' => __( 'Sad', 'youzer-posts-reactions' ),
                'description' => __( 'Sad Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_6' => array(
                'visibility' => 'true',
                'image' => $emoji_path . 'funny.png',
                'title' => __( 'Funny', 'youzer-posts-reactions' ),
                'description' => __( 'funny Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_7' => array(
                'visibility' => 'false',
                'image' => $emoji_path . 'wink.png',
                'title' => __( 'Wink', 'youzer-posts-reactions' ),
                'description' => __( 'Winked Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_8' => array(
                'visibility' => 'true',
                'image' => $emoji_path . 'angry.png',
                'title' => __( 'Angry', 'youzer-posts-reactions' ),
                'description' => __( 'Angry Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_9' => array(
                'visibility' => 'false',
                'image' => $emoji_path . 'dead.png',
                'title' => __( 'Dead', 'youzer-posts-reactions' ),
                'description' => __( 'Dead Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_10' => array(
                'visibility' => 'false',
                'image' => $emoji_path . 'sleepy.png',
                'title' => __( 'Sleepy', 'youzer-posts-reactions' ),
                'description' => __( 'Sleepy Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_11' => array(
                'visibility' => 'false',
                'image' => $emoji_path . 'cute.png',
                'title' => __( 'Cute', 'youzer-posts-reactions' ),
                'description' => __( 'Cute Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_12' => array(
                'visibility' => 'false',
                'image' => $emoji_path . 'bored.png',
                'title' => __( 'Bored', 'youzer-posts-reactions' ),
                'description' => __( 'Boring Posts', 'youzer-posts-reactions' )
            ),
            'yz_emoji_13' => array(
                'visibility' => 'false',
                'image' => $emoji_path . 'shock.png',
                'title' => __( 'Shock', 'youzer-posts-reactions' ),
                'description' => __( 'Shocking Posts', 'youzer-posts-reactions' )
            )
        );

        return $emojis;

    }
  
    /**
     * Init Youzer Posts Reactions.
     */
    function init_youzer_posts_reactions() {

        // Include Functions.
        require YZPR_PATH . 'functions/yzpr-general-functions.php';

        // Include Classes.
        require YZPR_PATH . 'core/class-yzpr-query.php';
        require YZPR_PATH . 'core/class-yzpr-ajax.php';

        // Init Classes
        $this->query = new YZPR_Query();
        $this->ajax  = new YZPR_Ajax();
        
        if ( is_admin() ) {
            require YZPR_PATH . 'functions/yzpr-reactions-admin.php';
        }

    }

    /**
     * # Init Post Reactions Global Variables.
     */
    private function globals() {

        global $wpdb, $yzpr_table;

        // Get Logy Users Table Name.
        $yzpr_table = $wpdb->prefix . 'yz_reactions';

    }

    /**
     * Check For Required Plugins.
     */
    function have_required_plugins() {
        
        if ( empty( $this->required_plugins ) ) {
            return true;
        }

        // Get Active Plugins List.
        $active_plugins = (array) get_option( 'active_plugins', array() );

        // Is Multisite ??
        if ( is_multisite() ) {
            // Get Site Wide Plugins.
            $sitewide_plugins = get_site_option( 'active_sitewide_plugins', array() );
            // Merge Plugins.
            $active_plugins = array_merge( $active_plugins, $sitewide_plugins );
        }

        foreach ( $this->required_plugins as $key => $required ) {

            // Get Plugin Path.
            $required = ! is_numeric( $key ) ? "{$key}/{$required}.php" : "{$required}/{$required}.php";

            if (
                ! in_array( $required, $active_plugins )
                &&
                ! array_key_exists( $required, $active_plugins )
            )
                return false;
        }
        return true;
    }

    /**
     * Action Links
     */
    function plugin_action_links( $links ) {
        // Get Youzer Plugin Pages. 
        $panel_url = esc_url( add_query_arg( array( 'page' => 'yz-extensions-settings&tab=reaction-settings' ), admin_url( 'admin.php' ) ) );
        $plugin_url = 'https://www.kainelabs.com/downloads/buddypress-activity-reactions/';
        $documentation_url = 'https://kainelabs.ticksy.com/articles/100013208';
        // Add a few links to the existing links array.
        return array_merge( $links, array(
            'settings' => '<a href="' . $panel_url . '">' . esc_html__( 'Settings', 'youzer' ) . '</a>',
            'documentation' => '<a href="' . $documentation_url . '">' . esc_html__( 'Documentation',    'youzer' ) . '</a>',
            'about'    => '<a href="' . $plugin_url . '">' . esc_html__( 'About',    'youzer' ) . '</a>'
        ) );
    }

}
