<?php

class YZPR_Ajax {

	protected $yzpr;

    public function __construct() {

		global $YZPR;

    	$this->yzpr = &$YZPR;
	
	 	// Save Post Reaction.
		add_action( 'wp_ajax_yzpr_save_post_reaction',  array( &$this, 'save_reaction' ) );

	 	// Delete Post Reaction. 
		add_action( 'wp_ajax_yzpr_delete_post_reaction',  array( &$this, 'delete_reaction' ) );

		// Add Post Favorite.
		add_action( 'yzpr_after_save_post_reaction',  array( &$this, 'add_favorite' ), 10, 3 );

		// Remove Post Favorite.
		add_action( 'yzpr_after_delete_post_reaction',  array( &$this, 'remove_favorite' ), 10, 2 );

    }

	/**
	 * Save Reaction.
	 */
	function save_reaction( $user_id ) {

		if ( ! is_user_logged_in() ) {
			$data['error'] = $this->msg( 'invalid_permission' );
			die( json_encode( $data ) );
		}

		// Hook.
		do_action( 'yzpr_before_save_post_reaction' );

		check_ajax_referer( 'yzpr-post-reaction-nonce', 'security' );

		// Get Action
		$reaction_action = isset( $_POST['reaction_action'] ) ? $_POST['reaction_action'] : null;

		if ( 'save_reaction' == $reaction_action ) {

			// Save The New Reaction.
			$reaction_id = $this->yzpr->query->save_reaction( $_POST );

			// Action
			do_action( 'yzpr_after_save_post_reaction', $reaction_id, $_POST['activity_id'], $_POST['emoji_id'] );

		}

		$data['error'] = $this->msg( 'error' );

		echo json_encode( $data );

		die();

	}

	/**
	 * Add Activity Favorite
	 */
	function add_favorite( $reaction_id, $activity_id, $emoji_id ) {

		// Get User ID.
		$user_id = bp_loggedin_user_id();

		// Get Favorite reaction id
		$favorite_reaction_id =  yz_options( 'yz_favorite_reaction_id' );

		if ( $favorite_reaction_id == $emoji_id ) {
			bp_activity_add_user_favorite( $activity_id, $user_id );
		}

	}

	/**
	 * Remove Activity Favorite
	 */
	function remove_favorite( $reaction, $activity_id ) {

		// Get User ID.
		$user_id = bp_loggedin_user_id();

		// Get Favorite reaction id
		$favorite_reaction_id = yz_options( 'yz_favorite_reaction_id' );

		if ( $favorite_reaction_id == $reaction['emoji_id'] ) {
			bp_activity_remove_user_favorite( $activity_id, $user_id );
		}

	}

	/**
	 * Delete Reaction
	 */
	function delete_reaction() {

		if ( ! is_user_logged_in() ) {
			$data['error'] = $this->msg( 'invalid_permission' );
			die( json_encode( $data ) );
		}

		// Hook.
		do_action( 'yzpr_before_delete_post_reaction' );

		check_ajax_referer( 'yzpr-post-reaction-nonce', 'security' );

    	$user_id = bp_loggedin_user_id();
    	
		// Check if user Already Reacted ( Returns Reaction ID ).
		$reaction = $this->yzpr->query->already_reacted( $user_id, $_POST['activity_id'] );
		
		// Delete Reaction.
		$delete_reaction = $this->yzpr->query->delete_reaction( $reaction['id'] );

		// Action After Deleting Reaction.
		if ( $delete_reaction ) {
			// Action
			do_action( 'yzpr_after_delete_post_reaction', $reaction, $_POST['activity_id'] );
		}

		die( json_encode( '1' ) );

	}

    /**
     * Get Error Message.
     */
    public function msg( $code ) {

        // Messages
        switch ( $code ) {

            case 'invalid_permission':
                return __( 'The action you have requested is not allowed.', 'youzer' );

            case 'invalid_reaction':
                return __( 'The reaction you have submitted is not availble.', 'youzer' );

            case 'invalid_action':
                return __( 'The action you have requested is not exit.', 'youzer' );

        }

        return __( 'An unknown error occurred while saving your reaction. Please try again later.', 'youzer' );
    }
}