<?php

class YZPR_Query {

    /**
     * Save Reactions.
     */
    public function save_reaction( $data = array() ) {

    	global $wpdb, $yzpr_table;

    	$user_id = bp_loggedin_user_id();

    	if ( ! $user_id ) {
    		return false;
    	}

    	// Get Activity ID.
    	$activity_id = $data['activity_id'];

		// Get Current Time.
		$current_time = current_time( 'mysql' );

		// Get Reaction Data
		$reaction_data = array( 
			'emoji_id' 	  	=> $data['emoji_id'],
			'activity_id' 	=> $activity_id, 
			'time' 			=> $current_time,
			'user_id' 		=> $user_id
		);

		// Check if user Already Reacted ( Returns Reaction ID ).
		$is_already_reacted = $this->already_reacted( $user_id, $activity_id );

		// Insert The New Reaction.
		if ( $is_already_reacted ) {
			$result = $wpdb->update( $yzpr_table, $reaction_data, array( 'ID' => $is_already_reacted['id'] ) );
			// Action
			do_action( 'yzpr_after_updating_post_reaction', $is_already_reacted['id'], $reaction_data );
		} else {
			$result = $wpdb->insert( $yzpr_table, $reaction_data );
			// Action
			do_action( 'yzpr_after_adding_post_reaction', $wpdb->insert_id, $reaction_data );
		}

		if ( $result ) {
			// Return Reaction ID.
			return $wpdb->insert_id;
		}

		return false;

    }

    /**
     * Check if Value Already Exist In Database.
     */
    public function already_reacted( $user_id, $activity_id ) {

		global $wpdb, $yzpr_table;

    	// Prepare Sql
		$sql = $wpdb->prepare(
			"SELECT * FROM $yzpr_table WHERE user_id = %d AND activity_id = %d",
			$user_id, $activity_id
		);

		// Get Result
		$result = $wpdb->get_results( $sql , ARRAY_A );
		$result = ( isset( $result[0]['id'] ) && ! empty( $result[0]['id'] ) ) ? $result[0] : false;

		
		return $result;

    }

    /**
     * Get User Reaction
     */
    public function get_user_reaction( $user_id, $activity_id ) {

		global $wpdb, $yzpr_table;

    	// Prepare Sql
		$sql = $wpdb->prepare(
			"SELECT emoji_id FROM $yzpr_table WHERE user_id = %d AND activity_id = %d",
			$user_id, $activity_id
		);

		// Get Result
		$result = $wpdb->get_var( $sql );

		return $result;

    }

    /**
     * Delete Reaction.
     */
    function delete_reaction( $reaction_id ) {

		global $wpdb, $yzpr_table;

		if ( ! $reaction_id ) {
			return false;
		}

		// Delete Reaction.
		$delete_reaction = $wpdb->delete( $yzpr_table, array( 'id' => $reaction_id ), array( '%d' ) );

		// Get Result.
		if ( $delete_reaction ) {
			return true;
		}

		return false;

    }

    /**
     * Get Post Emoji Count.
     */
    public function get_post_emoji_reactors( $activity_id, $emoji_id ) {

    	global $wpdb, $yzpr_table;
		
		// Get SQL Query.
		$sql = $wpdb->prepare(
			"SELECT user_id FROM $yzpr_table WHERE activity_id = %d AND emoji_id = %s",
			$activity_id, $emoji_id
		);

		// Get Result
		$reactors = $wpdb->get_results( $sql , ARRAY_A );

		// Get Only User Ids.
		$reactors = wp_list_pluck( $reactors, 'user_id' );

		return $reactors;

    }

    /**
     * Get Post Emoji Count.
     */
    public function get_activity_reactions( $activity_id ) {

		// Get Transient Option.
		$transient_id = 'yz_get_activity_reactions_' . $activity_id;

		$reactions = get_transient( $transient_id );

		if ( false === $reactions ) {

	    	global $wpdb, $yzpr_table;
			
			// Get SQL Query.
			$sql = $wpdb->prepare(
				"SELECT emoji_id FROM $yzpr_table WHERE activity_id = %d ", 
				$activity_id
			);

			// Get Result
			$reactions = $wpdb->get_results( $sql , ARRAY_A );
			
			// Get Result
			$reactions = wp_list_pluck( $reactions , 'emoji_id' );
				
			// Get Result with Count.
			$reactions = array_count_values( $reactions );

    		set_transient( $transient_id, $reactions, 12 * HOUR_IN_SECONDS );
	
		}

		// Return Count.
		return $reactions;

    }
    
    /**
     * Get Post Emoji Count.
     */
    public function get_post_emoji_count( $activity_id, $emoji_id ) {

    	global $wpdb, $yzpr_table;
		
		// Get SQL Query.
		$sql = $wpdb->prepare(
			"SELECT COUNT(*) FROM $yzpr_table WHERE activity_id = %d AND emoji_id = %d",
			$activity_id, $emoji_id
		);

    	// Get Count.
		$count = $wpdb->get_var( $sql );
		
		// Return Count.
		return $count;

    }

    /**
     * Get Post Reactions Totlak.
     */
    public function get_post_reactions_count( $activity_id ) {

    	global $wpdb, $yzpr_table;
		
		// Get SQL Query.
		$sql = $wpdb->prepare(
			"SELECT COUNT(*) FROM $yzpr_table WHERE activity_id = %d ", $activity_id
		);

    	// Get Count.
		$count = $wpdb->get_var( $sql );
		
		// Return Count.
		return $count;

    }

    /**
     * Check if Value Already Exist In Database.
     */
    public function delete_emoji_reactions( $emoji_id ) {

		global $wpdb, $yzpr_table;

    	// Prepare Sql
    	$wpdb->delete( $yzpr_table, array( 'emoji_id' => $emoji_id ), array( '%s' ) );

    	do_action( 'yz_after_emoji_reactions_delete' , $emoji_id );
    }

}