<?php

/* Activity Administration screen does not use bp_ajax_querystring
Moreover This action type is reordering instead of filtering so you will only
use it on front end */
function yzpr_set_new_activity_action() {

	if ( ! is_admin() ) {
	    bp_activity_set_action( 'bp_plugin', 'activity_mostfavs', __( 'Most Favorited' ) );
	}
}
add_action( 'bp_init', 'yzpr_set_new_activity_action' );

class BP_Loop_Filters {
 
    /**
     * Constructor
     */
    public function __construct() {
        $this->setup_actions();
        // simply add the following line to your constructor
        $this->setup_filters();
    }

    /**
	 * Filters
	 */
	private function setup_filters() {
	    add_filter( 'bp_ajax_querystring', array( $this, 'activity_querystring_filter' ), 12, 2 );
	}
	/**
 * Builds an Activity Meta Query to retrieve the favorited activities
 *
 * <a class="bp-suggestions-mention" href="https://buddypress.org/members/param/" rel="nofollow">@param</a>  string $query_string the front end arguments for the Activity loop
 * <a class="bp-suggestions-mention" href="https://buddypress.org/members/param/" rel="nofollow">@param</a>  string $object       the Component object
 * @uses   wp_parse_args()
 * @uses   bp_displayed_user_id()
 * <a class="bp-suggestions-mention" href="https://buddypress.org/members/return/" rel="nofollow">@return</a> array()|string $query_string new arguments or same if not needed
 */
public function activity_querystring_filter( $query_string = '', $object = '' ) {

    if ( $object != 'activity' ) {
        return $query_string;
    }
 
    // You can easily manipulate the query string
    // by transforming it into an array and merging
    // arguments with these default ones
    $args = wp_parse_args( $query_string, array(
        'action'  => false,
        'type'    => false,
        'user_id' => false,
        'page'    => 1
    ) );
 
    /* most favorited */
    if ( $args['action'] == 'activity_mostfavs' ) {
    	
        unset( $args['action'], $args['type'] );
 
        // on user's profile, shows the most favorited activities for displayed user
        if ( bp_is_user() ){
            $args['user_id'] = bp_displayed_user_id();
        }
 
        // An activity meta query <img draggable="false" class="emoji" alt="🙂" src="https://s.w.org/images/core/emoji/2.4/svg/1f642.svg">
        $args['meta_query'] = array(
            array(
                /* this is the meta_key you want to filter on */
                'key'     => 'favorite_count',
                /* You need to get all values that are >= to 1 */
                'value'   => 1,
                'type'    => 'numeric',
                'compare' => '>='
            ),
        );
 
        $query_string = empty( $args ) ? $query_string : $args;
    }
 
    return apply_filters( 'bp_plugin_activity_querystring_filter', $query_string, $object );
}
 /**
 * Filters
 */
private function setup_filters() {
    add_filter( 'bp_ajax_querystring',              array( $this, 'activity_querystring_filter' ), 12, 2 );
    add_filter( 'bp_activity_get_user_join_filter', array( $this, 'order_by_most_favorited' ),     10, 6 );
}
}