<?php

/**
 * Emojis List.
 */
function yzpr_get_emojis_list() {

	// Get Emojis
	$reaction_emojis = yz_options( 'yz_reaction_emojis' );
	
	if ( ! empty( $reaction_emojis ) ) {

		foreach ( $reaction_emojis as $key => $emoji ) {

			// Hide Hidden Emojis.
			if ( $emoji['visibility'] != 'true' ) {
				unset( $reaction_emojis[ $key ] );			
			}

		}	
	}

	return apply_filters( 'yzpr_get_emojis_list', $reaction_emojis );

}

/**
 * Activity Reactions Script.
 */
function yzpr_scripts() {

	// Register Posts Reactions Js & Css Scripts.
    wp_enqueue_style( 'yz-posts-reactions', YZPR_ASSETS . 'css/yz-posts-reactions.min.css' );
    wp_enqueue_script( 'yz-posts-reactions', YZPR_ASSETS . 'js/yz-posts-reactions.min.js', array( 'jquery' ), false, true );

}

add_action( 'wp_enqueue_scripts', 'yzpr_scripts' );

/**
 * Call Activity Scritps.
 */
function yzpr_activity_scripts( ) {
	
	if ( bp_is_activity_component() || bp_is_group_activity() ) {
		yzpr_scripts();
	}

}

add_action( 'wp_enqueue_scripts', 'yzpr_activity_scripts' );
add_action( 'yz_before_activity_shortcode', 'yzpr_scripts' );

/**
 * Posts Reaction Form
 */
function yzpr_form() {

	// Get Emoji Path
	$emoji_path = YZPR_ASSETS . 'emoji/';

	// Get Emojis
	$emojis = yzpr_get_emojis_list();

	if ( empty( $emojis ) ) {
		return;
	}

	?>

	<div class="yzpr-bar" data-yz-default-reaction="<?php echo yz_options( 'yz_like_reaction_id' ); ?>">
		<?php foreach ( $emojis as $emoji_id => $emoji ) : ?>
			<div class="yzpr-bar-item" data-yztooltip="<?php echo $emoji['title']; ?>">
				<img src="<?php echo $emoji['image']; ?>" data-reaction="<?php echo $emoji_id; ?>" alt=""/>
			</div>
		<?php endforeach; ?>
	</div>

	<?php

}

add_action( 'bp_after_bookmarks_loop', 'yzpr_form' );
add_action( 'bp_after_activity_loop', 'yzpr_form' );
add_action( 'bp_after_single_activity_post', 'yzpr_form' );

/**
 * Edit Posts Like Button.
 */
function yzpr_edit_posts_like_button( $button, $link, $activity_id ) {

	// Button Default Title.
	$default_title = __( 'Like', 'youzer' );

	// Get User Reaction.
	$reaction_data = yzpr_get_post_reaction_data( $activity_id );

	// Get Reaction Title.
	$title = ! empty( $reaction_data ) ? $reaction_data['title'] : $default_title;
	
	// Get Reaction Class.
	$class = ! empty( $reaction_data ) ? 'yzpr-yes-reaction' : 'yzpr-no-reaction';

	// Get Like Button.
	$button = '<a class="yzpr-reacto-post button" data-default-title="' . $default_title . '"><div class="yzpr-post-reaction ' . $class . '">';

	if (  ! empty( $reaction_data ) ) {	
		$button .= '<img src="' . $reaction_data['image'] . '" alt="" >';
	} else {
		$button .= '<i class="far fa-heart"></i>';		
	}

	$button .= '</div><span class="yzpr-react-title">' . $title . '</span></a>';

	return $button;
}

/**
 * Add Comment Like Button.
 */
function yzpr_add_comment_like_button(){
	echo yzpr_edit_posts_like_button( null, null, bp_get_activity_comment_id() );
}


/**
 * Init Buttons.
 */
function yzpr_init_activity_reaction_buttons() {

	if ( 'on' == yz_options( 'yz_enable_posts_reaction' ) ) {
		add_filter( 'yz_filter_post_like_button', 'yzpr_edit_posts_like_button', 10, 3 );
		add_filter( 'yz_filter_post_unlike_button', 'yzpr_edit_posts_like_button', 10, 3 );
	}
	
	if ( is_user_logged_in() && 'on' == yz_options( 'yz_enable_comments_reaction' ) ) {
		add_action( 'bp_before_activity_comment_options', 'yzpr_add_comment_like_button', 10, 3 );
	}

}

add_action( 'init', 'yzpr_init_activity_reaction_buttons' );

/**
 * Get Post User Reaction Data
 */
function yzpr_get_post_reaction_data( $activity_id ) {

	global $YZPR;

	// Get User ID.
	$user_id = bp_loggedin_user_id();

	// Get Post Reaction.
	$emoji_id = $YZPR->query->get_user_reaction( $user_id, $activity_id );

	// Get Emoji List.
	$emoticons = yzpr_get_emojis_list();

	// Check If User Emji Is Available.
	if ( isset( $emoticons[ $emoji_id ] ) ) {
		return $emoticons[ $emoji_id ];
	}

	return false;

}

/**
 * Add Reaction Nonces.
 */
function yzpr_add_reactions_nonce() {
	// Create Nonce.
	wp_nonce_field( 'yzpr-post-reaction-nonce', 'yzpr-post-reaction-nonce' );
}

add_action( 'wp_footer', 'yzpr_add_reactions_nonce' );

/**
 * Get Post Reactions List.
 */ 
function yzpr_get_post_reactions_list( $activity_id ) {

	global $YZPR;
	
	// Init Emoji List.
	$output = null;

	// Get Available Emoticons.
	$emoticons = yzpr_get_emojis_list();
		
	// Get Reactions
	$reactions = $YZPR->query->get_activity_reactions( $activity_id );

	if ( empty( $reactions ) ) {
		return;
	}

	foreach ( $reactions as $emoji_id => $count ) {

		if ( ! isset( $emoticons[ $emoji_id ] ) ) {
			$YZPR->query->delete_emoji_reactions( $emoji_id );
			continue;
		}

    	// Get User Image Code.
        $output .= "<a data-yztooltip='" . $count . "'><img src='" . $emoticons[ $emoji_id ]['image']."' data-emoji-id='" . $emoji_id. "' alt=''/></a>";

	}

	// Get Total Reactions.
	$total_reations = $YZPR->query->get_post_reactions_count( $activity_id );

	if ( $total_reations > 0 ) {
		// Get Reactions Total Visibility.
		$display_ractions_count = yz_options( 'yzpr_display_reactions_count' );

		if ( 'on' == $display_ractions_count ) {
			// Print Number.
			$output .= '<a class="yzpr-reactions-count">' . $total_reations . '</a>';
		}
	}


    if ( $output ) : ?>
		<div class="yz-post-reactors-list">
        	<?php echo $output; ?>
        </div>
    <?php  endif;

}

add_action( 'bp_activity_entry_meta_non_logged_in', 'yzpr_get_post_reactions_list' );

/**
 * Get Comment List
 */
function yzpr_get_comment_reactions_list() {

	// Get Comment ID.
	$comment_id = bp_get_activity_comment_id();

	// Get List.
	yzpr_get_post_reactions_list( $comment_id );
	
}

add_action( 'bp_activity_comment_options', 'yzpr_get_comment_reactions_list' );

/**
 * Get who Reacted to a post Modal.
 */
function yzpr_get_who_reacted_to_post_modal() {

	// Get Modal Args
	$args = array( 
		'post_id'  => $_POST['post_id'],
		'emoji_id' => $_POST['emoji_id'],
		'function' => 'yzpr_get_posts_reactions_list',
		'title'    => __( 'People who reacted to this', 'youzer' )
	);

	// Get Modal Content
	yzpr_reactors_modal( $args );

	die();
}

add_action( 'wp_ajax_yzpr_get_post_reactors', 'yzpr_get_who_reacted_to_post_modal' );
add_action( 'wp_ajax_nopriv_yzpr_get_post_reactors', 'yzpr_get_who_reacted_to_post_modal' );

/**
 * Get Post Reactors List.
 */
function yzpr_get_posts_reactions_list( $post_id, $emoji_id ) {

	global $YZPR;

	// Get Reactors List.
	$users = (array) $YZPR->query->get_post_emoji_reactors( $post_id, $emoji_id );

	echo '<div class="yz-users-who-list yz-modal-active-list" data-emoji-id="' . $emoji_id . '">';

	foreach ( $users as $user_id ) {

		// Get Username.
		$username = bp_core_get_username( $user_id );

		// Get User Display Name.
		$user_link = bp_core_get_user_domain( $user_id );

		// Get User Avatar.
    	$avatar = bp_core_fetch_avatar( array( 'type'=> 'thumb', 'item_id'=> $user_id ) );
        
		?>

		<div class="yz-list-item">
			<a href="<?php echo $user_link; ?>" class="yz-item-avatar"><?php echo $avatar; ?></a>
			<div class="yz-item-data">
				<div class="yz-item-name"><?php echo bp_core_get_userlink( $user_id ); ?></div>
				<div class="yz-item-meta">@ <?php echo $username; ?></div>
			</div>
		</div>

	<?php }

	echo '</div>';

}

/**
 * Get Reactors Model.
 */
function yzpr_reactors_modal( $args = false ) {

	// item ID.
	$content_function = $args['function'];

	?>

	<div class="yz-wall-modal yz-modal-post-reactors" data-post-id="<?php echo $args['post_id']; ?>">

		<div class="yz-modal-reactors-head">
			<?php echo yzpr_get_modal_head_emojis( $args['post_id'], $args['emoji_id'] ); ?>				
		</div>

		<div class="yz-wall-modal-content">
			<?php $content_function( $args['post_id'], $args['emoji_id'] ); ?>
			<div class="yz-modal-list-loader">
				<i class="fa fa-spinner fa-spin" area-hidden="true"></i>
			</div>
		</div>

		<div class="yz-wall-modal-actions">
			<button class="yz-wall-modal-button yz-wall-modal-close"><?php _e( 'close', 'youzer' ); ?></button>
		</div>

	</div>

	<?php
}

/**
 * Get Post Reactions Count.
 */ 
function yzpr_get_modal_head_emojis( $activity_id, $emoticon_id ) {

	global $YZPR;
	
	// Init Emoji List.
	$output = null;

	// Get Available Emoticons.
	$emoticons = yzpr_get_emojis_list();

	foreach ( $emoticons as $emoji_id => $emoji ) {

		// Check if there's Emoji
		$emoji_reactors = (array) $YZPR->query->get_post_emoji_reactors( $activity_id, $emoji_id );

		if ( empty( $emoji_reactors ) ) {
			continue;
		}

		// Emoji Reactors Number
		$emoji_count = count( $emoji_reactors );

		// Emoji Head Class.
		$emoji_class = ( $emoji_id != $emoticon_id ) ? 'yz-modal-head-emoji' : 'yz-modal-head-emoji yz-modal-active-tab';
		
		// I Tab Already Loaded.
		$is_loaded = ( $emoji_id != $emoticon_id ) ? 'false' : 'true';
    	
    	// Get User Image Code.
        $output .= "<div class='$emoji_class' data-emoji-id='" . $emoji_id . "' data-loaded='" . $is_loaded ."'><img src='" . $emoticons[ $emoji_id ]['image']."'   alt=''/><span class='yz-modal-emoji-count'>" . $emoji_count . "</span></div>";

	}

	return $output;

}

/**
 * Get Post Reactors Modal Tab Users
 */
function yzpr_get_reactors_modal_tab_users() {

	// Get Modal Content
	yzpr_get_posts_reactions_list( $_POST['post_id'], $_POST['emoji_id'] );

	die();
}

add_action( 'wp_ajax_yzpr_get_modal_tab_reactors', 'yzpr_get_reactors_modal_tab_users' );
add_action( 'wp_ajax_nopriv_yzpr_get_modal_tab_reactors', 'yzpr_get_reactors_modal_tab_users' );	


/**
 * Delete Wall Favs Transient.
 */
function yz_delete_activity_reactions_transient( $reaction_id = null, $activity_id = null ) {
	// Delete Transient.
	delete_transient( 'yz_get_activity_reactions_' . $activity_id );
}

add_action( 'yzpr_after_save_post_reaction', 'yz_delete_activity_reactions_transient', 10, 2 );
add_action( 'yzpr_after_delete_post_reaction', 'yz_delete_activity_reactions_transient', 10, 2 );

/**
 * Remove Buddypress Old Likes
 */
function yzprc_remove_buddypress_old_likes() {
	remove_action( 'bp_activity_entry_meta_non_logged_in', 'yz_show_who_liked_activities', 99 );
}

add_action( 'bp_activity_entry_meta_non_logged_in', 'yzprc_remove_buddypress_old_likes', 9 );


/*
 * Set Body Scheme Class
 */
function yzprc_class( $classes ) {
    $classes[] = 'yz-enabled-activity-reactions';   
    return $classes;
}

add_filter( 'yz_activity_page_class','yzprc_class' );

/**
 * Set Default Options.
 */
function yzpr_options_default_options( $options ) {

	$options['yz_enable_posts_reaction'] = 'on';
	$options['yz_like_reaction_id'] = 'yz_emoji_1';
	$options['yz_enable_comments_reaction'] = 'on';
	$options['yzpr_display_reactions_count'] = 'on';
	$options['yz_favorite_reaction_id'] = 'yz_emoji_1';

	return $options;
}

add_filter( 'yz_default_options', 'yzpr_options_default_options', 10, 1 );