<?php 

class Yz_Reactions_Admin {

    public $field_name;

    function __construct() {

        // Set Licence Field Name
        $this->field_name = 'yz_activity_reactions_license_key';

        add_filter( 'yz_extensions_settings_menu', array( $this, 'settings_menu' ) );
        add_action( 'yz_panel_save_settings', array( $this, 'save_settings' ) );
        add_action( 'admin_init', array( $this, 'check_for_updates' ) );

    }

    /**
     * Add New Panel Menu.
     */
    function settings_menu( $tabs ) {

        // Add New Tab.
        $tabs['reaction-settings'] =  array(
            'id'    => 'reaction-settings',
            'icon'  => 'fas fa-smile',
            'function'  => array( $this, 'settings' ),
            'title' => __( 'Posts Reactions settings', 'youzer' ),
        );

        return $tabs;
    }

    /**
     * # Reactions Settings.
     */
    function settings() {

        global $Yz_Settings, $Youzer_Admin;

        // Get License.
        $license = get_option( $this->field_name );

        if ( ! empty( $license ) ) {

        // Get License Status.
        $Youzer_Admin->get_license_status( array( 'license' => $license, 'option_id' => $this->field_name, 'product_id' => 1276, 'position' => 'top' )  );
        
        // Scripts.
        $this->scripts();        


        $Yz_Settings->get_field(
            array(
                'title' => __( 'general Settings', 'youzer' ),
                'type'  => 'openBox'
            )
        );

        $Yz_Settings->get_field(
            array(
                'title' => __( 'Enable Posts Reactions', 'youzer' ),
                'desc'  => __( 'enable activity posts reactions', 'youzer' ),
                'id'    => 'yz_enable_posts_reaction',
                'type'  => 'checkbox'
            )
        );

        $Yz_Settings->get_field(
            array(
                'title' => __( 'Enable Comments Reactions', 'youzer' ),
                'desc'  => __( 'enable activity commets reactions', 'youzer' ),
                'id'    => 'yz_enable_comments_reaction',
                'type'  => 'checkbox'
            )
        );

        $reactions = yzpr_get_emojis_list();

        foreach ( $reactions as $key => $reaction ) {
            $reactions_select[ $key ] = $reaction['title'];
        }

        $Yz_Settings->get_field(
            array(
                'title' => __( 'Favorites Tab Linked Reaction', 'youzer' ),
                'desc'  => __( 'this reaction posts will appear under the user favorites tab', 'youzer' ),
                'id'    => 'yz_favorite_reaction_id',
                'opts'  => $reactions_select,
                'type'  => 'select'
            )
        );

        $Yz_Settings->get_field(
            array(
                'title' => __( 'Sync the like button with a reaction', 'youzer' ),
                'desc'  => __( 'if the user clicked the activity like button the selected reaction will be used automatically.', 'youzer' ),
                'id'    => 'yz_like_reaction_id',
                'opts'  => $reactions_select,
                'type'  => 'select'
            )
        );

        $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

        $modal_args = array(
            'id'        => 'yz-reactions-form',
            'title'     => __( 'add new emoji', 'youzer' ),
            'button_id' => 'yz-add-emoji'
        );

        // Get 'Create new Emoji' Form.
        yz_panel_modal_form( $modal_args, array( &$this, 'create_new_emoji_form' ) );

        // Get Exists Reactions.
        $this->get_reaction_emojis();

        }

        // Get License Settings.
        $Youzer_Admin->get_license_settings( array( 'license' => $license, 'option_id' => $this->field_name, 'product_id' => 1276 )  );

    }

    /**
     * # Create New Emoji Form.
     */
    function create_new_emoji_form() {

        // Get Data.
        global $Yz_Settings;

        $Yz_Settings->get_field(
            array(
                'type'  => 'openDiv',
                'class' => 'yz-reactions-form'
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'Emoji Visbility', 'youzer' ),
                'desc'       => __( 'show/hide emoji', 'youzer' ),
                'id'         => 'yz_emoji_visibility',
                'type'       => 'checkbox',
                'std'        => 'on',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'Emoji Title', 'youzer' ),
                'desc'       => __( 'add emoji title', 'youzer' ),
                'id'         => 'yz_emoji_title',
                'type'       => 'text',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'Emoji Description', 'youzer' ),
                'desc'       => __( 'add emoji description', 'youzer' ),
                'id'         => 'yz_emoji_description',
                'type'       => 'text',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'Emoji Image', 'youzer' ),
                'desc'       => __( 'upload emoji image', 'youzer' ),
                'id'         => 'yz_emoji_image',
                'type'       => 'upload',
                'no_options' => true
            )
        );

        // Add Hidden Input
        $Yz_Settings->get_field(
            array(
                'type'       => 'hidden',
                'id'         => 'yz_reactions_form',
                'class'      => 'yz-keys-name',
                'std'        => 'yz_reactions',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field( array( 'type' => 'closeDiv' ) );
    }

    /**
     * Get Reactions List
     */
    function get_reaction_emojis() {

        global $Yz_Settings;

        // Get Reactions Items
        $reactions = yz_options( 'yz_reaction_emojis' );

        // Next Emoji ID
        $yz_nextEmoji = yz_options( 'yz_next_emoji_nbr' );
        $yz_nextEmoji = ! empty( $yz_nextEmoji ) ? $yz_nextEmoji : 1;

        ?>

        <script> var yz_nextEmoji = <?php echo $yz_nextEmoji; ?>; </script>

        <div class="yz-custom-section">
            <div class="yz-cs-head">
                <div class="yz-cs-buttons">
                    <button class="yz-md-trigger yz-reactions-button" data-modal="yz-reactions-form">
                        <i class="fa fa-plus-circle" aria-hidden="true"></i>
                        <?php _e( 'add new emoji', 'youzer' ); ?>
                    </button>
                </div>
            </div>
        </div>

        <ul id="yz_reactions" class="yz-cs-content">

        <?php

            // Show No Emojis Found .
            if ( empty( $reactions ) ) {
                echo "<p class='yz-no-content yz-no-emojis'>" . __( 'No emojis found', 'youzer-posts-reactions' ) . "</p></ul>";
                return false;
            }

            foreach ( $reactions as $emoji_id => $data ) :

                // Get Data.
                $image       = isset( $data['image'] ) ? $data['image'] : null ;
                $title       = isset( $data['title'] ) ? $data['title'] : null ;
                $visibility  = isset( $data['visibility'] ) ? $data['visibility'] : null ;
                $description = isset( $data['description'] ) ? $data['description'] : null ;

                $name = "yz_reactions[$emoji_id]";

                ?>

                <!-- Emoji Item -->
                <li class="yz-emoji-item" data-emoji-name="<?php echo $emoji_id; ?>">
                    <div class="yz-emoji-img" style="background-image:url(<?php echo $image; ?>);"></div>
                    <div class="yz-emoji-data">
                        <h2 class="yz-emoji-title"><?php echo $title; ?></h2>
                        <div class="yz-emoji-actions">
                            <a class="yz-edit-item yz-edit-emoji"></a>
                            <a class="yz-delete-item yz-delete-emoji"></a>
                        </div>
                    </div>
                    <!-- Data Inputs -->
                    <input type="hidden" name="<?php echo $name; ?>[title]" value="<?php echo $title; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[description]" value="<?php echo $description; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[image]" value="<?php echo $image; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[visibility]" value="<?php echo $visibility; ?>">
                </li>

            <?php endforeach; ?>

        </ul>

        <?php
    }

    /**
     * # Add Settings Tab Content
     */
    function save_settings( $data ) {

        // Save Reaction Emojis.
        if ( isset( $data['yz_reactions_form'] ) ) {

            // Get Options
            $emojis = isset( $data['yz_reactions'] ) ? $data['yz_reactions'] : null;

            // Update Options
            // yzpr_save_emojis_settings( $reactions );

            if ( empty( $emojis ) ) {
                delete_option( 'yz_reaction_emojis' );
                return false;
            }

            // Update Options.
            $update_options = update_option( 'yz_reaction_emojis', $emojis );

            // Update Next ID
            if ( $update_options ) {
                update_option( 'yz_next_emoji_nbr', $this->get_next_ID( $emojis, 'emoji' ) );
            }
        }

    }

    /**
     * Get Fields Next ID.
     */
    function get_next_ID( $items, $item ) {

        // Set Up Variables.
        $keys = array_keys( $items );

        // Get Keys Numbers.
        foreach ( $keys as $key ) {
            $key_number = preg_match_all( '/\d+/', $key, $matches );
            $new_keys[] = $matches[0][0];
        }

        // Get ID's Data.
        $new_ID = max( $new_keys ); 
        $old_ID = yz_option( 'yz_next_' . $item . '_nbr' );
        $max_ID = ( $new_ID < $old_ID ) ? $old_ID : $new_ID;

        // Return Biggest Key.
        return $max_ID + 1;
    }
    /**
     * Call Social Sharing Assets.
     */
    function scripts() {
    
        // Call CSS.
        wp_enqueue_style( 'yz-posts-reactions', YZPR_ASSETS . 'css/yzpr-admin.min.css' ); 

        // Call JS.
        wp_enqueue_script( 'yz-posts-reactions', YZPR_ASSETS . 'js/yzpr-reactions.min.js' ); 
        
        $data = array( 
            'update_emoji' => __( 'Update Emoji', 'youzer-posts-reactions' ),
            'no_emojis' => __( 'No emojis found', 'youzer-posts-reactions' ),
            'empty_emoji' => __( 'Emoji Name Is Empty or Is Already Exist', 'youzer-posts-reactions' ),
            'empty_emoji_desc' => __( 'Emoji Description Is Empty', 'youzer-posts-reactions' ),
            'empty_emoji_image' => __( 'Emoji Image Is Empty', 'youzer-posts-reactions' )
        );

        wp_localize_script( 'yz-posts-reactions', 'Youzer_AR', $data );

    }

    /**
     * Check For Updates.
     **/

    function check_for_updates() {

        // Get Licence.
        $license = get_option( $this->field_name );

        if ( empty( $license ) ) {
            return;
        }

        // setup the updater
        $edd_updater = new EDD_SL_Plugin_Updater( EDD_KAINELABS_STORE_URL, YZPR_FILE,
            array(
                'version' => YZPR_VERSION,                   
                'license' => $license,
                'item_id' => '1276',
                'author'  => 'Youssef Kaine', 
                'beta'    => false,
            )
        );

    }
}

$Reactions_Admin = new Yz_Reactions_Admin();