<?php
/*
 * Plugin Name: Youzer - Activity Reactions
 * Plugin URI:  http://youzer.kainelabs.com
 * Description: Youzer Activity Reactions Extension
 * Version: 1.0.7
 * Author: Youssef Kaine
 * Author URI: http://www.kainelabs.com
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 */

// Youzer Posts Reactions Path.
define( 'YZPR_FILE', __FILE__ );
define( 'YZPR_VERSION', '1.0.7' );
define( 'YZPR_BASENAME', plugin_basename( __FILE__ ) );
define( 'YZPR_PATH', plugin_dir_path( __FILE__ ) );
define( 'YZPR_ASSETS', plugin_dir_url( __FILE__ ) . 'assets/' );

/**
 * Check if Youzer Plugin is installed
 */
function yzar_check_for_youzer_plugin() {

    if ( ! class_exists( 'Youzer' ) ) {

        function yzar_extension_admin_notice() {

            ?>
            <div class="notice notice-warning is-dismissible">
                <p><?php echo sprintf( __( '<strong> Notice : </strong>Please install and activate <strong><a href="%1s">Youzer</strong></a> plugin to use the <strong>Youzer - Activity Reactions</strong> extension.', 'youzer' ), 'https://codecanyon.net/item/youzer-new-wordpress-user-profiles-era/19716647' ); ?></p>
            </div>
            <?php
        }

        // Show Notice
        add_action( 'admin_notices', 'yzar_extension_admin_notice' );

        // Deactivate The Plugin.
        deactivate_plugins( plugin_basename( __FILE__ ) );

        return;

    }
    
}

add_action( 'admin_init', 'yzar_check_for_youzer_plugin' );

/**
 * Init Activity Reactions Extension.
 */
function youzer_activity_reactions_init() {

    // Init Global Var.
    global $YZPR;

    // Include Main Class.
    require_once YZPR_PATH . 'class-youzer-posts-reactions.php';
    
    // Init.
    $YZPR = new Youzer_Posts_Reactions;

}

add_action( 'youzer_after_setup_actions', 'youzer_activity_reactions_init' );


/**
 * On Youzer Activity Reactions Activation Hook.
 */
function youzer_activity_reactions_activation() {

    // Include Setup File.    
    require_once YZPR_PATH . 'core/class-yzpr-setup.php';

    // Init Setup Class.
    $YZPR_Setup = new YZPR_Setup();

    // Install Youzer Options
    $YZPR_Setup->install_options();

    // Build Database.
    $YZPR_Setup->build_database_table();

}

register_activation_hook( __FILE__, 'youzer_activity_reactions_activation' );

/**
 * Load Youzer - Activity Reactions Text Domain!
 */
function yz_activity_reactions_localization() {

    $domain = 'youzer';
    $mofile_custom = trailingslashit( WP_LANG_DIR ) . sprintf( '%s-%s.mo', $domain, get_locale() );

    if ( is_readable( $mofile_custom ) ) {
        return load_textdomain( $domain, $mofile_custom );
    } else {
        return load_plugin_textdomain( $domain, FALSE, dirname( YZPR_BASENAME ) . '/languages/' );

    }
}

add_action( 'plugins_loaded', 'yz_activity_reactions_localization' );
