<?php

class Youzer_Member_Types_Admin {

	public $field_name;

	function __construct() {

		// Set Licence Field Name
		$this->field_name = 'yz_member_types_license_key';

		// Add Settings Tab.
		add_filter( 'yz_extensions_settings_menu', array( $this, 'settings_menu' ) );

		// Sync Member Type => Field Value.
		add_action( 'current_screen', array( $this, 'users_page_screen' ) );

		// Check for Updates.
		add_action( 'admin_init', array( $this, 'check_for_updates' ) , 0 );

		// Save Settings
		add_action( 'yz_panel_save_settings',  array( $this, 'save_settings' ) );

	}

	/**
	 * # Add Settings Tab
	 */
	function settings_menu( $tabs ) {

		$tabs['member-types'] = array(
       	    'icon'  => 'fas fa-sitemap',
       	    'id'    => 'member-types',
       	    'function' => array( $this, 'settings' ),
       	    'title' => __( 'Member Types settings', 'youzer-member-types' ),
        );
        
        return $tabs;

	}

    /**
     * # Custom Tabs Settings.
     */
    function settings() {
	   
        global $Yz_Settings, $Youzer_Admin;

		// Get License.
		$license = get_option( $this->field_name );

		if ( ! empty( $license ) ) {

            $this->scripts();

            // Get License Status.
            $Youzer_Admin->get_license_status( array( 'license' => $license, 'option_id' => $this->field_name, 'product_id' => 64, 'position' => 'top' )  );

	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'Registration Settings', 'youzer-member-types' ),
	                'type'  => 'openBox'
	            )
	        );

	        $modal_args = array(
	            'button_id' => 'yz-add-member-type',
	            'id'        => 'yz-member-types-form',
	            'title'     => __( 'create new member type', 'youzer-member-types' )
	        );

	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'Enable Member Types While Registration', 'youzer-member-types' ),
	                'desc'  => __( 'make member types selectable in the registration form', 'youzer-member-types' ),
	                'id'    => 'yz_enable_member_types_registration',
	                'type'  => 'checkbox'
	            )
	        );

	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'Set Default Members Type', 'youzer-member-types' ),
	                'desc'  => __( 'works only if the the option above is disabled', 'youzer-member-types' ),
	                'id'    => 'yz_default_member_type',
	                'opts'  => $this->member_types_drop_down(),
	                'type'  => 'select'
	            ) 
	        );

	        $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'general Settings', 'youzer-member-types' ),
	                'type'  => 'openBox'
	            )
	        );

	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'Enable Member Types', 'youzer-member-types' ),
	                'desc'  => __( 'activate member types', 'youzer-member-types' ),
	                'id'    => 'yz_enable_member_types',
	                'type'  => 'checkbox'
	            )
	        );

	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'Enable Member Types Modification', 'youzer-member-types' ),
	                'desc'  => __( 'enable users to edit the member type after registration', 'youzer-member-types' ),
	                'id'    => 'yz_enable_member_types_modification',
	                'type'  => 'checkbox'
	            )
	        );

	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'Display Member Types in Infos Tab', 'youzer-member-types' ),
	                'desc'  => __( 'show member types in the infos tab', 'youzer-member-types' ),
	                'id'    => 'yz_enable_member_types_in_infos',
	                'type'  => 'checkbox'
	            )
	        );
	    
	        $Yz_Settings->get_field(
	            array(
	                'title' => __( 'Allow members with no type', 'youzer-member-types' ),
	                'desc'  => __( 'give the users the ability to stay with no member types', 'youzer-member-types' ),
	                'id'    => 'yz_allow_no_member_type',
	                'type'  => 'checkbox'
	            )
	        );

	        $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

	        // Get New Member Types Form.
	        $this->modal( $modal_args, array( &$this, 'form' ) );

	        // Get Member Types List.
	        $this->get_types_list();
		
		}

        // Get License Settings.
        $Youzer_Admin->get_license_settings( array( 'license' => $license, 'option_id' => $this->field_name, 'product_id' => 64 )  );
        
    }

    /**
     * # Member Types Dropdown.
     */
    function member_types_drop_down() {

        // Get Var.
        $options = array();

        // Add default option
        $options[''] = __( '-- Select Default Type --', 'youzer-member-types' );

        // Get Member Types.
        $member_types = yz_get_registration_member_types();

        if ( empty( $member_types ) ) {
            return $options;
        }

        foreach ( $member_types as $type ) {

            // Get Type ID.
            $type_id = isset( $type['id'] ) ? $type['id'] : yz_get_member_type_id( $type['singular'] );

            // Get Option.
            $options[ $type_id ] = $type['name'];

        }

        return $options;

    }

    /**
     * # Get Roles.
     */
    function get_roles() {
        global $wp_roles;
        return apply_filters('editable_roles', $wp_roles->roles );
    }

    /**
     *  Modal
     */
    function modal( $args, $modal_function ) {

        $title        = $args['title'];
        $button_id    = $args['button_id'];
        $button_title = isset( $args['button_title'] ) ? $args['button_title'] : __( 'save', 'youzer' );
        ?>

        <div class="yz-md-modal yz-md-effect-1" id="<?php echo $args['id'] ;?>">
            <h3 class="yz-md-title" data-title="<?php echo $title; ?>">
                <?php echo $title; ?>
                <i class="fas fa-times yz-md-close-icon"></i>
            </h3>
            <div class="yz-md-content">
                <?php $modal_function(); ?>
            </div>
            <div class="yz-md-actions">
                <button id="<?php echo $button_id; ?>" data-add="<?php echo $button_id; ?>" class="yz-md-button yz-md-save">
                    <?php echo $button_title ?>
                </button>
                <button class="yz-md-button yz-md-close">
                    <?php _e( 'close', 'youzer' ); ?>
                </button>
            </div>
        </div>

        <?php
    }

    /**
     * # Create New Member Types Form.
     */
    function form() {

        // Get Data.
        global $Yz_Settings;

        $Yz_Settings->get_field(
            array(
                'type'  => 'openDiv',
                'class' => 'yz-member-types-form'
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'enable member type', 'youzer-member-types' ),
                'desc'       => __( 'enable this member type', 'youzer-member-types' ),
                'id'         => 'yz_member_type_active',
                'type'       => 'checkbox',
                'std'        => 'on',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'display in registration form', 'youzer-member-types' ),
                'desc'       => __( 'make this type selectable in the registration form', 'youzer-member-types' ),
                'id'         => 'yz_member_type_register',
                'type'       => 'checkbox',
                'std'        => 'on',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'        => __( 'member type icon', 'youzer-member-types' ),
                'desc'         => __( 'select member type icon', 'youzer-member-types' ),
                'id'           => 'yz_member_type_icon',
                'type'         => 'icon',
                'std'          => 'fas fa-user',
                'no_options'   => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'        => __( 'member type ID', 'youzer-member-types' ),
                'desc'         => __( 'Should be in english letters and without spaces you can use only underscores to link words example: company_ceo', 'youzer-member-types' ),
                'id'           => 'yz_member_type_id',
                'type'         => 'text',
                'no_options'   => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'        => __( 'member type name', 'youzer-member-types' ),
                'desc'         => __( 'example: students', 'youzer-member-types' ),
                'id'           => 'yz_member_type_name',
                'type'         => 'text',
                'no_options'   => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'member type singular name', 'youzer-member-types' ),
                'desc'       => __( 'example: student', 'youzer-member-types' ),
                'id'         => 'yz_member_type_singular',
                'type'       => 'text',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'member type directory slug', 'youzer-member-types' ),
                'desc'       => __( 'example: students', 'youzer-member-types' ),
                'id'         => 'yz_member_type_slug',
                'type'       => 'text',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'display in members directory', 'youzer-member-types' ),
                'desc'       => __( 'show member type tab in members directory', 'youzer-member-types' ),
                'id'         => 'yz_member_type_show_in_md',
                'type'       => 'checkbox',
                'std'        => 'on',
                'no_options' => true
            )
        );

        // foreach ( get_editable_roles() as $id => $role ) {
        //     $checkbox_roles[ $id ] = $role['name']; 
        // }
        // // foreach ( get_editable_roles() as $id => $role ) {
        //       $Yz_Settings->get_field(
        //     array(
        //             'title' => __( 'associated roles', 'youzer-member-types' ),
        //             // 'desc'  => __( 'make member types selectable in the registration form', 'youzer-member-types' ),
        //             'id'    => 'yz_member_type_roles',
        //             'type'  => 'checkbox',
        //             'opts' => $checkbox_roles,
        //         'std'        => 'off',
        //         'no_options' => true
        //         )
        //     );

        // // }

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'icon background left color', 'youzer-member-types' ),
                'desc'       => __( 'directory icon background left color', 'youzer-member-types' ),
                'id'         => 'yz_member_type_left_color',
                'type'       => 'color',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field(
            array(
                'title'      => __( 'icon background right color', 'youzer-member-types' ),
                'desc'       => __( 'directory icon background right color', 'youzer-member-types' ),
                'id'         => 'yz_member_type_right_color',
                'type'       => 'color',
                'no_options' => true
            )
        );

        // Add Hidden Input
        $Yz_Settings->get_field(
            array(
                'type'       => 'hidden',
                'class'      => 'yz-keys-name',
                'std'        => 'yz_member_types',
                'id'         => 'yz_member_types_form',
                'no_options' => true
            )
        );

        $Yz_Settings->get_field( array( 'type' => 'closeDiv' ) );

    }

    /**
     * Get Member Types List
     */
    function get_types_list() {

        global $Yz_Settings;

        // Get Member Type Items
        $yz_member_types = yz_options( 'yz_member_types' );

        // Next Member Type ID
        $next_id = yz_options( 'yz_next_member_type_nbr' );
        $yz_nextMType = ! empty( $next_id ) ? $next_id : '1';

        ?>

        <script> var yz_nextMType = <?php echo $yz_nextMType; ?>; </script>

        <div class="yz-custom-section">
            <div class="yz-cs-head">
                <div class="yz-cs-buttons">
                    <button class="yz-md-trigger yz-member-types-button" data-modal="yz-member-types-form">
                        <i class="fas fa-user-plus"></i>
                        <?php _e( 'add new member type', 'youzer-member-types' ); ?>
                    </button>
                </div>
            </div>
        </div>

        <ul id="yz_member_types" class="yz-cs-content">

        <?php

            // Show No Types Found .
            if ( empty( $yz_member_types ) ) {
                echo "<p class='yz-no-content yz-no-member-types'>" . __( 'No member types Found !', 'youzer-member-types' ) . "</p></ul>";
                return false;
            }

            foreach ( $yz_member_types as $type => $data ) :

                // Get Widget Data.
                $icon = $data['icon'];
                $slug = $data['slug'];
                $title = $data['name'];
                $active = $data['active'];
                $singular = $data['singular'];
                $register = $data['register'];
                $show_in_md = $data['show_in_md'];
                $left_color = $data['left_color'];
                $right_color = $data['right_color'];
                $id = isset( $data['id'] ) ? $data['id'] : yz_get_member_type_id( $data['singular'] );

                // Get Field Name.
                $name = "yz_member_types[$type]";

                ?>

                <!-- Tab Item -->
                <li class="yz-member-type-item" data-member-type-name="<?php echo $type; ?>">
                    <h2 class="yz-member-type-name">
                        <i class="yz-member-type-icon <?php echo $icon; ?>"></i>
                        <span><?php echo $title; ?></span>
                    </h2>
                    <input type="hidden" name="<?php echo $name; ?>[id]" value="<?php echo $id; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[icon]" value="<?php echo $icon; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[name]" value="<?php echo $title; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[singular]" value="<?php echo $singular; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[active]" value="<?php echo $active; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[right_color]" value="<?php echo $right_color; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[left_color]" value="<?php echo $left_color; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[show_in_md]" value="<?php echo $show_in_md; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[slug]" value="<?php echo $slug; ?>">
                    <input type="hidden" name="<?php echo $name; ?>[register]" value="<?php echo $register; ?>">
                    <a class="yz-edit-item yz-edit-member-type"></a>
                    <a class="yz-delete-item yz-delete-member-type"></a>
                </li>

            <?php endforeach; ?>

        </ul>

        <?php
    }

	/**
	 * # Admin Scripts.
	 */
	function scripts() {

        global $Youzer_Member_Types;

        $data = array(
            'update_member_type'    => __( 'update member type', 'youzer-member-types' ),
            'no_member_types'       => __( 'No member types Found !', 'youzer-member-types' ),
            'mtype_name_empty'      => __( 'member type name is empty!', 'youzer-member-types' ),
            'mtype_slug_empty'      => __( 'member type slug is empty!', 'youzer-member-types' ),
            'mtype_singular_empty'  => __( 'member type singular name is empty!', 'youzer-member-types' ),
            'mtype_singular_lowercase'  => __( 'member type singular name should be all lowercase !', 'youzer-member-types' ),
            'mtype_singular_spaces'  => __( 'member type singular name should not contain spaces !', 'youzer-member-types' ),
        );

        // Load Member Types Script.
        wp_enqueue_script( 'yz-member-types', YZMT_AA . 'js/yz-member-types.min.js', array( 'jquery' ), $Youzer_Member_Types->version, true );
        
        wp_localize_script( 'yz-member-types', 'Youzer_MT', $data );

	}

	/**
	 * Users Page Screen Actions.
	 **/
	function users_page_screen() {

		// Get Current Screen Page.
    	$current_screen = get_current_screen();

	    if ( $current_screen->id === 'users' ) {
			add_action( 'bp_set_member_type', array( &$this, 'link_member_type_to_field_value' ), 10, 2 );
	    }
	}

	
	/**
	 * Sync Member Type => Field Value.
	 */
	function link_member_type_to_field_value( $user_id, $member_type ) {

	    if ( ! is_admin() ) {
	        return;
	    }

	    // Get Filed ID.
	    $field_id = yz_get_xprofile_fields_by_type( 'member_types' );


	    if ( ! isset( $field_id[0] ) || empty( $field_id[0] ) ) {
	        return;
	    }

	    xprofile_set_field_data( $field_id[0], $user_id, $member_type );

	}

	/**
	 * Check For Updates.
	 **/
	function check_for_updates() {
		
		// Get Licence.
		$license = get_option( $this->field_name );

		if ( empty( $license ) ) {
			return;
		}

		// setup the updater
		$edd_updater = new EDD_SL_Plugin_Updater( EDD_KAINELABS_STORE_URL, YZMT_FILE,
			array(
				'version' => YZMT_VERSION,                   
				'license' => $license,
				'item_id' => '64',
				'author'  => 'Youssef Kaine', 
				'beta'    => false,
			)
		);

	}

    /**
	 * # Add Settings Tab Content
	 */
	function save_settings( $data ) {

	    // Save Member Types.
	    if ( isset( $data['yz_member_types_form'] ) ) {
     		// Member Types Options
	    	$member_types = $data['yz_member_types'];
		    // Update Options
	    	$this->save_member_types( $member_types );
	    }

	}

	/**
	 * # Save Member Types.
	 */
	function save_member_types( $types ) {
		
		if ( empty( $types ) ) {
			delete_option( 'yz_member_types' );
			return false;
		}
		
		// Update Types.
    	$update_options = update_option( 'yz_member_types', $types );

		// Update Next ID
    	if ( $update_options ) {
			update_option(
				'yz_next_member_type_nbr', $this->get_next_ID( $types, 'member_type' )
			);
    	}

	}

    /**
     * Get Fields Next ID.
     */
    function get_next_ID( $items, $item ) {

        // Set Up Variables.
        $keys = array_keys( $items );

        // Get Keys Numbers.
        foreach ( $keys as $key ) {
            $key_number = preg_match_all( '/\d+/', $key, $matches );
            $new_keys[] = $matches[0][0];
        }

        // Get ID's Data.
        $new_ID = max( $new_keys ); 
        $old_ID = yz_option( 'yz_next_' . $item . '_nbr' );
        $max_ID = ( $new_ID < $old_ID ) ? $old_ID : $new_ID;

        // Return Biggest Key.
        return $max_ID + 1;
    }

}