<?php

class Youzer_Moderation_Admin {

	public $slug;	
	public $field_name;


	function __construct() {

		// Set Licence Field Name
		$this->field_name = 'yz_buddypress_moderation_license_key';

		// Add Settings Content.
		add_action( 'admin_menu', array( &$this, 'admin_init' ) );
		add_filter( 'yz_extensions_settings_menu', array( &$this, 'settings_menu' ) );
		add_action( 'yzm_reports_settings', array( &$this, 'settings' ) );

		// Save Settings.
		add_action( 'yz_panel_save_settings',  array( &$this, 'save_settings' ) );

        // Reports Page Slug.
        $this->slug = 'youzer-reports';

        // Init Query Class.
        $this->query = new YZM_Query();
        
		// Add Plugin Updater.
		// add_action( 'after_plugin_row_' . YZBM_BASENAME, array( &$this, 'activate_license_notice' ), 10, 3 );

		// Check For Updates.
		add_action( 'admin_init', array( &$this, 'check_for_updates' ), 0 );
        
	}

	/**
	 * # Add Reports Pages .
	 */
	function admin_init() {

		$moderators = $this->get_multicheckbox_options( 'yz_reports_moderation_roles' );

		if ( empty( $moderators ) ) {
			return;
		}

        // Get Current User Data.
        $user = get_userdata( bp_loggedin_user_id() );

        // Get User Roles.
        $user_roles = (array) $user->roles;

        foreach ( $moderators as $role ) {

            if ( in_array( $role, $user_roles ) ) {
            	$this->add_reports_admin_pages( $role );
                break;
            }

        }

	}

	/**
	 * Get Multi-Checkboxes.
	 */
	function get_multicheckbox_options( $option_id, $type = 'on' ) {

	    // Init Array.
	    $new_values = array();

	    // Get Option Values.
	    $options = yz_options( $option_id );

	    if ( ! empty( $options ) ) {
	        // Get Values
	        foreach ( $options as $option => $value ) {
	            if ( $value == $type ) {
	                $new_values[] = $option;
	            }
	        }
	    } else {
	        $new_values = $options;
	    }

	    return apply_filters( 'yz_get_multicheckbox_options', $new_values );
	}

	/**
	 * Add Admin & Reports Pages
	 */
	function add_reports_admin_pages( $role ) {


    	if ( apply_filters( 'yz_show_reports_page', true ) ) {

			global $wpdb;
	
			$total_items = $wpdb->get_var( 'SELECT COUNT( DISTINCT item_id ) FROM ' . $wpdb->prefix . "yz_reports WHERE status='open'" );
		    
		    // Add Youzer Plugin Admin Page.
		    $reports_hook = add_menu_page(
		    	__( 'Reports', 'youzer-moderation' ), $total_items ? sprintf( __( 'Reports <span class="awaiting-mod">%d</span>', 'youzer-moderation' ), $total_items ) :  __( 'Reports', 'youzer-moderation' ), $role, 'youzer-reports', array( &$this, 'general_settings' ), 'dashicons-flag' );
			
			add_action( "load-$reports_hook", array( &$this, 'admin_load' ) );
    	}

    	if ( apply_filters( 'yz_show_reports_restrictions_page', true ) ) {
    		$restriction_hook = add_submenu_page( 'youzer-reports', __( 'Users Restrictions', 'youzer-moderation' ), __( 'Restrictions', 'youzer-moderation' ), $role, 'youzer-users-restrictions', array( &$this, 'restrictions_table_content' ) );
			add_action( "load-$restriction_hook", array( &$this, 'restrictions_admin_load' ) );
		}

	}

	/**
	 * Restrictions Admin Load
	 */
	function restrictions_admin_load() {

		// Call Scripts
		$this->admin_header();

		global $yz_restrictions_table;

        include YZBM_PATH . 'admin/yz-class-restrictions-table.php';

        $yz_restrictions_table = new Youzer_Restrictions_Table();

	}

	/**
	 * Process Report Action.
	 */
	function admin_load() {

		// Call Scripts
		$this->admin_header();

	    // Load Light Box CSS and JS.
	    if ( defined( 'YZ_PA' ) ) {
		    wp_enqueue_style( 'yz-lightbox', YZ_PA . 'css/lightbox.min.css', array(), YZ_Version );
		    wp_enqueue_script( 'yz-lightbox', YZ_PA . 'js/lightbox.min.js', array( 'jquery' ), YZ_Version, true );
	    }

  		global $yz_reports_table;

		// Include Files.
        include YZBM_PATH . 'admin/yz-class-reports-table.php';
        include YZBM_PATH . 'admin/yz-class-attachments.php';

        // Init Class.
  		$yz_reports_table = new Youzer_Reports_Table();

	}

	/**
	 * Restrictions.
	 */
	function restrictions_table_content() {

		global $yz_restrictions_table;

		$messages = array();
		$title = __( 'Restrictions', 'youzer-moderation' );

        if ( isset( $_GET['user_id'] ) ) {
        	$display_name = bp_core_get_user_displayname( $_GET['user_id'] );
            $title = sprintf( __("%s's Restrictions", 'youzer-moderation' ), $display_name );
        }

		// If the user has just made a change to an activity item, build status messages.
		if ( ! empty( $_REQUEST['end-restrictions'] ) ) {

			$ended_restrictions = ! empty( $_REQUEST['end-restrictions'] ) ? (int) $_REQUEST['end-restrictions'] : 0;

			if ( $ended_restrictions > 0 )
				$messages[] = sprintf( _n( '%s restriction has been successfully ended.', '%s restrictions have been successfully ended.', $ended_restrictions, 'youzer-moderation' ), number_format_i18n( $ended_restrictions ) );

			if ( ! empty( $messages ) ) {
				set_transient( 'yzm-admin-notice', $messages, 5 );
				$redirect_to = remove_query_arg( array( 'end-restrictions' ), wp_get_referer() );
				wp_redirect( $redirect_to );
				exit;
			}

 		}

	    echo '<div class="wrap"><h2>' . $title . '</h2>'; 

	    $yz_restrictions_table->prepare_items(); 

	    $messages = get_transient( 'yzm-admin-notice' ); 
       
        /* Delete transient, only display this notice once. */
		if ( ! empty( $messages ) ) : ?>
			<div id="moderated" class="<?php echo ( ! empty( $_REQUEST['error'] ) ) ? 'error' : 'updated'; ?>"><p><?php echo implode( "<br/>\n", $messages ); ?></p></div><?php
        	delete_transient( 'yzm-admin-notice' );
		endif;

	    $yz_restrictions_table->views(); 

	    echo '<form method="post"><input type="hidden" name="page" value="">';
        // $yz_restrictions_table->search_box( 'search', 'search_id' );
        $yz_restrictions_table->display(); 
	    echo '</form></div>'; 

	}

	/**
	 * Content
	 */
	function general_settings() {

		global $yz_reports_table;

		$title = __( 'Reports', 'youzer-moderation' );

        if ( yzm_is_single_user_reports() ) {
        	$display_name = bp_core_get_user_displayname( $_GET['author'] );

            if ( $_GET['reports-type'] == 'reports' ) {
                $title = sprintf( __("%s's Reports", 'youzer-moderation' ), $display_name );
            } else if ( $_GET['reports-type'] == 'reported' ) {
                $title = sprintf( __("%s's Reported Items", 'youzer-moderation' ), $display_name );
            }

        }

		$messages = array();

		// If the user has just made a change to an activity item, build status messages.
		if ( ! empty( $_REQUEST['restore'] ) || ! empty( $_REQUEST['close'] ) || ! empty( $_REQUEST['spam-author'] ) || ! empty( $_REQUEST['ham-author'] ) || ! empty( $_REQUEST['delete'] ) || ! empty( $_REQUEST['delete-with-restrictions'] ) || ! empty( $_REQUEST['block-reports'] ) || ! empty( $_REQUEST['unblock-reports'] )  ) {

			$restored  = ! empty( $_REQUEST['restore'] ) ? (int) $_REQUEST['restore'] : 0;
			$closed    = ! empty( $_REQUEST['close']   ) ? (int) $_REQUEST['close'] : 0;
			$deleted   = ! empty( $_REQUEST['delete'] ) ? (int) $_REQUEST['delete'] : 0;
			$spammed   = ! empty( $_REQUEST['spam-author'] ) ? (int) $_REQUEST['spam-author'] : 0;
			$blocked   = ! empty( $_REQUEST['block-reports'] ) ? (int) $_REQUEST['block-reports'] : 0;
			$unblocked = ! empty( $_REQUEST['unblock-reports'] ) ? (int) $_REQUEST['unblock-reports'] : 0;
			$unspammed = ! empty( $_REQUEST['ham-author'] ) ? (int) $_REQUEST['ham-author'] : 0;
			$delete_r = ! empty( $_REQUEST['delete-with-restrictions'] ) ? (int) $_REQUEST['delete-with-restrictions'] : 0;

			if ( $spammed > 0 )
				$messages[] = sprintf( _n( '%s user has been successfully marked as spammer.', '%s users have been successfully marked as spammers.', $spammed, 'youzer-moderation' ), number_format_i18n( $spammed ) );

			if ( $unspammed > 0 )
				$messages[] = sprintf( _n( '%s user has been successfully marked as not spammer.', '%s users have been successfully marked as not spammers.', $unspammed, 'youzer-moderation' ), number_format_i18n( $unspammed ) );

			if ( $restored > 0 )
				$messages[] = sprintf( _n( '%s item has been successfully restored.', '%s items have been successfully restored.', $restored, 'youzer-moderation' ), number_format_i18n( $restored ) );

			if ( $closed > 0 )
				$messages[] = sprintf( _n( '%s report has been successfully closed.', '%s reports have been successfully closed.', $closed, 'youzer-moderation' ), number_format_i18n( $closed ) );

			if ( $deleted > 0 )
				$messages[] = sprintf( _n( '%s item has been successfully deleted.', '%s reports have been successfully deleted.', $deleted, 'youzer-moderation' ), number_format_i18n( $deleted ) );

			if ( $delete_r > 0 )
				$messages[] = sprintf( _n( '%s item has been successfully deleted and the restrictions are applied on the user.', '%s reports have been successfully deleted and the restrictions are applied on the users.', $delete_r, 'youzer-moderation' ), number_format_i18n( $delete_r ) );

			if ( $blocked > 0 )
				$messages[] = sprintf( _n( '%s user has been successfully blocked.', '%s users have been successfully blocked.', $blocked, 'youzer-moderation' ), number_format_i18n( $blocked ) );

			if ( $unblocked > 0 )
				$messages[] = sprintf( _n( '%s user has been successfully unblocked.', '%s users have been successfully unblocked.', $unblocked, 'youzer-moderation' ), number_format_i18n( $unblocked ) );

			if ( ! empty( $messages ) ) {
				set_transient( 'yzm-admin-notice', $messages, 5 );
				$redirect_to = remove_query_arg( array( 'rid', 'delete', 'restore', 'spam-author', 'ham-author', 'close', 'delete-with-restrictions','block-reports' ), wp_get_referer() );
				wp_redirect( $redirect_to );
				exit; 
			}

 		}

	    echo '<div class="wrap"><h2>' . $title . '</h2>'; 

	    $yz_reports_table->prepare_items(); 

	    $messages = get_transient( 'yzm-admin-notice' ); 
       
        /* Delete transient, only display this notice once. */
		if ( ! empty( $messages ) ) : ?>
			<div id="moderated" class="<?php echo ( ! empty( $_REQUEST['error'] ) ) ? 'error' : 'updated'; ?>"><p><?php echo implode( "<br/>\n", $messages ); ?></p></div><?php
        	delete_transient( 'yzm-admin-notice' );
		endif;

	    $yz_reports_table->views(); 

	    echo '<form method="post"><input type="hidden" name="page" value="">';
        // $yz_reports_table->search_box( 'search', 'search_id' );
        $yz_reports_table->display(); 
	    echo '</form></div>'; 

	}

	/**
	 * Settings
	 */
	function settings() {

		global $Youzer_Admin, $Yz_Settings;

		// Get License.
		$license = get_option( $this->field_name );

		if ( ! empty( $license ) ) {

        // Get License Status.
        $Youzer_Admin->get_license_status( array( 'license' => $license, 'option_id' => $this->field_name, 'product_id' => 27779, 'position' => 'top' )  );

	    /**
	     * This is the exemple to add roles checkbox.
	     */
	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Who can report items?', 'youzer-moderation' ),
	            'type'  => 'openBox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'desc'  => __( 'Select what roles can report items ?', 'youzer-moderation' ),
	            'id'    => 'yz_who_can_report_items',
	            'opts'  => yz_get_site_roles(),
	            'type'  => 'checkbox',
	        )
	    );

	    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Who can moderate items?', 'youzer-moderation' ),
	            'type'  => 'openBox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'desc'  => __( 'Select what roles can moderate items ?', 'youzer-moderation' ),
	            'id'    => 'yz_reports_moderation_roles',
	            'opts'  => yz_get_site_roles(),
	            'type'  => 'checkbox',

	        )
	    );

	    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Reports Form Settings', 'youzer-moderation' ),
	            'type'  => 'openBox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Description Required', 'youzer-moderation' ),
	            'desc'  => __( 'Make reports form description field required', 'youzer-moderation' ),
	            'id'    => 'yz_reports_form_desc_required',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );
	    
	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Visitors Reports Settings', 'youzer-moderation' ),
	            'type'  => 'openBox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Visitors Reports', 'youzer-moderation' ),
	            'desc'  => __( 'Allow visitors to report items', 'youzer-moderation' ),
	            'id'    => 'yz_enable_visitors_reports',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Show Fullname Field', 'youzer-moderation' ),
	            'desc'  => __( 'Show report form fullname field', 'youzer-moderation' ),
	            'id'    => 'yz_visitors_reports_show_fullname',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Show E-mail Field', 'youzer-moderation' ),
	            'desc'  => __( 'Show report form email field', 'youzer-moderation' ),
	            'id'    => 'yz_visitors_reports_show_email',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Emails Settings', 'youzer-moderation' ),
	            'type'  => 'openBox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify Admin On New Reports', 'youzer-moderation' ),
	            'desc'  => __( 'Notify admin when new reports are added', 'youzer-moderation' ),
	            'id'    => 'yz_notify_admin_on_new_reports',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify Admin On Hidden Reports', 'youzer-moderation' ),
	            'desc'  => __( 'Notify admin when new item is hidden', 'youzer-moderation' ),
	            'id'    => 'yz_notify_admin_on_hidden_item',
	            'type'  => 'checkbox'
	        )
	    );
	    
	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify User On Restored Item', 'youzer-moderation' ),
	            'desc'  => __( 'Notify user when their item is restored', 'youzer-moderation' ),
	            'id'    => 'yz_notify_user_on_restored_item',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify Reporter On Restored Item', 'youzer-moderation' ),
	            'desc'  => __( 'Notify reporter when their reported item is restored', 'youzer-moderation' ),
	            'id'    => 'yz_notify_reporter_on_restored_item',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify User On Deleted Item', 'youzer-moderation' ),
	            'desc'  => __( 'Notify user when their item is deleted', 'youzer-moderation' ),
	            'id'    => 'yz_notify_user_on_deleted_item',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify Reporter On Deleted Item', 'youzer-moderation' ),
	            'desc'  => __( 'Notify reporter when their reported item is deleted', 'youzer-moderation' ),
	            'id'    => 'yz_notify_reporter_on_deleted_item',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify User On Hidden Item', 'youzer-moderation' ),
	            'desc'  => __( 'Notify user when their item is hidden', 'youzer-moderation' ),
	            'id'    => 'yz_notify_user_on_hidden_item',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify User On Temporary Restrictions', 'youzer-moderation' ),
	            'desc'  => __( 'Notify user when temporary restrictions applied on their account', 'youzer-moderation' ),
	            'id'    => 'yz_notify_user_on_temporary_restrictions',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field(
	        array(
	            'title' => __( 'Notify User On Official Restrictions', 'youzer-moderation' ),
	            'desc'  => __( 'Notify user when official restrictions applied on their account', 'youzer-moderation' ),
	            'id'    => 'yz_notify_user_on_official_restrictions',
	            'type'  => 'checkbox'
	        )
	    );

	    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );


	    ?>

		<div class="yz-panel-subtabs">

			<input name="tabs" type="radio" id="tab-1" checked="checked" class="yz-panel-subtab-input"/>
			<label for="tab-1" class="yz-panel-subtab-label"><i class="fas fa-pencil-alt"></i><?php _e( 'Activities', 'youzer-moderation' ); ?></label>
			
			<div class="yz-panel-subtab-content">
				<?php

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'General Settings', 'youzer-moderation' ),
				            'type'  => 'openBox'
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Enable Reports', 'youzer-moderation' ),
				            'desc'  => __( 'Enable Activities Reports', 'youzer-moderation' ),
				            'id'    => 'yz_enable_activity_reports',
				            'type'  => 'checkbox'
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Subjects', 'youzer-moderation' ),
				            'desc'  => __( 'Activities Report Subjects', 'youzer-moderation' ),
				            'id'    => 'yz_activity_subjects',
				            'type'  => 'taxonomy'
				        )
				    );

				    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Automatic Moderation Settings', 'youzer-moderation' ),
				            'type'  => 'openBox'
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title'  => __( 'Activities automatic moderation', 'youzer-moderation' ),
				            'desc'  => __( 'Enable activities automatic moderation', 'youzer-moderation' ),
				            'id'    => 'yz_activity_automatic_moderation',
				            'type'  => 'checkbox',
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title'  => __( 'Activities Threshold', 'youzer-moderation' ),
				            'desc'  => __( 'Hide Activity after certain number of reports', 'youzer-moderation' ),
				            'id'    => 'yz_activity_reports_threshold',
				            'type'  => 'number',
				        )
				    );

				    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

				    // Get Temporary Restrictions.
				    $this->get_restrictions_settings( 'activity', 'temporary' );

				    // Get Official Restrictions.
				    $this->get_restrictions_settings( 'activity', 'official' );

				?>

			</div>

			<input name="tabs" type="radio" id="tab-2" class="yz-panel-subtab-input"/>
			<label for="tab-2" class="yz-panel-subtab-label"><i class="fas fa-comments"></i><?php _e( 'Comments', 'youzer-moderation' ); ?></label>
			<div class="yz-panel-subtab-content">
				<?php

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'General Settings', 'youzer-moderation' ),
				            'type'  => 'openBox'
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Enable Reports', 'youzer-moderation' ),
				            'desc'  => __( 'Enable Comments Reports', 'youzer-moderation' ),
				            'id'    => 'yz_enable_comment_reports',
				            'type'  => 'checkbox'
				        )
				    );


				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Subjects', 'youzer-moderation' ),
				            'desc'  => __( 'Comments Report Subjects', 'youzer-moderation' ),
				            'id'    => 'yz_comment_subjects',
				            'type'  => 'taxonomy'
				        )
				    );

				    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Automatic Moderation Settings', 'youzer-moderation' ),
				            'type'  => 'openBox'
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title'  => __( 'Comments automatic moderation', 'youzer-moderation' ),
				            'desc'  => __( 'Enable comments automatic moderation', 'youzer-moderation' ),
				            'id'    => 'yz_comment_automatic_moderation',
				            'type'  => 'checkbox',
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title'  => __( 'Comments Threshold', 'youzer-moderation' ),
				            'desc'  => __( 'Hide comment after certain number of reports', 'youzer-moderation' ),
				            'id'    => 'yz_comment_reports_threshold',
				            'type'  => 'number',
				        )
				    );

				    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );
				    

				    // Get Temporary Restrictions.
				    $this->get_restrictions_settings( 'comment', 'temporary' );

				    // Get Official Restrictions.
				    $this->get_restrictions_settings( 'comment', 'official' );
				?>
			</div>

			<input name="tabs" type="radio" id="tab-3" class="yz-panel-subtab-input"/>
			<label for="tab-3" class="yz-panel-subtab-label"><i class="fas fa-envelope"></i><?php _e( 'Messages', 'youzer-moderation' ); ?></label>
			<div class="yz-panel-subtab-content">
				<?php

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'General Settings', 'youzer-moderation' ),
				            'type'  => 'openBox'
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Enable Reports', 'youzer-moderation' ),
				            'desc'  => __( 'Enable Messages Reports', 'youzer-moderation' ),
				            'id'    => 'yz_enable_message_reports',
				            'type'  => 'checkbox'
				        )
				    );


				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Subjects', 'youzer-moderation' ),
				            'desc'  => __( 'Messages report subjects', 'youzer-moderation' ),
				            'id'    => 'yz_message_subjects',
				            'type'  => 'taxonomy'
				        )
				    );

				    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

				    $Yz_Settings->get_field(
				        array(
				            'title' => __( 'Automatic Moderation Settings', 'youzer-moderation' ),
				            'type'  => 'openBox'
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title'  => __( 'Messages automatic moderation', 'youzer-moderation' ),
				            'desc'  => __( 'Enable messages automatic moderation', 'youzer-moderation' ),
				            'id'    => 'yz_message_automatic_moderation',
				            'type'  => 'checkbox',
				        )
				    );

				    $Yz_Settings->get_field(
				        array(
				            'title'  => __( 'Messages Threshold', 'youzer-moderation' ),
				            'desc'  => __( 'Hide message after certain number of reports', 'youzer-moderation' ),
				            'id'    => 'yz_message_reports_threshold',
				            'type'  => 'number',
				        )
				    );

				    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

				    // Get Temporary Restrictions.
				    $this->get_restrictions_settings( 'message', 'temporary' );

				    // Get Official Restrictions.
				    $this->get_restrictions_settings( 'message', 'official' );

				?>
			</div>

			<input name="tabs" type="radio" id="tab-4" class="yz-panel-subtab-input"/>
			<label for="tab-4" class="yz-panel-subtab-label"><i class="fas fa-user"></i><?php _e( 'Members', 'youzer-moderation' ); ?></label>
			<div class="yz-panel-subtab-content"><?php

			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'General Settings', 'youzer-moderation' ),
			            'type'  => 'openBox'
			        )
			    );

			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'Enable Reports', 'youzer-moderation' ),
			            'desc'  => __( 'Enable Users Reports', 'youzer-moderation' ),
			            'id'    => 'yz_enable_user_reports',
			            'type'  => 'checkbox'
			        )
			    );


			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'Subjects', 'youzer-moderation' ),
			            'desc'  => __( 'Users Report Subjects', 'youzer-moderation' ),
			            'id'    => 'yz_user_subjects',
			            'type'  => 'taxonomy'
			        )
			    );

			    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );


			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'Automatic moderation settings', 'youzer-moderation' ),
			            'type'  => 'openBox'
			        )
			    );

			    $Yz_Settings->get_field(
			        array(
			            'title'  => __( 'Users automatic moderation', 'youzer-moderation' ),
			            'desc'  => __( 'Enable users automatic moderation', 'youzer-moderation' ),
			            'id'    => 'yz_user_automatic_moderation',
			            'type'  => 'checkbox',
			        )
			    );

			    $Yz_Settings->get_field(
			        array(
			            'title'  => __( 'Users threshold', 'youzer-moderation' ),
			            'desc'  => __( 'Hide user after certain number of reports', 'youzer-moderation' ),
			            'id'    => 'yz_user_reports_threshold',
			            'type'  => 'number',
			        )
			    );

			    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

			    // Get Temporary Restrictions.
			    $this->get_restrictions_settings( 'user', 'temporary' );

			    // Get Official Restrictions.
			    $this->get_restrictions_settings( 'user', 'official' );

			?></div>

			<input name="tabs" type="radio" id="tab-5" class="yz-panel-subtab-input"/>
			<label for="tab-5" class="yz-panel-subtab-label"><i class="fas fa-users"></i><?php _e( 'Groups', 'youzer-moderation' ); ?></label>
			<div class="yz-panel-subtab-content"><?php

			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'General settings', 'youzer-moderation' ),
			            'type'  => 'openBox'
			        )
			    );

			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'Enable reports', 'youzer-moderation' ),
			            'desc'  => __( 'Enable groups reports', 'youzer-moderation' ),
			            'id'    => 'yz_enable_group_reports',
			            'type'  => 'checkbox'
			        )
			    );


			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'Subjects', 'youzer-moderation' ),
			            'desc'  => __( 'Groups report subjects', 'youzer-moderation' ),
			            'id'    => 'yz_group_subjects',
			            'type'  => 'taxonomy'
			        )
			    );

			    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

			    $Yz_Settings->get_field(
			        array(
			            'title' => __( 'Automatic Moderation Settings', 'youzer-moderation' ),
			            'type'  => 'openBox'
			        )
			    );

			    $Yz_Settings->get_field(
			        array(
			            'title'  => __( 'Groups automatic moderation', 'youzer-moderation' ),
			            'desc'  => __( 'Enable groups automatic moderation', 'youzer-moderation' ),
			            'id'    => 'yz_group_automatic_moderation',
			            'type'  => 'checkbox',
			        )
			    );

			    $Yz_Settings->get_field(
			        array(
			            'title'  => __( 'Groups Threshold', 'youzer-moderation' ),
			            'desc'  => __( 'Hide group after certain number of reports', 'youzer-moderation' ),
			            'id'    => 'yz_group_reports_threshold',
			            'type'  => 'number',
			        )
			    );

			    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

			    // Get Temporary Restrictions.
			    $this->get_restrictions_settings( 'group', 'temporary' );

			    // Get Official Restrictions.
			    $this->get_restrictions_settings( 'group', 'official' );

			?></div>

		</div>

		<?php

		}

        // Get License Settings.
        $Youzer_Admin->get_license_settings( array( 'license' => $license, 'option_id' => $this->field_name, 'product_id' => 27779 )  );

	}

	/**
	 * # Add Settings Tab
	 */
	function settings_menu( $tabs ) {

		$tabs['moderation'] = array(
       	    'id'    => 'moderation',
       	    'icon'  => 'fas fa-flag',
       	    'function' => 'yzm_reports_settings',
       	    'title' => __( 'Moderation settings', 'youzer-moderation' ),
        );
        
        return $tabs;

	}

	/**
	 * Threshold Restrictions.
	 **/
	function get_restrictions_settings( $component, $type = 'temporary' ) {

		global $Yz_Settings;

		$restrictions = array(
			'posts' => array(
				'title' =>  __( 'Posts', 'youzer-moderation' ),
				'description' => __( 'Prevent user from adding activity posts', 'youzer-moderation' )
			),
			'comments' => array(
				'title' =>  __( 'Comments', 'youzer-moderation' ),
				'description' => __( 'Prevent user from adding comments', 'youzer-moderation' )
			),
			'friends' => array(
				'title' =>  __( 'Friendship', 'youzer-moderation' ),
				'description' => __( 'Prevent user from adding & deleting friends', 'youzer-moderation' )
			),
			'groups' => array(
				'title' =>  __( 'Groups', 'youzer-moderation' ),
				'description' => __( 'Prevent user from joining & leaving and creating groups', 'youzer-moderation' )
			),
			'reviews' => array(
				'title' =>  __( 'Reviews', 'youzer-moderation' ),
				'description' => __( 'Prevent user from adding & deleting reviews', 'youzer-moderation' )
			),
			'follows' => array(
				'title' =>  __( 'Follows', 'youzer-moderation' ),
				'description' => __( 'Disable follows system', 'youzer-moderation' )
			),
			'messages' => array(
				'title' =>  __( 'Messages', 'youzer-moderation' ),
				'description' => __( 'Disable private messages system', 'youzer-moderation' )
			)
		);

		$options_name = $type == 'temporary' ? 'yz_rtr' : 'yz_rgr';

		// Get Options Data.
	    $options = get_option( $options_name );
	    $options = ! empty( $options ) ? $options : array();
		$option_name = $options_name . '[' . $component .']';
		$section_title  = $type == 'temporary' ?  __( 'Temporary Threshold Restrictions Settings', 'youzer-moderation' ) :  __( 'Official Restrictions Settings', 'youzer-moderation' );
	    $Yz_Settings->get_field(
	        array(
	            'title' => $section_title,
	            'class' => 'ukai-box-3cols',
	            'type'  => 'openBox',
	        )
	    );

	    if ( $type == 'official' ) {

		    $Yz_Settings->get_field(
		        array(
		            'title'  => __( 'Restriction Period', 'youzer-moderation' ),
		            'desc'  => __( 'How many days this restriction should be applied.', 'youzer-moderation' ),
		            'id'    => $options_name . '_' . $component . '_period',
		            'type'  => 'number',
		        )
		    );

	    }

	    foreach ( $restrictions as $id => $restriction ) {
		    $Yz_Settings->get_field(
		        array(
		            'id'    => $id,
		            'std' 	=> isset( $options[ $component ][ $id ] ) ? $options[ $component ][ $id ] : 'off',
		            'type'  => 'checkbox',
		            'title' => $restriction['title'],
		            'desc'  => $restriction['description'],
		        ), false, $option_name
		    );
	    }


	    $Yz_Settings->get_field( array( 'type' => 'closeBox' ) );

        // Add Hidden Input
        $Yz_Settings->get_field(
            array(
                'type'       => 'hidden',
                'class'      => 'yz-keys-name',
                'std'        => 'yz_reports_settings',
                'id'         => 'yz_reports_settings_form',
                'no_options' => true
            )
        );
	}

	/**
	 * # Save Settings.
	 */
	function save_settings( $data ) {

	    if ( ! isset( $data['yz_reports_settings_form'] ) ) {
	    	return;
	    }

		// Save Official Restrictions.
		if ( isset( $data['yz_rgr'] ) ) {
			update_option( 'yz_rgr', $data['yz_rgr'] );
		}

		// Save Temporary Restrictions.
		if ( isset( $data['yz_rtr'] ) ) {
			update_option( 'yz_rtr', $data['yz_rtr'] );
			update_option( 'yz_rtr_activity', $data['yz_rtr']['activity'] );
			update_option( 'yz_rtr_comment', $data['yz_rtr']['comment'] );
			update_option( 'yz_rtr_message', $data['yz_rtr']['message'] );
			update_option( 'yz_rtr_user', $data['yz_rtr']['user'] );
			update_option( 'yz_rtr_group', $data['yz_rtr']['group'] );
		}

		// Save Roles.
		if ( empty( $this->get_multicheckbox_options( 'yz_who_can_report_items', 'off' ) ) ) {
			$reporters = 'on';
		} else {
			$reporters = $this->get_multicheckbox_options( 'yz_who_can_report_items' );
			$reporters = ! empty( $reporters ) ? $reporters : 'off';
		}

		update_option( 'yz_reporters_roles', $reporters );

	}

	/**
	 * Admin Header.
	 */
	function admin_header() {
		
		wp_enqueue_script( 'jquery' );

		// Call Font Awesome Icons.
    	wp_enqueue_style( 'yz-icons', YZ_AA . 'css/all.min.css', array(), YZ_Version );

	    // Call CSS.
	    wp_enqueue_style( 'yz-moderation', YZBM_URL . 'assets/css/yz-moderation.min.css' ); 

	    // Call JS.
    	wp_enqueue_script( 'yz-moderation', YZBM_URL . 'assets/js/yz-admin-moderation.min.js' ); 
	}

	/**
	 * Check For Updates.
	 **/
	function check_for_updates() {
		// Get Licence.
		$license = get_option( $this->field_name );

		if ( empty( $license ) ) {
			return;
		}

		// setup the updater
		$edd_updater = new EDD_SL_Plugin_Updater( EDD_KAINELABS_STORE_URL, YZBM_FILE,
			array(
				'version' => YZBM_VERSION,                   
				'license' => $license,
				'item_id' => '27779',
				'author'  => 'Youssef Kaine', 
				'beta'    => false,
			)
		);

	}

}