<?php

/**
 * Reports Attachments
 */
class Youzer_Reports_Attachments {
	
	function __construct() {
	}

    /**
     * Get Wall Attachments.
     */
	function get_attachments( $type, $item = null ) {
	
		$attachments = $this->get_attachments_files( $item->id, $type );

		if ( empty( $attachments ) ) {
			return;
		}

		if ( $type == 'message' || $type == 'comment' ) {

			$file_type = $this->get_file_type( $attachments[0]['original'] );
		
			switch ( $file_type ) {

				case 'image':
					$item->type = 'activity_photo';
					break;
				
				case 'video':
					$item->type = 'activity_video';
					break;
				
				case 'audio':
					$item->type = 'activity_audio';
					break;
				
				case 'file':
					$item->type = 'activity_file';
					break;
				
				default:
				return;
			}			

		}

        ob_start();

		switch ( $item->type ) {

			case 'new_cover':
			case 'new_avatar':
			case 'activity_photo':
			case 'activity_slideshow':
				$this->get_images( $attachments, $item->id );
				break;
			case 'activity_video':
				$this->get_videos( $attachments );
				break;
			case 'activity_audio':
				$this->get_audios( $attachments );
				break;
			case 'activity_link':
				$this->get_post_link( $attachments, $item->id );
				break;
			case 'activity_file':
				$this->get_files( $type, $attachments, $item->id );
				break;
			case 'activity_quote':
				$this->get_post_quote( $attachments, $item->id );
				break;
			case 'activity_giphy':
				$this->get_post_giphy( $item->id );
				break;
		}

		// Get Url Preview
		if ( $type == 'activity' ) {
			$this->get_activity_url_preview( $item->id, $item->content );
		}
		
		$content = ob_get_contents();
        
        ob_end_clean();

        if ( ! empty( $content ) ) {
        	$content = '<div class="yz-attachments">' . $content . '</div>';
        }

        return $content;
	}

	/**
	 * Cover Post.
	 */
	function get_post_giphy( $activity_id ) {

		// Get Image Url.
		$img_url = bp_activity_get_meta( $activity_id, 'giphy_image' );

		?>
		<a href="<?php echo $img_url; ?>" rel="nofollow" class="yz-img-with-padding" data-lightbox="yz-post-<?php echo $activity_id; ?>">
			<img src="<?php echo $img_url; ?>" alt="" />
		</a>
		<?php

	}

	/**
	 * Quote Post.
	 */
	function get_post_quote( $attachments, $activity_id ) {

		// Get Quote Cover Url. 
		$cover_img = ! empty( $attachments ) ? yz_get_media_url( $attachments[0] ) : false;

		// Get Link Data
		$quote_txt = bp_activity_get_meta( $activity_id, 'yz-quote-text' );
		$quote_owner = bp_activity_get_meta( $activity_id, 'yz-quote-owner' );

		// Get User Data
	    $quote_bg = "style='background-image:url( $cover_img );'";

	    ?>

	    <div class="yzw-quote-post">
		    <div class="yzw-quote-content quote-with-img">
		        <?php if ( $cover_img ) : ?>
		            <div class="yzw-quote-cover" <?php echo $quote_bg; ?>></div>
		        <?php endif; ?>
		        <div class="yzw-quote-main-content">
		            <div class="yzw-quote-icon"><i class="fas fa-quote-right"></i></div>
		            <blockquote><?php echo $quote_txt; ?></blockquote>
		            <h3 class="yzw-quote-owner"><?php echo $quote_owner; ?></h3>
		        </div>
		    </div>
	    </div>
		
		<?php
	}

	/**
	 * File Post.
	 */
	function get_files( $type, $attachments, $item_id ) { 

		// Get Attachment Data
		$data = $this->get_attachments_files( $item_id, $type, 'data' );

		?>

		<div class="yzw-file-post">
			<i class="fas fa-cloud-download-alt yzw-file-icon"></i>
			<div class="yzw-file-details">
				<div class="yzw-file-title" title="<?php echo $data[0]['real_name']; ?>"><?php echo yz_get_filename_excerpt( $data[0]['real_name'], 45 ); ?></div>
				<div class="yzw-file-size"><?php echo yz_file_format_size( $data[0]['file_size'] ); ?></div>
			</div>
			<a rel="nofollow" href="<?php echo yz_get_media_url( $attachments[0] ); ?>" class="yzw-file-download"><i class="fas fa-download"></i><?php _e( 'download', 'youzer' ); ?></a>
		</div>

		<?php
	}

	/**
	 * Link Post.
	 */
	function get_post_link( $attachments, $activity_id ) {

		// Get Link Data
		$link_url = bp_activity_get_meta( $activity_id, 'yz-link-url' );
		$link_desc = bp_activity_get_meta( $activity_id, 'yz-link-desc' );
		$link_title = bp_activity_get_meta( $activity_id, 'yz-link-title' );

		?>

		<a class="yz-wall-link-content" rel="nofollow" href="<?php echo $link_url; ?>" target="_blank">
			<?php if ( ! empty( $attachments ) && isset( $attachments[0]['original'] ) ) : ?>
				<img src="<?php echo yz_get_media_url( $attachments[0] ); ?>" alt="">
			<?php endif; ?>
			<div class="yz-wall-link-data">
				<div class="yz-wall-link-title"><?php echo $link_title; ?></div>
				<div class="yz-wall-link-desc"><?php echo $link_desc; ?></div>
				<div class="yz-wall-link-url"><?php echo $link_url; ?></div>
			</div>
		</a>

		<?php
	}

	/**
	 * Get Url Preview
	 */
	function get_activity_url_preview( $activity_id, $activity_content = null ) {

		// Get Url Data.
		$url = bp_activity_get_meta( $activity_id, 'url_preview' );

		if ( empty( $url ) ) {
			return;
		}

		// Unserialize data.
		$url = is_serialized( $url ) ? unserialize( $url ) : maybe_unserialize( base64_decode( $url ) );
		
		if ( ! $this->show_url_preview( $url, $activity_content ) ) {
			return;
		}

		?>
 
		<a class="yz-wall-link-content" rel="nofollow" href="<?php echo $url['link']; ?>" target="_blank">
			<?php if ( ! empty( $url['image'] ) && ( empty( $url['use_thumbnail'] ) || $url['use_thumbnail'] == 'off' ) ) : ?><div class="yz-wall-link-thumbnail" style="background-image:url(<?php echo $url['image']; ?>);"></div><?php endif; ?>
			<div class="yz-wall-link-data">
				<?php if ( ! empty( $url['title'] ) ) : ?><div class="yz-wall-link-title"><?php echo $url['title']; ?></div><?php endif; ?>
				<?php if ( ! empty( $url['description'] ) ) : ?><div class="yz-wall-link-desc"><?php echo $url['description']; ?></div><?php endif; ?>
				<?php if ( ! empty( $url['site'] ) ) : ?><div class="yz-wall-link-url"><?php echo $url['site']; ?></div><?php endif; ?>
			</div>
		</a>
		<?php

	}

	/**
	 * Check if we should show Live Url Preview.
	 **/
	function show_url_preview( $data, $activity_content = null ) {

		$show = true;

		// Remove Empty Spaces.
		// $activity_content = trim( $activity_content );
		
		// Get Preview Link.
		$preview_link = ! empty( $data['link'] ) ? $data['link'] : null;

		if ( empty( $data ) || empty( $preview_link ) ) {
			$show = false;
		}
			
		if ( $show == true ) {

			// Get Post Urls.
			preg_match_all( '#\bhttps?://[^,\s()<>]+(?:\([\w\d]+\)|([^,[:punct:]\s]|/))#', $activity_content, $match );

			if ( isset( $match[0] ) && ! empty( $match[0] ) ) {

				foreach ( array_unique( $match[0] ) as $link ) {
					
					if ( strpos( $link, '?s=%23' ) !== false ) {
						continue;								
					}

					if ( wp_oembed_get( $link ) ) {
						$show = false;
						break;
					}

				}
			
			}
		}

		return apply_filters( 'yz_display_activity_live_url_preview', $show );
	}
	/**
	 * Audio Post.
	 */
	function get_audios( $attachments ) {

		?>

		<audio controls>
			<source src="<?php echo yz_get_media_url( $attachments[0] ); ?>" type="audio/mpeg">
			<?php _e( 'Your browser does not support the audio element.', 'youzer' ); ?>
		</audio>

		<?php

	}

	/**
	 * Video Post.
	 */
	function get_videos( $attachments ) {

		$video = $attachments[0];

		if ( ! isset( $video['provider'] ) || $video['provider'] != 'local' ) {
			return;
		}
	
		echo apply_filters( 'yz_get_wall_post_video', '<video width="100%" controls preload="metadata"><source src="' . yz_get_media_url( $attachments[0], true ) . '" type="video/mp4">' . __( 'Your browser does not support the video tag.', 'youzer' ) . '</video>', $attachments );

	}

	/**
	 * Photo Post.
	 */
	function get_images( $attachments, $activity_id ) {

		// Get Attachments number.
		$count_atts = count( $attachments );		

		if ( 1 == $count_atts ) {  ?>
		
		<?php $img_url = yz_get_media_url( $attachments[0] ); ?>
		<a href="<?php echo $img_url; ?>" rel="nofollow" data-lightbox="yz-post-<?php echo $activity_id; ?>"><img src="<?php echo $img_url; ?>" alt="" /></a>
		
		<?php } else { ?>

		<div class="yz-post-<?php echo $count_atts; ?>imgs">

			<?php foreach( $attachments as $i => $attachment ) : ?>
				
				<?php $img_url = yz_get_media_url( $attachment ); ?>
				<a class="yz-post-img" rel="nofollow" href="<?php echo $img_url; ?>" data-lightbox="yz-post-<?php echo $activity_id; ?>">
					<div class="yz-post-img" style="background-image: url(<?php echo $img_url; ?>)"></div>
				</a>

			<?php endforeach; ?>

		</div>

		<?php
		}
	}

    /**
     * Get Attchment files.
     */
    function get_attachments_files( $item_id = null, $type = null , $field = 'src' ) {

        if ( empty( $item_id ) || empty( $type ) ) {
            return;
        }

        global $wpdb, $Yz_media_table;

        // Prepare Sql
        $sql = $wpdb->prepare( "SELECT $field FROM $Yz_media_table WHERE item_id = %d AND component = '%s'", $item_id, $type );

		// Get Result
		$result = $wpdb->get_results( $sql , ARRAY_A );

		if ( empty( $result ) ) {
			return false;
		}

		if ( $field != '*' ) {

			$result = wp_list_pluck( $result, $field );
			
			$atts = array();

			foreach ( $result as $src ) {
				$atts[] = maybe_unserialize( $src );
			}
		
		} else {
			$atts = $result;
		}

		return $atts;

    }

    /**
     * Get File Type.
     */
    function get_file_type( $path ) {

        // Get File Extension.
        $ext = pathinfo( $path, PATHINFO_EXTENSION );

        if ( in_array( $ext, array( 'png', 'jpg', 'jpeg', 'gif' ) ) ) {
            return 'image';
        } else if ( in_array( $ext, array( 'mp4', 'ogg', 'ogv', 'webm', 'flv', 'wmv', 'avi', 'mov' ) ) ) {
            return 'video';
        } else if ( in_array( $ext, array( 'mp3', 'ogg', 'wav' ) ) ) {
            return 'audio';
        } else {
            return 'file';
        }   

    }

}