<?php
/**
 * Reports Table.
 */
if( ! class_exists( 'WP_List_Table' ) ) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class Youzer_Reports_Table extends WP_List_Table {

    public $attachments;
    public $reports_table;
    function __construct(){
        global $status, $page;
    
            parent::__construct( array(
                'singular'  => __( 'report', 'youzer-moderation' ),
                'plural'    => __( 'reports', 'youzer-moderation' ),
                'ajax'      => false, 
    
        ) );

        $this->attachments = new Youzer_Reports_Attachments();
        $this->reports_table = 'yz_reports';
    }

    /**
     * Table Columns
     */
    function get_columns() {
    
        $columns = array(
            'cb'       => '<input type="checkbox" />',
            'reporter' => __( 'Reporter', 'youzer-moderation' ),
            'component'=> __( 'Component', 'youzer-moderation' ),
            'subject'  => __( 'Subject', 'youzer-moderation' ),
            'author'   => __( 'Author', 'youzer-moderation' ),
            'item'     => __( 'Item', 'youzer-moderation' ),
            'reports'  => __( 'Reported', 'youzer-moderation' )
        );


        if ( isset( $_GET['reports-type'] ) && isset( $_GET['author'] ) ) {

            if ( $_GET['reports-type'] == 'reports' ) {
                unset( $columns['reporter'] );
            } else if ( $_GET['reports-type'] == 'reported' ) {
                unset( $columns['author'] );
            }

        }
        
        return $columns;
    
    }

    /**
     * Content column, and "quick admin" rollover actions.
     */
    function column_author( $item ) {

        $user_id = $item['author'];
        $report_id = $item['id'];
        $base_url = bp_get_admin_url( 'admin.php?page=youzer-reports' );
        $nonce = esc_html( '_wpnonce=' . wp_create_nonce( 'yz-moderation-item_' . $item['id'] ) );

        if ( bp_is_user_spammer( $item['author'] ) ) {
            $actions['ham'] = sprintf( '<a href="%s">%s</a>', $base_url . "&amp;rid=$report_id&amp;author=$user_id&amp;action=ham-author", __( 'Not Spammer', 'youzer-moderation' ) );
        } else {
            $actions['spam'] = sprintf( '<a href="%s">%s</a>', $base_url . "&amp;rid=$report_id&amp;author=$user_id&amp;action=spam-author", __( 'Mark as Spammer', 'youzer-moderation' ) );
        }

        // $actions['delete'] = sprintf( '<a href="%s" onclick="%s">%s</a>', $base_url . "&amp;aid=$user_id&amp;action=delete-user&amp;$nonce", "javascript:return confirm('" . esc_js( __( 'Are you sure?', 'youzer-moderation' ) ) . "'); ", __( 'Delete', 'youzer-moderation' , 'youzer-moderation') );

        return $this->get_author( $item['author'] ). $this->row_actions( $actions );
    }

    /**
     * Content column, and "quick admin" rollover actions.
     */
    function column_item( $item ) {

        // Init.
        $status = '';
        $actions = array();
        // $show_restore = false;

        // Get Item ID.
        $item_id = $this->get_item_report_id( $item['id'], $item['item_id'], $item['reports_nbr'] );

        switch ( $item['component'] ) {

            case 'comment':
            case 'activity':
                $delete_action = $item['component'] == 'activity' ? __( 'Delete Activity', 'youzer-moderation' ) : __( 'Delete Comment', 'youzer-moderation' );
                $actions['view'] = sprintf( '<a href="%s">%s</a>', bp_activity_get_permalink( $item['item_id'] ), __( 'View', 'youzer-moderation' ) );
                // $activity = new BP_Activity_Activity( $item['item_id'] );
                // $show_restore = $activity->is_spam;
                break;
            
            case 'user':
                $actions['view'] = sprintf( '<a href="%s">%s</a>', bp_core_get_user_domain( $item['item_id'] ), __( 'View', 'youzer-moderation' ) );
                break; 

            case 'group':
                $delete_action = __( 'Delete Group', 'youzer-moderation' );
                $group = groups_get_group( $item['item_id'] );
                $actions['view'] = sprintf( '<a href="%s">%s</a>', bp_get_group_permalink( $group ), __( 'View', 'youzer-moderation' ) );
                break;

            case 'message':
                $delete_action = __( 'Delete Message', 'youzer-moderation' );
                $message = new BP_Messages_Message( $item['item_id'] );
                $actions['view'] = sprintf( '<a href="%s">%s</a>', bp_get_message_thread_view_link( $message->thread_id ) . '#thread-message-' . $message->id, __( 'View', 'youzer-moderation' ) );
                break;
        }

        // Build actions URLs.
        $base_url = bp_get_admin_url( 'admin.php?page=youzer-reports&amp;rid=' . $item_id );

        // Add Filter Args.
        if ( isset( $_GET['filter'] ) ) {
            $base_url .= '&amp;filter=' . $_GET['filter'];
        }

        $nonce = esc_html( '_wpnonce=' . wp_create_nonce( 'yz-moderation-item_' . $item['id'] ) );

        if ( $item['status'] == 'open' ) {

            if ( $item['is_hidden'] == 1 ) {
                $status = '<div class="yz-item-status-hidden">' . __( 'Hidden', 'youzer-moderation' ) . '</div><br>';
                $actions['restore'] = sprintf( '<a href="%s">%s</a>', $base_url . '&amp;action=restore', __( 'Restore', 'youzer-moderation' ) );
            } else {
                $status = '';
                $actions['close'] = sprintf( '<a href="%s">%s</a>', $base_url . '&amp;action=close', __( 'Close', 'youzer-moderation' ) );
            }
            $delete_and_punish = __( 'Delete & Punish', 'youzer-moderation' );

            if ( $item['component'] != 'user' ) {
                // Delete.
                $actions['delete'] = sprintf( '<a href="%s" onclick="%s">%s</a>', $base_url . "&amp;action=delete&amp;$nonce", "javascript:return confirm('" . esc_js( __( 'Are you sure?', 'youzer-moderation' ) ) . "'); ", $delete_action );
            } else {
                $delete_and_punish = __( 'Punish', 'youzer-moderation' );
            }

            // Delete.
            $actions['delete-with-restrictions'] = sprintf( '<a href="%s" onclick="%s">%s</a>', $base_url . "&amp;action=delete-with-restrictions&amp;$nonce", "javascript:return confirm('" . esc_js( __( 'Are you sure?', 'youzer-moderation' ) ) . "'); ", $delete_and_punish );
        }

        /**
         * Filters available actions for plugins to alter.
         */
        $actions = apply_filters( 'bp_activity_admin_comment_row_actions', array_filter( $actions ), $item );

        /**
         * Filter here to add extra output to the activity content into the Administration.
         */
        echo $status . $this->get_item( $item['item_id'], $item['component'], $item['reports_nbr'] ) . $this->row_actions( $actions );
    }

    /**
     * Colmun Content.
     */
	function column_default( $item, $column_name ) {
		switch( $column_name ) {
			case 'reporter':
				return $this->get_reporters( $item );
            case 'subject':
				return $this->get_subjects( $item );            
			case 'actions':
				return $this->get_actions( $item['item_id'], $item['component'] );
            case 'reports':
                return '<span class="yz-reports-nbr">' . $item['reports_nbr'] . '</span>';
			case 'component':
				return $this->get_report_component( $item[ $column_name ], $item['status'] );
			default:
			    return print_r( $item, true ) ; 
		}
	}

	/**
	 * Get Subject.
	 */
	function get_subjects( $item ) {
    
        // Init Vars.		
        $description = $item['description'];

        $content = '<div class="yzm-subjects">';

        if ( ! empty( $description ) ) {
            $class = ' yzm-clickable';
            $arrow = '<i class="fas fa-chevron-down"></i>';
        } else {
            $class = '';
            $arrow = '';
        }

        $content .= '<span class="yzm-subject' . $class .'">' . $item['category'] . $arrow  . '</span>';

        if ( ! empty( $description ) ) {
            $content .= '<p class="yzm-subject-description">' . stripslashes( $description ) . '</p>';
        }

        if ( $item['reports_nbr'] > 1 ) {
       
            global $wpdb;

            $content .= '<div class="yzm-show-subjects yzm-clickable">' . __( 'Show all subjects', 'youzer-moderation' ) . '</div>';

            // Get Reporters.
            $subjects = $wpdb->get_results( $wpdb->prepare( "SELECT id, category, description FROM " . $wpdb->prefix. $this->reports_table. " WHERE item_id = %d AND status = 'open' ", $item['item_id'] ), ARRAY_A );

            if ( isset( $subjects[0] ) ) {

                $content .= '<div class="yzm-extra-subjects">';

                foreach ( $subjects as $data ) {
                    
                    if ( $data['id'] == $item['id'] ) {
                        continue;
                    }

                    if ( ! empty( $data['description'] ) ) {
                        $r_class = ' yzm-clickable';
                        $r_arrow = '<i class="fas fa-chevron-down"></i>';
                    } else {
                        $r_class = '';
                        $r_arrow = '';
                    }

                    $content .= '<span class="yzm-subject' . $r_class .'">' . $data['category'] . $r_arrow  . '</span>';

                    if ( ! empty( $data['description'] ) ) {
                        $content .= '<p class="yzm-subject-description">' . stripslashes( $data['description'] ) . '</p>';
                    }

                }

                $content .= '</div>';

            }

        }

        $content .= '</div>';
		
        return $content;
	
	}

	/**
	 * Get Item.
	 */
	function get_item( $item_id, $component, $reports_nbr ) {

        $content = '';

		switch ( $component ) {

			case 'activity':
            case 'comment':

				$activity = new BP_Activity_Activity( $item_id );

                if ( $activity->id == 0 ) {
                    return $component == 'activity' ? __( 'Activity Deleted !', 'youzer-moderation' ) : __( 'Comment Deleted !', 'youzer-moderation' )  ;
                }

                if ( ! empty( $activity->content ) ) {
                    add_filter( 'the_content', 'make_clickable' );
                    $content .= '<div class="yz-activity-content">'. apply_filters( 'the_content', stripslashes_deep( $activity->content ) ) . '</div>';
                }

                if ( empty( $content ) ) {
                    $content .= $activity->action;
                }

                // Get Post Attachments.
                if ( class_exists( 'Youzer' ) ) {
                    $content .= $this->attachments->get_attachments( $component, $activity );
                }

				break;

            case 'message':

                $message = new BP_Messages_Message( $item_id );

                if ( empty( $message->id ) ) {
                    return __( 'Message Deleted !', 'youzer-moderation' );
                }

                $content .= apply_filters( 'bp_get_the_thread_message_content', stripslashes_deep( $this->get_excerpt( $message->message ) ) );
                
                // Get Messages Attachments.
                if ( class_exists( 'Youzer' ) ) {
                    $content .= $this->attachments->get_attachments( 'message', $message );
                }

                break;

			case 'user':
                $content .= $this->get_user_item( $item_id );
				break; 
		
            case 'group':
                $content .= $this->get_group_item( $item_id );
                break;

			default:
				break;
		}

        return $content;

	}

	/**
	 * Get Reporters.
	 */
	function get_reporters( $item ) {

        // Init Vars.
        $actions = array();
        $user_id = $item['reporter'];
        $base_url = bp_get_admin_url( 'admin.php?page=youzer-reports&amp;rid=' . $item['id'] );

        if ( $item['reporter'] != 0 ) {
            $email = $ip = '';
            $usernanme = bp_core_get_user_displayname( $user_id );
            $avatar = bp_core_fetch_avatar( array( 'item_id' => $user_id, 'width' => 40, 'height' => 40, 'type' => 'thumb' ) );
            $action = '&amp;action=';
        } else {
            $user_data = maybe_unserialize( $item['data'] );

            if ( isset( $user_data['ip'] ) ) {
                $actions['ip'] = $user_data['ip'];
                $user_id = $user_data['ip'];
            }

            if ( isset( $user_data['email'] ) ) {
                $actions['email'] =  '<a href = "mailto: ' . $user_data['email'] . '">' . $user_data['email'] . '</a>' ;
            }

            // $email = isset( $user_data['email'] ) ? $user_data['email'] : '';
            $usernanme = isset( $user_data['fullname'] ) ? $user_data['fullname'] : __( 'Visitor', 'youzer-moderation' );
            $avatar = '<img style="width: 40px;height: 40px;" src="' . bp_core_avatar_default_thumb( 'local' ) .'" alt="">';
        }

        if ( get_option( 'yz_block_reports_' . $user_id ) ) {
            $actions['unblock'] =  '<a href="' . $base_url . '&amp;action=unblock-reports">' . __( 'Unblock Reports', 'youzer-moderation' ) . '</a>';
        } else {
            $actions['block'] =  '<a href="'. $base_url . '&amp;action=block-reports">' . __( 'Block Reports', 'youzer-moderation' ) . '</a>';
        }

        ob_start();

        ?>

        <div class="yzm-reporters">

            <div class="yzm-reporter">

                <?php echo $avatar; ?>

                <div class="yzm-reporter-data">
                    <a class="yzm-username" href="<?php echo bp_core_get_user_domain( $user_id ); ?>"><?php echo $usernanme; ?></a><?php if ( $item['reports_nbr'] > 1 ) { ?><span class="yzm-show-reporters yzm-clickable" title="<?php _e( 'Show All Reporters', 'youzer-moderation' ); ?>"><i class="fas fa-ellipsis-h"></i></span><?php } ?>
                    <div class="yzm-report-time"><?php echo sprintf( __( '%1$s at %2$s', 'youzer-moderation' ),
                        date_i18n( bp_get_option( 'date_format' ), strtotime( $item['time'] ) ),
                        get_date_from_gmt( $item['time'], bp_get_option( 'time_format' ) )
                    ); ?>
                    </div>
                </div>

            </div>

        <?php

            if ( $item['reports_nbr'] > 1  ) :

                global $wpdb;

                // Get Reporters.
                $reporters = $wpdb->get_results( $wpdb->prepare( "SELECT reporter, time FROM " . $wpdb->prefix. $this->reports_table. " WHERE item_id = %d AND status = 'open'", $item['item_id'] ), ARRAY_A );
                
                if ( isset( $reporters[0] ) ) {

                    $reporters = wp_list_pluck( $reporters, 'time', 'reporter' );

                    // Delete the shown Reporter.
                    if ( isset( $reporters[ $user_id ] ) ) {
                        unset( $reporters[ $user_id ] );
                    }

                    echo '<div class="yzm-extra-reporters">';

                    foreach ( $reporters as $reporter => $report_date ) { ?>

                    <div class="yzm-reporter">

                        <?php echo bp_core_fetch_avatar( array( 'item_id' => $reporter, 'width' => 40, 'height' => 40, 'type' => 'thumb' ) ); ?>
                        <div class="yzm-reporter-data">
                            <a class="yzm-username" href="<?php echo bp_core_get_user_domain( $reporter ); ?>"><?php echo bp_core_get_user_displayname( $reporter ); ?></a>
                            <div class="yzm-report-time"><?php echo sprintf( __( '%1$s at %2$s', 'youzer-moderation' ),
                                        date_i18n( bp_get_option( 'date_format' ), strtotime( $report_date ) ),
                                        get_date_from_gmt( $report_date, bp_get_option( 'time_format' ) )
                                    ); ?>
                            </div>

                        </div>
                     </div>

                    <?php }

                    echo '</div>';

                }

                ?>

        <?php endif; ?>

        </div>

        <?php

        $content = ob_get_contents();

        ob_end_clean();

        return $content . $this->row_actions( $actions );

	}

    /**
     * Get Reporters.
     */
    function get_author( $user_id ) {

        $reports_nbr =1; 
        
        $reports = bp_get_admin_url( 'admin.php?page=youzer-reports&amp;author=' . $user_id );
        
        ob_start();

        ?>

        <div class="yzm-reporters">

            <div class="yzm-reporter">

                <?php echo bp_core_fetch_avatar( array( 'item_id' => $user_id, 'width' => 40, 'height' => 40, 'type' => 'thumb' ) ); ?>

                <div class="yzm-reporter-data">
                    <a class="yzm-username" href="<?php echo bp_core_get_user_domain( $user_id ); ?>"><?php echo bp_core_get_user_displayname( $user_id ); echo $this->user_spammer_status( $user_id ); ?></a><?php if ( $reports_nbr > 1 ) { ?><span class="yzm-show-reporters yzm-clickable"><i class="fas fa-ellipsis-h"></i></span><?php } ?>
                    <div class="yzm-meta"><?php echo sprintf( __( 'Reports <a href="%s">(%d)</a> | Reported <a href="%s">(%d)</a>', 'youzer-moderation' ),$reports . '&reports-type=reports', $this->get_user_reports( $user_id, 'reports' ), $reports . '&reports-type=reported', $this->get_user_reports( $user_id, 'reported' ) ); ?> 

                </div>

            </div>

        </div>

        <?php

        $content = ob_get_contents();

        ob_end_clean();

        return $content;

    }

    /**
     * User total Reports.
     */
    function get_user_reports( $user_id, $type ) {
        
        global $wpdb;

        if ( $type == 'reports' ) {
            $field = 'reporter';
        } else {
            $field = 'author';
        }

        // Get Total Items.
        $total_items = $wpdb->get_var( 'SELECT COUNT(*) FROM ' . $wpdb->prefix . "yz_reports WHERE $field = $user_id" );

        return $total_items;
    }

    /**
     * Get Reporter.
     */
    function get_user( $user_id, $size = 30  ) {

        return '<div class="yzm-user"><a href="' . bp_core_get_user_domain( $user_id ) . '">' . bp_core_fetch_avatar( 
            array(
                'item_id' => $user_id,
                'width' => $size, 
                'height' => $size, 
                'type'    => 'thumb',
            )
        ) . ' <span class="yzm-username">' . bp_core_get_user_displayname( $user_id ) . '</span></a></div>';

    }

    /**
     * Get Reported User.
     */
    function get_user_item( $user_id ) {

        $user = get_userdata( $user_id );

        if ( $user === false ) {
            return __( 'User Deleted !', 'youzer-moderation' );
        } else {
            $member_since = date( 'Y', strtotime( $user->user_registered ) );

            return '<div class="yzm-reported-item">' . bp_core_fetch_avatar( array( 'item_id' => $user_id, 'width' => 40, 'height' => 40, 'type' => 'thumb' ) ) . '<div class="yzm-reported-data"><a class="yzm-name" href="' . bp_core_get_user_domain( $user_id ) . '">' . bp_core_get_user_displayname( $user_id ). $this->user_spammer_status( $user_id ) . '</a><span class="yzm-meta">' . sprintf( __( 'Member Since %1$s', 'youzer-moderation' ), $member_since ) . '</span></div></div>';
        }
    }

    /**
     * Spammer Status.
     */
    function user_spammer_status( $user_id ) {

        if ( bp_is_user_spammer( $user_id ) ) {
            return '<span class="yzm-spammer-status">' .__( 'Spammer', 'youzer-moderation' ) . '</span>';
        }

        return;
    }

    /**
     * Get Reported Group.
     */
    function get_group_item( $group_id ) {
        
        $group = groups_get_group( array( 'group_id' => $group_id ) );

        if ( $group->id == 0 ) {
            return __( 'Group Deleted !', 'youzer-moderation' );
        } else {

            $admins = array();
            $admins_ids = groups_get_group_admins( $group_id );

            foreach ( $admins_ids as $admin ) {
                $admins[] = '<a class="yzm-name" href="' . bp_core_get_user_domain( $admin->user_id ) . '">' . bp_core_get_user_displayname( $admin->user_id ). '</a>';
            }

            if ( 'public' == $group->status ) {
                $type = __( "Public Group", 'youzer-moderation' );
            } elseif ( 'hidden' == $group->status ) {
                $type = __( "Hidden Group", 'youzer-moderation' );
            } elseif ( 'private' == $group->status ) {
                $type = __( "Private Group", 'youzer-moderation' );
            }
            // . ' | '. sprintf( __( 'Managed By %1$s', 'youzer-moderation' ), implode( ', ', $admins ) ) 
            return '<div class="yzm-reported-item">' . bp_core_fetch_avatar( array( 'item_id' => $group_id, 'object' => 'group', 'type' => 'thumb', 'width' => 40, 'height' => 40 ) ) . '<div class="yzm-reported-data"><a class="yzm-name" href="' . bp_get_group_permalink( $group ) . '">' . $group->name . ' </a><span class="yzm-meta">' . $type . '</span></div></div>';
        }
    }

	/**
	 * Get Type
	 */
	function get_report_component( $component, $status ) {

		switch ( $component ) {

			case 'activity':
				$item = '<i class="fas fa-pencil-alt"></i>';
				break;
		
			case 'comment':
				$item = '<i class="far fa-comments"></i>';
				break;
		
			case 'user':
				$item = '<i class="fas fa-user"></i>';
				break;
		
			case 'group':
				$item = '<i class="fas fa-users"></i>';
				break;
		
			case 'message':
				$item = '<i class="far fa-envelope"></i>';
				break;
		
			default:
				return $component;
				break;
		}

        if ( $status != 'open' ) {
            $item .= '<i class="fas fa-lock yzm-closed-report "></i>';
        }

		return "<div class='yzm-item-type yzm-$component-item-type'>$item</div>";

	}

    /** 
     * Prepare Items.
     */
	function prepare_items() {

        global $wpdb;

        // Init Vars.
        $per_page = apply_filters( 'yz_reports_items_per_page', 25 );

        // Configure table headers.
        $this->_column_headers = array( $this->get_columns(), array(), $this->get_sortable_columns() );

        // Process bulk action if any
        $this->process_bulk_action();
        
        // Get Report Type SQL.
        $filter = isset( $_GET['filter'] ) ? $_GET['filter'] : 'all';

        // Get SQL Where Request.
        $where = $this->get_report_component_sql( $filter );

        // Get Total Items.
        $total_items = $wpdb->get_var( 'SELECT COUNT( DISTINCT item_id, component ) FROM ' . $wpdb->prefix . "yz_reports $where" );

        // Pagination Query Params.
        $paged = isset( $_REQUEST['paged'] ) ? max( 0, intval( $_REQUEST['paged'] - 1 ) * $per_page ) : 0;
        $orderby = ( isset( $_REQUEST['orderby'] ) && in_array( $_REQUEST['orderby'], array_keys( $this->get_sortable_columns() ) ) )  ? $_REQUEST['orderby'] : 'id';
        $order = ( isset( $_REQUEST['order'] ) && in_array( $_REQUEST['order'], array( 'asc', 'desc' ) ) ) ? $_REQUEST['order'] : 'desc';


		// Get Report Items.        
        $this->items = $wpdb->get_results($wpdb->prepare("SELECT *, count(id) AS reports_nbr FROM " . $wpdb->prefix. $this->reports_table. " $where GROUP BY item_id, component ORDER BY $orderby $order LIMIT %d OFFSET %d ", $per_page, $paged), ARRAY_A);

        // Set Pagination
        $this->set_pagination_args(array(
            'total_items' => $total_items, // total items defined above
            'per_page' => $per_page, // per page constant defined at top of method
            'total_pages' => ceil($total_items / $per_page) // calculate pages count
        ));
	}

	/**
	 * No items Message !
	 */
	function no_items() {
		_e( 'No reports found !', 'youzer-moderation' );
	}

    /**
     * Get Bulk Actions.
     */
    function get_bulk_actions() {

		$actions = array(
			'bulk_delete-items' => __( 'Delete Items', 'youzer-moderation' ),
            'bulk_restore' => __( 'Restore Items', 'youzer-moderation' ),
            'bulk_close' => __( 'Close Reports', 'youzer-moderation' ),
            'bulk_delete-with-restrictions' => __( 'Delete & Punish', 'youzer-moderation' ),
            'bulk_spam-author' => __( 'Spam Authors', 'youzer-moderation' ),
            'bulk_ham-author' => __( 'Unspam Authors', 'youzer-moderation' ),
		);


        // Delete Close Option From The Closed Options Page.
        if ( isset( $_GET['filter'] ) && $_GET['filter'] == 'closed' ) {
            unset( $actions['bulk_close'] );
        }

    	return $actions;
    
    }

    /**
     * Process Bulk Actions
     */
    function process_bulk_action() {

        // Get Current Action.
        $action = $this->current_action();

        if ( ! empty( $action ) && ! in_array( $action, array( '-1' ) ) ) {

            // Build redirection URL.
            $redirect_to = remove_query_arg( array( 'rid', 'delete', 'restore', 'spam', 'ham', 'close' ), wp_get_referer() );
            $redirect_to = add_query_arg( 'paged', $this->get_pagenum(), $redirect_to );
            
            // Get activity IDs.
            $reports_ids = $this->get_selected_ids( $_REQUEST['rid'] );

            /**
             * Filters list of IDs being spammed/un-spammed/deleted.
             */
            $reports_ids = apply_filters( 'yz_report_admin_action_report_ids', $reports_ids );

            // Is this a bulk request?
            if ( 'bulk_' == substr( $action, 0, 5 ) && ! empty( $_REQUEST['rid'] ) ) {

                // Check this is a valid form submission.
                check_admin_referer( 'bulk-reports' );

                // Trim 'bulk_' off the action name to avoid duplicating a ton of code.
                $action = substr( $action, 5 );

            // This is a request to delete, spam, or un-spam, a single item.
            } elseif ( ! empty( $_REQUEST['rid'] ) ) {
                // Check this is a valid form submission.
                // check_admin_referer( 'spam-activity_' . $reports_ids[0] );
            }

            // Initialise counters for how many of each type of item we perform an action on.
            $items_count =0;

            // Store any errors that occurs when updating the database items.
            $errors = array();

            // "We'd like to shoot the monster, could you move, please?"
            foreach ( $reports_ids as $report_id ) {

                // Get Report Data.
                $report = $this->get_report( $report_id );

                if ( empty( $report ) ) {
                    continue;
                }

                switch ( $action ) {

                    case 'close':

                        if ( $report['is_hidden'] == 0 ) {

                            $this->set_report_status( $report, 'closed' );
                            
                            // Send Email to reporter that his reported item is restored.
                            if ( 'on' == yz_option( 'yz_notify_reporter_on_restored_item', 'on' ) ) {
                                $user_id_email = $this->get_user_id_or_email( $report );
                                if ( $user_id_email ) {
                                    yzm_send_email( $user_id_email, 'yz-reporter-item-restored', $report );
                                }
                            }
                        }

                        break;

                    case 'open':
                        $this->set_report_status( $report, 'open' );
                        break;
                    
                    case 'delete':
                        $this->delete_item( $report );
                        break;

                    case 'delete-with-restrictions':
                        $this->delete_item( $report );
                        yzm_apply_restrictions( $report['author'], $report['component'], 'official' );
                        break;

                    case 'restore':

                        if ( $report['is_hidden'] == 1 ) {

                            $send_message = false;

                            if ( $report['component'] == 'user' ) {
                                if ( bp_is_user_spammer( $report['author'] ) ) {
                                    $this->set_spammer_status( $report['author'] ,'ham', $report );
                                    $send_message = true;
                                }
                            } elseif ( $report['component'] == 'activity' || $report['component'] == 'comment' ) {
                                // Mark Activity & Comments As Not Spam.
                                $this->set_activity_status( $report['item_id'], 'ham', $report );
                            }

                            // Close Report.
                            $this->set_report_status( $report, 'closed' );

                            if ( $send_message ) {

                                // Send Email to user that his item is restored.
                                if ( $action == 'restore' && 'on' == yz_option( 'yz_notify_user_on_restored_item', 'on' ) ) {
                                    yzm_send_email( $report['author'], 'yz-user-item-restored', $report );
                                }

                                // Send Email to reporter that his reported item is restored.
                                if ( 'on' == yz_option( 'yz_notify_reporter_on_restored_item', 'on' ) ) {
                                    $user_id_email = $this->get_user_id_or_email( $report );
                                    if ( $user_id_email ) {
                                        yzm_send_email( $user_id_email, 'yz-reporter-item-restored', $report );
                                    }
                                }

                            }

                        }

                        break;

                    case 'unblock-reports' :
                    case 'block-reports' :

                            if ( $report['reporter'] != 0 ) {

                                $reporter = $report['reporter'];
                                
                                if ( is_super_admin( $reporter ) ) {
                                    break;
                                }

                            } else {
                                $user_data = maybe_unserialize( $report['data'] );
                                if ( isset( $user_data['ip'] ) ) {
                                    $reporter = $user_data['ip'];
                                }
                            }

                            if ( $action == 'block-reports' ) {
                                update_option( 'yz_block_reports_' . $reporter, true );
                            } else if ( $action == 'unblock-reports' ) {
                                delete_option( 'yz_block_reports_' . $reporter );
                            }


                        break;

                    // case 'ham-user' :
                    //         // Mark User As Spammer.
                    //         $this->set_spammer_status( $_REQUEST['author'] ,'ham', $report );
                    //     break;

                    // case 'spam-user' :
                    //         // Mark User As Spammer.
                    //         $this->set_spammer_status( $_REQUEST['author'] ,'spam', $report );
                    //     break;
                        // if (  ) {
                            // die( print_r( $report ) );
                            // Mark User As Spammer.
                        // } elseif ( $report['component'] == 'activity' || $report['component'] == 'comment' ) {
                            // Mark Activity & Comments As Spam.
                            // $this->set_activity_status( $report['item_id'], 'spam', $report );
                        // }
                        
                    case 'spam-author' :

                        $report_args = $report['component'] == 'user' ? $report : '';

                        // Mark Author As Spammer.
                        $this->set_spammer_status( $report['author'], 'spam', $report_args );

                        if ( $report['component'] == 'user' ) {
                            // Close Report.
                            $this->set_report_status( $report, 'closed' );
                        }

                        break;

                    case 'ham-author':
                        $report_args = $report['component'] == 'user' ? $report : '';
                        $this->set_spammer_status( $report['author'] ,'ham', $report_args );
                        break;

                    default:
                        break;
                }

                $items_count++;
            }

            /**
             * Fires before redirect for plugins to do something with activity.
             *
             * Passes an activity array counts how many were spam, not spam, deleted, and IDs that were errors.
             */
            do_action( 'yz_report_admin_action_after', array( $items_count ), $redirect_to, $reports_ids );

            // Add arguments to the redirect URL so that on page reload, we can easily display what we've just done.
            if ( $items_count )
                $redirect_to = add_query_arg( $action, $items_count, $redirect_to );


            if ( isset( $_GET['filter'] ) ) {
                $redirect_to = add_query_arg( 'filter', $_GET['filter'], $redirect_to );
            }

            /**
             * Filters redirect URL after activity spamming/un-spamming/deletion occurs.
             */
            wp_redirect( apply_filters( 'yz_report_admin_action_redirect', $redirect_to ) );
            exit;

        }
    }

    /**
     * Get User ID & Visitor E-mail.
     */
    function get_user_id_or_email( $report ) {

        if ( $report['reporter'] != 0 ) {
            return $report['reporter'];
        } else {
            // Get User Data.
            $user_data = maybe_unserialize( $report['data'] );
            if ( isset( $user_data['email'] ) ) {
                return $user_data['email'];
            } else {
                return false;
            }
        }

    }

    /**
     * Set Spammer Status.
     */
    function set_spammer_status( $user_id, $status, $report = null ) {
        
        // If Is Admin Return.
        if ( is_super_admin( $user_id ) ) {
            return;
        }

        switch ( $status ) {
            case 'spam':
                    bp_core_process_spammer_status( $user_id , 'spam', false );
                break;
                        
            case 'ham':
                if ( bp_is_user_spammer( $user_id ) ) {
                    bp_core_process_spammer_status( $user_id ,'ham', false );
                    if ( ! empty( $report ) ) {
                        $this->send_item_restored_message( $report );
                    }
                } 

                break;
            
            default:
                break;
        }

    }

    /**
     * Send Item Restored Message.
     */
    function send_item_restored_message( $report ) {

        // Send Email to user that his item is restored.
        if ( $this->current_action() == 'restore' && 'on' == yz_option( 'yz_notify_user_on_restored_item', 'on' ) ) {
            yzm_send_email( $report['author'], 'yz-user-item-restored', $report );
        }

            // Send Email to reporter that his reported item is restored.
        if ( 'on' == yz_option( 'yz_notify_reporter_on_restored_item', 'on' ) ) {
            $user_id_email = $this->get_user_id_or_email( $report );
            if ( $user_id_email ) {
                yzm_send_email( $user_id_email, 'yz-reporter-item-restored', $report );
            }
        }

    }

    /**
     * Set Activity As Spam.
     */
    function set_activity_status( $activity_id, $status, $report ) {

        $activity = new BP_Activity_Activity( $activity_id );

        if ( empty( $activity->component ) ) {
            return;
        }
        
        if ( $status == 'spam' ) {
            bp_activity_mark_as_spam( $activity );
        } else {

            /**
             * Remove moderation and blacklist checks in case we want to ham an activity
             * which contains one of these listed keys.
             */
            remove_action( 'bp_activity_before_save', 'bp_activity_check_moderation_keys', 2 );
            remove_action( 'bp_activity_before_save', 'bp_activity_check_blacklist_keys', 2 );
            
            if ( $activity->is_spam ) {
                $this->send_item_restored_message( $report );
            }

            bp_activity_mark_as_ham( $activity );

        }

        $result = $activity->save();

        // Release memory.
        unset( $activity );
    }

    /**
     * Get Report ids.
     */
    function get_selected_ids( $selected_ids ) {

        $reports_ids = array();

        if ( is_array( $selected_ids  ) ) {
            foreach ($selected_ids as $id ) {
                if ( strpos( $id, ',' ) !== false ) {
                    $multi_ids = explode( ',', $id );
                    foreach ( $multi_ids as $multi_id ) {
                        $reports_ids[] = $multi_id;
                    } 
                } else {
                    $reports_ids[] = $id;
                }
            }
        } else {
            if ( strpos( $selected_ids, ',' ) !== false ) {
                $multi_ids = explode( ',', $selected_ids );
                foreach ( $multi_ids as $multi_id ) {
                    $reports_ids[] = $multi_id;
                } 
            } else {
                $reports_ids[] = $selected_ids;
            }
        }

        return $reports_ids;
    }

    /**
     * Close Report !
     */
    function set_report_status( $item, $status ) {

        global $wpdb;

        // Mark Ticket As Closed.
        $wpdb->update( $wpdb->prefix . 'yz_reports', array( 'status' => $status ), array( 'id' => $item['id'] ), array(
        '%s', ), array( '%d' ) );

        // Clear Reported Elements
        if ( $status != 'open' ) {
            yzm_clear_reported_elements( $item['item_id'], $item['component'] );
        }

        // Add User Restriction.
        $query = new YZM_Query();

        // Delete Temporary Restriction.
        $query->end_restriction( $item['author'], $item['component'], 'temporary' );

    }

    /**
     * Clear Reported Elements !
     */
    function delete_item( $data ) {

        switch ( $data['component'] ) {

            case 'activity':

                if ( bp_is_active( 'activity' ) ) {
                    $activity = new BP_Activity_Activity( $data['item_id'] );
                    bp_activity_delete( array( 'id' => $activity->id ) );
                }

                break;          

            case 'comment':
                if ( bp_is_active( 'activity' ) ) {
                    $activity = new BP_Activity_Activity( $data['item_id'] );
                    bp_activity_delete_comment( $activity->item_id, $activity->id );
                }
                break;

            // case 'user':

            //     bp_core_delete_account( $data['item_id'] );

            //     break;

            case 'group':
                
                if ( bp_is_active( 'groups' ) ) {
                    groups_delete_group( $data['item_id'] );
                }

                break;

            case 'message':

                if ( bp_is_active( 'messages' ) ) {
                    $this->delete_message( $data['item_id'] );
                }

                break;
    
        }

        // Close Reported Items.
        $this->set_report_status( $data, 'deleted' );

        // Clear Reported Items.
        yzm_clear_reported_elements( $data['item_id'], $data['component'] );

        // Send Email to user that his item is restored.
        if ( 'on' == yz_option( 'yz_notify_user_on_deleted_item', 'on' ) ) {
            yzm_send_email( $data['author'], 'yz-user-item-deleted', $data );
        }

        // Send Email to reported that his reported item is restored.
        if ( 'on' == yz_option( 'yz_notify_reporter_on_deleted_item', 'on' ) ) {
            $user_id_email = $this->get_user_id_or_email( $data );
            if ( $user_id_email ) {
                yzm_send_email( $user_id_email, 'yz-reporter-item-deleted', $data );
            }
        }

    }

    /**
     * Delete Message !
     */
    function delete_message( $message_id ) {
        
        global $wpdb;

        $bp = buddypress();

        $wpdb->delete( $bp->messages->table_name_messages, array( 'id' => $message_id ), array( '%d' ) );
    }

    /**
     * Get Report Data !
     */
    function get_report( $report_id ) {
        
        global $wpdb;

        $report = $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}yz_reports WHERE id = $report_id", ARRAY_A );

        return $report;

    }

    /**
     * CheckBox Field.
     */
    function column_cb( $item ) {

        $checkbox = sprintf('<input class="yzm-report-id-checkbox" type="checkbox" name="rid[]" value="%s" />', $this->get_item_report_id( $item['id'], $item['item_id'], $item['reports_nbr'] ) );

        return $checkbox;

    }

    /**
     * Get Item Report Id.
     */
    function get_item_report_id( $report_id, $item_id, $reports_number ) {

        if ( $reports_number > 1 ) {
            $report_id = $this->get_report_ids( $item_id, true );
        } else {
            $report_id = $report_id;
        }

        return $report_id;
    }

    /**
     * Get Report Ids.
     */
    function get_report_ids( $item_id, $separator = null ) {
        
        global $wpdb;

        // Get Reporters.
        $reports_ids = $wpdb->get_results( $wpdb->prepare( "SELECT id FROM " . $wpdb->prefix. $this->reports_table. " WHERE item_id = %d and status = 'open'", $item_id ), ARRAY_A );

        if ( $separator ) {
            $reports_ids = implode( ',', wp_list_pluck( $reports_ids, 'id' ) );
        }

        return $reports_ids;
    }

    /**
     * Get Excerpt.
     */
    function get_excerpt( $content ) {
        
        $limit = apply_filters( 'yzm_excerpt_limit', 15 );

        $arr_exploded = explode( ' ', wp_strip_all_tags( $content ) );

        $part1 = array_slice( $arr_exploded, 0, $limit );
        $part2 = array_slice( $arr_exploded, $limit );

        $excerpt = implode( ' ', $part1 );

        if ( ! empty( $part2 ) ) {
        $excerpt .= '<span class="yzm-more-area">... <span class="yzm-read-more yzm-clickable">' . __( 'Read More', 'youzer-moderation' ) . '</span></span><span class="yzm-more"> '. implode( ' ', $part2 ) . ' <span class="yzm-show-less yzm-clickable">' . __( 'Show Less', 'youzer-moderation' ) . '</span></span>';
        }

        return apply_filters( 'yzm_get_excerpt', $excerpt, $content, $limit );
    }

    /**
     * Get Count.
     */
    function get_reports_count( $component ) {

        global $wpdb;

        $sql = "SELECT COUNT( DISTINCT item_id, component ) FROM " . $wpdb->prefix . $this->reports_table;

        // Get Report Type SQL.
        $component_sql = $this->get_report_component_sql( $component );

        if ( ! empty( $component_sql ) ) {
            $sql.= $component_sql;
        }

        return $wpdb->get_var( $sql );
    }

    /**
     * Get Report Type SQL
     */
    function get_report_component_sql( $component ) {

        $sql = '';
        switch ( $component ) {
            case 'all':
            case 'users-reports':
                $sql = ' WHERE status = "open"';
                break;
            case 'activity':
            case 'comment':
            case 'message':
            case 'group':
            case 'user':
                $sql = ' WHERE component = "' . $component . '" AND status = "open"';
                break;

            case 'closed':
                $sql = ' WHERE status NOT IN( "open" )';
                break;
            
            default:
                $sql = ' WHERE status = "open"';
                break;
        }

        if ( $component != 'users-reports' ) {

            if ( isset( $_GET['reports-type'] ) && isset( $_GET['author'] ) ) {
                if ( $_GET['reports-type'] == 'reports' ) {
                    $sql .= ' AND reporter = ' . $_GET['author'];
                } else if ( $_GET['reports-type'] == 'reported' ) {
                    $sql .= ' AND author = ' . $_GET['author'];
                }
            }

        }
        
        // Init Var.        
        $unsuported = false;
        $components = array( 'activity' => bp_is_active( 'activity' ), 'comment' => bp_is_active( 'activity' ), 'message' => bp_is_active( 'messages' ), 'group' => bp_is_active( 'groups' ) );

        foreach ( $components as $component => $visibility ) {
            if ( $visibility != 1 ) {
                $unsuported[] =  $component;
           }
        }

        if ( ! empty( $unsuported ) ) {
            $sql .= ' AND component NOT IN ("' . implode( '","', $unsuported ) . '")';
        }

        return $sql;
    }

    /**
     * Get Views
     */
    protected function get_views() { 
        
        $views = array();
        $current = ! empty( $_REQUEST['filter'] ) ? $_REQUEST['filter'] : 'all';
        
        $base_url = bp_get_admin_url( 'admin.php?page=youzer-reports' );

       // All link
       $class = $current == 'all' ? ' class="current"' :'';
       
       $all_url = remove_query_arg( 'filter', 'close', 'delete', 'spam', 'ham', 'restore' );

       $views['all'] = "<a href='" . $base_url . "' {$class} >" . sprintf( __( 'All (%d)', 'youzer-moderation' ), $this->get_reports_count( 'all' ) ) . "</a>";
    
        if ( bp_is_active( 'activity' ) ) {

           // Activities
           $class = $current == 'activity' ? ' class="current"' : '';
           $views['activity'] = "<a href='" . add_query_arg( 'filter', 'activity', $base_url ) . "' {$class} >" . sprintf( __( 'Activities (%d)', 'youzer-moderation' ), $this->get_reports_count( 'activity' ) ) . "</a>";
     
           // Comments
           $class = $current == 'comment' ? ' class="current"' : '';
           $views['comment'] = "<a href='" . add_query_arg( 'filter', 'comment', $base_url ) . "' {$class} >" . sprintf( __( 'Comments (%d)', 'youzer-moderation' ), $this->get_reports_count( 'comment' ) ) . "</a>";

        }
        
        // Messages
        if ( bp_is_active( 'messages' ) ) {
           $class = $current == 'message' ? ' class="current"' : '';
           $views['message'] = "<a href='" . add_query_arg( 'filter', 'message', $base_url ) . "' {$class} >" . sprintf( __( 'Messages (%d)', 'youzer-moderation' ), $this->get_reports_count( 'message' ) ) . "</a>";
        }

        // Users
        if ( 'on' == yz_option( 'yz_enable_user_reports', 'on' ) ) {
            $class = $current == 'user' ? ' class="current"' : '';
            $views['user'] = "<a href='" . add_query_arg( 'filter', 'user', $base_url ) . "' {$class} >" . sprintf( __( 'Users (%d)', 'youzer-moderation' ), $this->get_reports_count( 'user' ) ) . "</a>";
        }
   
        // Groups
        if ( bp_is_active( 'groups' ) ) {
           $class = $current == 'group' ? ' class="current"' : '';
           $views['group'] = "<a href='" . add_query_arg( 'filter', 'group', $base_url ) . "' {$class} >" . sprintf( __( 'Groups (%d)', 'youzer-moderation' ), $this->get_reports_count( 'group' ) ) . "</a>";
        }

        // Closed
        $class = $current == 'closed' ? ' class="current"' : '';
        $views['closed'] = "<a href='" . add_query_arg( 'filter', 'closed', $base_url ) . "' {$class} >" . sprintf( __( 'Closed (%d)', 'youzer-moderation' ), $this->get_reports_count( 'closed' ) ) . "</a>";

        if ( yzm_is_single_user_reports() ) {
        $views['user-reports'] = '<a href=' . $base_url . '>' . sprintf( __( 'Users Reports (%d)', 'youzer-moderation' ), $this->get_reports_count( 'users-reports' ) ) . '</a>';

        }

        return $views;
    
    }

}