<?php
/*
   Espace Guichet Functions
*/

if( ! class_exists( 'WP_List_Table' ) ) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class Youzer_Restrictions_Table extends WP_List_Table {

    public $restrictions_table;

    function __construct(){

        global $status, $page;
    
            parent::__construct( array(
                'singular'  => __( 'restriction', 'youzer-moderation' ),
                'plural'    => __( 'restrictions', 'youzer-moderation' ),
                'ajax'      => false, 
    
        ) );

        $this->restrictions_table = 'yz_mod_restrictions';
    }

    /**
     * Table Columns
     */
    function get_columns() {
    
        $columns = array(
            'cb'       => '<input type="checkbox" />',
            'user_id' => __( 'User', 'youzer-moderation' ),
            'type'     => __( 'Type', 'youzer-moderation' ),
            'time'   => __( 'Time', 'youzer-moderation' ),
            'component'   => __( 'Component', 'youzer-moderation' ),
            'restrictions'  => __( 'Restrictions', 'youzer-moderation' ),
            'status'     => __( 'Status', 'youzer-moderation' ),
        );

        return $columns;

    }

    /**
     * Colmun Content.
     */
	function column_default( $item, $column_name ) {

		switch( $column_name ) {
			case 'user_id':
				return $this->get_user( $item );
            case 'type':
            case 'status':
                
                if ( $item[ $column_name ] == 'temporary' ) {
                    $value = __( 'Threshold', 'youzer-moderation' );
                } else {
                    $value = $item[ $column_name ];
                }

				return '<span class="yzm-restriction-status yzm-restriction-' . $item[ $column_name ] .  '">' . $value . '</span>';       

            case 'component':
                return $this->get_component( $item['component'] );     
			case 'restrictions':
                $items = '';
                $restrictions = maybe_unserialize( $item[ $column_name ] );
                foreach ( $restrictions as $restriction ) {
                    $items .= '<div class="yzm-restriction-item">' . $restriction . '</div>';
                }

                if ( $item['status'] == 'active' ) {
                    $items .= $this->row_actions( array( 'end' => '<a href="' . bp_get_admin_url( 'admin.php?page=youzer-users-restrictions&amp;rid=' . $item['id'] ) . '&amp;action=end-restrictions">' . __( 'End Restrictions', 'youzer-moderation' ) . '</a>' ) );
                }
				return $items;
            case 'time':
                if ( $item['type'] == 'official' ) {

                    // Get Restictions Period.
                    $restriction_period = yz_option( 'yz_rgr_' . $item['component'] . '_period', 60 );
                    $time = strtotime( $item[ $column_name ] );
                    $started = date( 'Y-m-d', $time );
                    $ends = $restriction_period >= 1 ? date( 'Y-m-d', strtotime( "+$restriction_period day", $time ) ): __( 'Never', 'youzer-moderation' );
                    $time = sprintf( __( '<span class="yzm-starts">Started</span> %1s <br> <span class="yzm-ends">Ends</span> %2s', 'youzer-moderation' ), $started, $ends );

                } else {
                    $time = '<span class="yzm-temporary-time">' . __( 'Temporary', 'youzer-moderation' ) . '</span>';
                }
                return $time;
			default:
			    return print_r( $item, true ) ; 
		}
	}

    /**
     * Get Type
     */
    function get_component( $type ) {

        switch ( $type ) {

            case 'activity':
                $item = '<i class="fas fa-pencil-alt"></i>';
                break;
        
            case 'comment':
                $item = '<i class="far fa-comments"></i>';
                break;
        
            case 'user':
                $item = '<i class="fas fa-user"></i>';
                break;
        
            case 'group':
                $item = '<i class="fas fa-users"></i>';
                break;
        
            case 'message':
                $item = '<i class="far fa-envelope"></i>';
                break;
        
            default:
                return $type;
                break;
        }

        return "<div class='yzm-item-type yzm-$type-item-type'>$item</div>";

    }

	/**
	 * Get Reporters.
	 */
	function get_user( $item ) {

        // Init Vars.
        $user = get_userdata( $item['user_id'] );

        ob_start();

        if ( $user === false ) {
            echo __( 'User Deleted !', 'youzer-moderation' );
        } else { ?>

        <div class="yzm-reporters">

            <div class="yzm-reporter">

                <?php echo bp_core_fetch_avatar( array( 'item_id' => $item['user_id'], 'width' => 40, 'height' => 40, 'type' => 'thumb' ) ); ?>

                <div class="yzm-reporter-data">
                    <a class="yzm-username" href="<?php echo bp_core_get_user_domain( $item['user_id'] ); ?>"><?php echo bp_core_get_user_displayname( $item['user_id'] ); ?></a>
                    <div class="yzm-report-time"><?php echo sprintf( __( 'Member Since %1s | Restrictions <a href="%2s">(%d)</a>', 'youzer-moderation' ), date( 'Y', strtotime( $user->user_registered ) ), bp_get_admin_url( 'admin.php?page=youzer-users-restrictions&amp;user_id=' . $item['user_id'] ), $this->get_user_restrictions( $item['user_id'] ) ); ?></div>
                </div>

            </div>

        </div>

        <?php

        }

        $content = ob_get_contents();

        ob_end_clean();

        return $content;

	}
   
    /**
     * User total Reports.
     */
    function get_user_restrictions( $user_id ) {
        
        global $wpdb;

        // Get Total Items.
        $total_items = $wpdb->get_var( 'SELECT COUNT(*) FROM ' . $wpdb->prefix . $this->restrictions_table . " WHERE user_id = $user_id" );

        return $total_items;
    }

    /**
     * Get Reported User.
     */
    function get_user_item( $user_id ) {

        $user = get_userdata( $user_id );

        if ( $user === false ) {
            return __( 'User Deleted !', 'youzer-moderation' );
        } else {
            $member_since = date( 'Y', strtotime( $user->user_registered ) );

            return '<div class="yzm-reported-item">' . bp_core_fetch_avatar( array( 'item_id' => $user_id, 'width' => 40, 'height' => 40, 'type' => 'thumb' ) ) . '<div class="yzm-reported-data"><a class="yzm-name" href="' . bp_core_get_user_domain( $user_id ) . '">' . bp_core_get_user_displayname( $user_id ). $this->user_spammer_status( $user_id ) . '</a><span class="yzm-meta">' . sprintf( __( 'Member Since %1$s', 'youzer-moderation' ), $member_since ) . '</span></div></div>';
        }

    }

    /**
     * Spammer Status.
     */
    function user_spammer_status( $user_id ) {

        if ( bp_is_user_spammer( $user_id ) ) {
            return '<span class="yzm-spammer-status">' .__( 'Spammer', 'youzer-moderation' ) . '</span>';
        }

        return;
    }

    /** 
     * Prepare Items.
     */
	function prepare_items() {

        global $wpdb;

        // Init Vars.
        $per_page = apply_filters( 'yz_restructions_items_per_page', 25 );

        // Configure table headers.
        $this->_column_headers = array( $this->get_columns(), array(), $this->get_sortable_columns() );

        // Process bulk action if any
        $this->process_bulk_action();
        
        // Get Report Type SQL.
        $filter = isset( $_GET['filter'] ) ? $_GET['filter'] : 'all';

        // Get SQL Where Request.
        $where = $this->get_sql_filter( $filter );

        // Get Total Items.
        $total_items = $wpdb->get_var( 'SELECT count(*) FROM ' . $wpdb->prefix . $this->restrictions_table . " $where" );

        // Pagination Query Params.
        $paged = isset( $_REQUEST['paged'] ) ? max( 0, intval( $_REQUEST['paged'] - 1 ) * $per_page ) : 0;
        $orderby = ( isset( $_REQUEST['orderby'] ) && in_array( $_REQUEST['orderby'], array_keys( $this->get_sortable_columns() ) ) )  ? $_REQUEST['orderby'] : 'id';

        $order = ( isset( $_REQUEST['order'] ) && in_array( $_REQUEST['order'], array( 'asc', 'desc' ) ) ) ? $_REQUEST['order'] : 'desc';

		// Get Report Items.
        $this->items = $wpdb->get_results($wpdb->prepare("SELECT * FROM " . $wpdb->prefix . $this->restrictions_table . " $where ORDER BY $orderby $order LIMIT %d OFFSET %d ", $per_page, $paged), ARRAY_A);

        // Set Pagination
        $this->set_pagination_args( array( 'total_items' => $total_items, 'per_page' => $per_page, 'total_pages' => ceil( $total_items / $per_page ) ) );

	}

	/**
	 * No items Message !
	 */
	function no_items() {
		_e( 'No restrictions found !', 'youzer-moderation' );
	}

    /**
     * Get Bulk Actions.
     */
    function get_bulk_actions() {

		$actions = array(
			'end-restrictions' => __( 'End Restrictions', 'youzer-moderation' ),
		);

        if ( isset( $_GET['filter'] ) && $_GET['filter'] == 'ended' ) {
            unset( $actions['end-restrictions'] );
        }

    	return $actions;
    
    }

    /**
     * Process Bulk Actions
     */
    function process_bulk_action() {


        if ( 'end-restrictions' ===  $this->current_action() ) {

            global $yz_restrictions_table;
            // Build redirection URL.
            $redirect_to = remove_query_arg( array( 'rid', 'end-restrictions' ), wp_get_referer() );
            $redirect_to = add_query_arg( 'paged', $yz_restrictions_table->get_pagenum(), $redirect_to );
            
            $ids = isset( $_REQUEST['rid'] ) ? $_REQUEST['rid'] : array();
             
            if ( ! empty( $ids ) ) {
                $items_count = 0;
                $restriction_ids = is_array( $ids ) ? $ids : array( $ids );

                // Init Class.
                $query = new YZM_Query();
                
                foreach ( $restriction_ids as $restriction_id ) {
                    // Get Restriction Data.
                    $restriction = $query->get_restriction( $restriction_id );
                    $query->end_restriction( $restriction['user_id'], $restriction['component'], $restriction['type'] );
                    $items_count++;
                }

            }

            // Add arguments to the redirect URL so that on page reload, we can easily display what we've just done.
            if ( $items_count )
                $redirect_to = add_query_arg( 'end-restrictions', $items_count, $redirect_to );

            if ( isset( $_GET['filter'] ) ) {
                $redirect_to = add_query_arg( 'filter', $_GET['filter'], $redirect_to );
            }

            /**
             * Filters redirect URL after activity spamming/un-spamming/deletion occurs.
             */
            wp_redirect( apply_filters( 'yz_restrictions_admin_action_redirect', $redirect_to ) );
            exit;
        }


    }

    /**
     * CheckBox Field.
     */
    function column_cb( $item ) {
        return sprintf( '<input type="checkbox" name="rid[]" value="%s" />', $item['id'] );
    }

    /**
     * Get Report Type SQL
     */
    function get_sql_filter( $type ) {

        $sql = '';
        switch ( $type ) {
            case 'all':
            case 'users-restrictions':
                $sql = ' WHERE status = "active"';
                break;
            case 'activity':
            case 'comment':
            case 'message':
            case 'group':
            case 'user':
                $sql = ' WHERE component = "' . $type . '" AND status = "active"';
                break;

            case 'ended':
                $sql = ' WHERE status = "ended"';
                break;
            
            default:
                break;
        }

        if ( isset( $_GET['user_id'] ) ) {
            $sql .= ' AND user_id = ' . $_GET['user_id'];
        }
        
        // Init Var.        
        $unsuported = false;
        $components = array( 'activity' => bp_is_active( 'activity' ), 'comment' => bp_is_active( 'activity' ), 'message' => bp_is_active( 'messages' ), 'group' => bp_is_active( 'groups' ) );

        foreach ( $components as $component => $visibility ) {
            if ( $visibility != 1 ) {
                $unsuported[] = $component;
           }
        }

        if ( ! empty( $unsuported ) ) {
            $sql .= ' AND component NOT IN ("' . implode( '","', $unsuported ) . '")';
        }

        return $sql;
    }

    /**
     * Get Views
     */
    protected function get_views() { 
        
        $views = array();
        $current = ! empty( $_REQUEST['filter'] ) ? $_REQUEST['filter'] : 'all';
        
        $base_url = bp_get_admin_url( 'admin.php?page=youzer-users-restrictions' );

       // All link
       $class = $current == 'all' ? ' class="current"' :'';
       
       $all_url = remove_query_arg( 'filter', 'close', 'delete', 'spam', 'ham', 'restore' );

       $views['all'] = "<a href='" . $base_url . "' {$class} >" . sprintf( __( 'All (%d)', 'youzer-moderation' ), $this->get_items_count( 'all' ) ) . "</a>";
    
        if ( bp_is_active( 'activity' ) ) {

           // Activities
           $class = $current == 'activity' ? ' class="current"' : '';
           $views['activity'] = "<a href='" . add_query_arg( 'filter', 'activity', $base_url ) . "' {$class} >" . sprintf( __( 'Activities (%d)', 'youzer-moderation' ), $this->get_items_count( 'activity' ) ) . "</a>";
     
           // Comments
           $class = $current == 'comment' ? ' class="current"' : '';
           $views['comment'] = "<a href='" . add_query_arg( 'filter', 'comment', $base_url ) . "' {$class} >" . sprintf( __( 'Comments (%d)', 'youzer-moderation' ), $this->get_items_count( 'comment' ) ) . "</a>";

        }
        
        // Messages
        if ( bp_is_active( 'messages' ) ) {
           $class = $current == 'message' ? ' class="current"' : '';
           $views['message'] = "<a href='" . add_query_arg( 'filter', 'message', $base_url ) . "' {$class} >" . sprintf( __( 'Messages (%d)', 'youzer-moderation' ), $this->get_items_count( 'message' ) ) . "</a>";
        }

        // Users
        if ( 'on' == yz_option( 'yz_enable_user_reports', 'on' ) ) {
            $class = $current == 'user' ? ' class="current"' : '';
            $views['user'] = "<a href='" . add_query_arg( 'filter', 'user', $base_url ) . "' {$class} >" . sprintf( __( 'Users (%d)', 'youzer-moderation' ), $this->get_items_count( 'user' ) ) . "</a>";
        }
   
        // Groups
        if ( bp_is_active( 'groups' ) ) {
           $class = $current == 'group' ? ' class="current"' : '';
           $views['group'] = "<a href='" . add_query_arg( 'filter', 'group', $base_url ) . "' {$class} >" . sprintf( __( 'Groups (%d)', 'youzer-moderation' ), $this->get_items_count( 'group' ) ) . "</a>";
        }

        // Ended
        $class = $current == 'ended' ? ' class="current"' : '';
        $views['ended'] = "<a href='" . add_query_arg( 'filter', 'ended', $base_url ) . "' {$class} >" . sprintf( __( 'Ended (%d)', 'youzer-moderation' ), $this->get_items_count( 'ended' ) ) . "</a>";

        if ( isset( $_GET['user_id'] ) ) {
        $views['user-reports'] = '<a href=' . $base_url . '>' . sprintf( __( 'Users Restrictions (%d)', 'youzer-moderation' ), $this->get_items_count( 'users-restrictions' ) ) . '</a>';

        }

        return $views;
    
    }

    /**
     * Get Count.
     */
    function get_items_count( $type ) {

        global $wpdb;

        $sql = "SELECT COUNT(*) FROM " . $wpdb->prefix . $this->restrictions_table;

        // Get Report Type SQL.
        $type_sql = $this->get_sql_filter( $type );

        if ( ! empty( $type_sql ) ) {
            $sql.= $type_sql;
        }

        return $wpdb->get_var( $sql );
    }

}