<?php
/**
 * Moderation Form
 */
class YZBM_Form {
	
	function __construct( ) {

		// Ajax
		add_action( 'wp_ajax_nopriv_yz_handle_user_reports', array( &$this, 'handle_user_reports' ) );
		add_action( 'wp_ajax_yz_handle_user_reports', array( &$this, 'handle_user_reports' ) );
				
		add_action( 'wp_ajax_yz_get_user_report_form', array( &$this, 'get_user_report_form' ) );
		add_action( 'wp_ajax_nopriv_yz_get_user_report_form', array( &$this, 'get_user_report_form' ) );

		// Save User Reports.
		add_action( 'yzm_after_adding_user_report', array( &$this, 'save_user_reports' ), 10, 2 );

		// Add Reports Buttons.
		add_action( 'init', array( &$this, 'add_activity_report_buttons' ) );
		add_action( 'bp_before_activity_loop', array( &$this, 'add_activity_comment_report_buttons' ) );
		add_action( 'bp_before_single_activity_post', array( &$this, 'add_activity_comment_report_buttons' ) );
		add_action( 'bp_before_message_thread_content', array( &$this, 'add_messages_report_button' ) );
		add_action( 'bp_before_members_loop', array( &$this, 'add_members_report_button' ) );
		add_action( 'youzer_profile_before_profile', array( &$this, 'add_members_report_button' ) );
		add_action( 'bp_before_groups_loop', array( &$this, 'add_groups_report_button' ) );
		add_action( 'youzer_group_before_group', array( &$this, 'add_groups_report_button' ) );
	}

	/**
	 * Add activity Report button.
	 */
	function add_activity_report_buttons() {
	    
	    if ( wp_doing_ajax() ) {

		    if ( yzm_show_report_button_component( 'activity' ) ) {
				add_filter( 'yz_activity_tools', array( &$this, 'activity_report_button' ), 99, 2 );
			}

			$this->add_activity_comment_report_buttons();

	    }
		
	}

	/**
     * Add Activity Comment Report Button.
     */
	function add_activity_comment_report_buttons() {

		if ( ! is_user_logged_in() && yzm_show_report_button_component( 'activity' ) ) {
			add_action( 'bp_activity_entry_meta_non_logged_in', array( &$this, 'visitors_report_button' ) );
			add_action( 'bp_before_activity_entry_header', array( &$this, 'visitors_report_button' ) );
		}

	    if ( yzm_show_report_button_component( 'comment' ) ) {
			add_action( 'yz_activity_comment_before_time_meta', array( &$this, 'activity_comment_report_tool' ), 15);
		}

	}

	/**
	 * Add Visitors Report Button
	 */
	function visitors_report_button() { ?>
	    <a class="yz-report-activity" data-loaded="false"><i class="far fa-flag"></i><span class="yz-report-activity-title"><?php _e( 'Report', 'youzer-moderation' ); ?></span></a><?php
	}

	/**
	 * Add Messages Report Button
	 */
	function add_messages_report_button() {

		if ( yzm_show_report_button_component( 'message' ) ) {
			add_action( 'bp_after_message_meta', array( &$this, 'message_report_tool' ) );
		}

	}

	/**
	 * Add Members Report Button
	 */
	function add_members_report_button() {

		if ( yzm_show_report_button_component( 'user' ) ) {
			add_action( 'yz_user_tools', array( &$this, 'user_report_button' ), 10, 2 );
		}

	}

	/**
	 * Add Groups Report Button
	 */
	function add_groups_report_button() {

		if ( yzm_show_report_button_component( 'group' ) ) {
			add_action( 'yz_group_tools', array( &$this, 'add_group_report_tool' ), 10, 2 );
		}

	}

	/**
	 * Add Group Report Button
	 */
	function add_group_report_tool( $group_id = null, $icons = null ) {

		if ( bp_loggedin_user_id() == bp_get_group_creator_id() || is_super_admin( bp_get_group_creator_id() ) ) {
			return;
		}

	    // Get Button Title.
	    $button_title = __( 'Report Group', 'youzer-moderation' );
	    
	    ?>

	    <div class="yz-tool-btn yz-report-btn" <?php if ( 'only-icons' == $icons ) { ?> data-yztooltip="<?php echo $button_title; ?>"<?php } ?>>
	        <div class="yz-tool-icon"><i class="fas far fa-flag"></i></div><?php if ( 'full-btns' == $icons ) : ?><div class="yz-tool-name"><?php echo $button_title; ?></div><?php endif; ?>
	    </div>

	    <?php
	}

	/**
	 * Add Activity Report Tool.
	 **/
	function activity_report_button( $tools, $post_id ) {
		
		$activity = new BP_Activity_Activity( $post_id );

		if ( bp_loggedin_user_id() == $activity->user_id || is_super_admin( $activity->user_id ) ) {
			return $tools;
		}

		unset( $activity );

		// Get Tool Data.
		$tools[] = array(
			'icon' => 'fas fa-flag',
			'title' => __( 'Report', 'youzer-moderation' ),
			'action' => 'yz-report-activity',
			'class' => array( 'yz-report-tool' ),
			'attributes' => array( 'item-type' => 'activity' )
		);


		return $tools;
	}

	/**
	 * Handle Posts Bookmark
	 */
	function handle_user_reports() {

		// Hook.
		do_action( 'yz_before_adding_user_report' );

		// Check Ajax Referer.
		check_ajax_referer( 'youzer-nonce', 'security' );

		$query = new YZM_Query();

		$action = isset( $_POST['operation'] ) ? $_POST['operation'] : null;
		
		// Get Table Data.
		$data = array(
			'status' => 'open',
			'component'	=> isset( $_POST['component'] ) ? $_POST['component'] : null,
			'reporter'  => is_user_logged_in() ? bp_loggedin_user_id() : 0,
			'category'  => isset( $_POST['category'] ) ? $_POST['category'] : null,
			'item_id'   => isset( $_POST['item_id'] ) ? $_POST['item_id'] : null,
			'description' => isset( $_POST['description'] ) ? $_POST['description'] : null
		);

		// Get User IP.

		if ( $data['reporter'] != 0 ) {
			$reporter = $data['reporter'];
		} else {
			$user_ip = $this->get_visitor_ip();
            $reporter = $user_ip;
		}

		if ( get_option( 'yz_block_reports_' . $reporter ) ) {
			yz_die( __( 'Sorry, you are not allowed to report items anymore.', 'youzer-moderation' ) );
		}

		if ( ! is_user_logged_in() ) {
			
			$data['data']['ip'] = $user_ip;

			if ( 'on' == yz_option( 'yz_visitors_reports_show_fullname', 'on' ) ) {

				if ( ! isset( $_POST['fullname'] ) || empty( $_POST['fullname'] ) ) {
					yz_die( __( 'Please make sure to fill the fullname field.', 'youzer-moderation' ) );
				} else {
					$data['data']['fullname'] = $_POST['fullname'];
				}

			}

			if ( 'on' == yz_option( 'yz_visitors_reports_show_email', 'on' ) ) {

				if ( ! isset( $_POST['email'] ) || empty( $_POST['email'] ) ) {
					yz_die( __( 'Please make sure to fill the email field.', 'youzer-moderation' ) );
				} elseif( ! is_email( $_POST['email'] ) ) {
					yz_die( __( 'Please enter a valid email.', 'youzer-moderation' ) );
				} else {
					$data['data']['email'] = $_POST['email'];
				}

			}

			if ( ! empty( $data['data'] ) ) {
				$data['data'] = maybe_serialize( $data['data'] );
			}

		}
		
		// Filter Data.
		$data = apply_filters( 'yz_user_report_form_data', $data );

		if ( yz_is_user_report_description_required() && empty( $data['description'] ) ) {
			yz_die( __( 'The report description field is required!', 'youzer-moderation' ) );
		}
		
		if ( $query->is_user_already_reported_item( $data['reporter'], $data['item_id'], $data['component'] ) ) {
			yz_die( sprintf( __( 'You already reported this %s.', 'youzer-moderation' ), yzm_get_report_item_type( $data['component'] ) ) );
		}

		$item_inactive = false;

		switch ( $data['component'] ) {

			case 'activity':
			case 'comment':

				if ( bp_is_active( 'activity' ) ) {
					$activity = new BP_Activity_Activity( $data['item_id'] );
					$data['author'] = $activity->user_id;
				} else {
					$item_inactive = true;
				}

				break;
			
			case 'user':
				$data['author'] = $data['item_id'];
				break;
			
			case 'group':
			
				if ( bp_is_active( 'groups' ) ) {

					// Get Group Data
					$group = groups_get_group( $data['item_id'] );

					// Get Groups Creator.
					$data['author'] = $group->creator_id;

				} else {
					$item_inactive = true;
				}

				break;
			
			case 'message':

				if ( bp_is_active( 'messages' ) ) {
				    $message = new BP_Messages_Message( $data['item_id'] );
					$data['author'] = $message->sender_id;
				} else {
					$item_inactive = true;
				}

				break;

			default:
				break;

		}

		// Check one of the components is disactivated.
		if ( $item_inactive ) {
			yz_die( __( 'Something went wrong, please try again later.', 'youzer-moderation' ) );
		}

		if ( apply_filters( 'yz_disallow_user_report_their_own_items', true ) ) {
			
			// Check is current User Own item.
			$own_item = false;
			
			if ( is_array( $data['author'] ) ) {
				foreach( $data['author'] as $author_id ) {
					if ( $data['reporter'] == $author_id ) {
						$own_item = true;
						break;
					}
				}  
			} else if ( $data['reporter'] == $data['author'] ) {
				$own_item = true;
			}
	
			if ( $own_item ) {
				yz_die( sprintf( __( "Sorry you can't report your own %s.", 'youzer-moderation' ), yzm_get_report_item_type( $data['component'] ) ) );
			}
		}

		if ( apply_filters( 'yz_disallow_reporting_admin_items', true ) && is_super_admin( $data['author'] ) ) {
			yz_die( __( 'You cannot report administrators items.', 'youzer-moderation' ) );
		}

		$query = new YZM_Query();

		if ( $query->is_report_item_hidden( $data['item_id'], $data['component'] ) ) {
			yz_die( __( "Sorry, This Item was already reported and it's pending review right now.", 'youzer-moderation' ) );
		}

		$item_already_reported = $query->is_item_already_reported( $data['item_id'], $data['component'] );

		// Get Review Ad.
		$report_id = $query->add_report( $data );

		if ( $report_id ) {

			// Notify admin on The new added item.
			if ( ! $item_already_reported && 'on' == yz_option( 'yz_notify_admin_on_new_reports', 'on' ) ) {
				yzm_notify_admin( 'yz-admin-new-report', $report_id );
			}

			do_action( 'yzm_after_adding_user_report', $report_id, $data );
		
		}

		$response['msg'] = __( 'Your report has been successfully submitted.', 'youzer-moderation' );

		die( json_encode( $response ) );

	}

	/**
	 * Get Visitor IP.
	 */
	function get_visitor_ip() {
		foreach ( array( 'HTTP_CLIENT_IP', 'HTTP_X_FORWARDED_FOR', 'HTTP_X_FORWARDED', 'HTTP_X_CLUSTER_CLIENT_IP', 'HTTP_FORWARDED_FOR', 'HTTP_FORWARDED', 'REMOTE_ADDR' ) as $key ) {
			if ( array_key_exists( $key, $_SERVER ) === true) {
				foreach ( explode(',', $_SERVER[$key] ) as $ip ) {
					if ( filter_var( $ip, FILTER_VALIDATE_IP ) !== false) {
						return $ip;
					}
				}
			}
		}
	}

	/**
	 * Activity Report tool.
	 */
	function activity_comment_report_tool() {

		$comment = bp_activity_current_comment();

		if ( bp_loggedin_user_id() == $comment->user_id || is_super_admin( $comment->user_id ) ) {
			return;
		}


		?>
		<div class="yz-report-comment" data-type="comment"><i class="far fa-flag"></i><span class="yz-report-comment-title"><?php _e( 'report', 'youzer-moderation') ?></span><span class="yz-separator-point">•</span></div>
		<?php
	}

	/**
	 * Add Report Message tool.
	 */
	function message_report_tool() {

		if ( bp_loggedin_user_id() == bp_get_the_thread_message_sender_id() || is_super_admin( bp_get_the_thread_message_sender_id() ) ) {
			return;
		}
		
		?>
		<div class="yz-report-message" data-yztooltip="<?php _e( 'report message', 'youzer-moderation' ); ?>" data-message-id="<?php bp_the_thread_message_id(); ?>"><i class="far fa-flag"></i></div>
		<?php
	}

	/**
	 * Add User Report Button.
	 */
	function user_report_button( $user_id = null, $icons = null ) {

		if ( bp_loggedin_user_id() == $user_id || is_super_admin( $user_id ) ) {
			return;
		}

		// Get Button Title.
		$button_title = __( 'Report User', 'youzer-moderation' );

		?>

		<div class="yz-tool-btn yz-report-btn" <?php if ( 'only-icons' == $icons ) { ?> data-yztooltip="<?php echo $button_title; ?>"<?php } ?>  data-action="report" data-type="user">
				<div class="yz-tool-icon"><i class="fas fa-flag"></i></div><?php if ( 'full-btns' == $icons ) : ?><div class="yz-tool-name"><?php echo $button_title; ?></div><?php endif; ?>
		</div>

		<?php
	}

	/**
	 * Count Number Of messages Reports.
	 */
	function save_user_reports( $report_id, $data ) {

	    // Get User ID.
	    $user_id = bp_loggedin_user_id();

	    // Get Report Key.
	    $key = 'yzm_' . $data['component'] . '_reports';

	    // Get User Reports.
	    $user_reports = get_the_author_meta( $key, $user_id );

	    // Get Reports
	    $reports = ! empty( $user_reports ) ? $user_reports : array();

	    // Check if item is not already saved.
	    if ( empty( $reports ) || ! in_array( $data['item_id' ], $reports ) ) {

	    	// Add New Reported Item.
	        $reports[] = $data['item_id'];

	    	// Save New Updated Reports.
	        update_user_meta( $user_id, $key, $reports );

	    }

        // Check for threshold items
        $this->save_threshold_reports( $report_id, $data );

	}

	/**
	 * Save Threshold Reports.
	 **/
	function save_threshold_reports( $report_id, $data ) {

		if ( 'off' == yz_option( 'yz_' .  $data['component'] . '_automatic_moderation', 'on' ) ) {
			return;
		}

	    // Get Reports Threshold.
	    $threshold = yz_option( 'yz_' .  $data['component'] . '_reports_threshold', 5 );

	    // Init Class.
	    $query = new YZM_Query();

		// Get Item Reports Count
		$reports_count = $query->get_item_reports_count( $data['item_id'], $data['component'] );

		if ( $reports_count >= $threshold ) {

			if ( ( $data['component'] == 'activity' || $data['component'] == 'comment' ) && bp_is_active( 'activity' ) ) {

				$activity = new BP_Activity_Activity( $data['item_id'] );

				if ( empty( $activity->component ) ) {
					return;
				}

				bp_activity_mark_as_spam( $activity );

				$activity->save();
		
				unset( $activity );

				yzm_clear_reported_elements( $data['item_id'], $data['component'] );

			} else {

				// Theresold Items Key.
				$threshold_key = 'yz_' .  $data['component']  . '_threshold_reports';

				// Get Threshold Items.
				$threshold_reports = is_multisite() ? get_blog_option( BP_ROOT_BLOG, $threshold_key ) : get_option( $threshold_key );

				// Check if there's some threshold items already exist or not.
				$threshold_reports = ! empty( $threshold_reports ) ? $threshold_reports : array();

		    	// Check if item is not already saved.
				if ( empty( $threshold_reports ) || ! in_array( $data['item_id'], $threshold_reports ) ) {
		    		
		    		// Add New Reported Item.
					$threshold_reports[] = $data['item_id'];
					
					if ( is_multisite() ) {
						update_blog_option( BP_ROOT_BLOG, $threshold_key, $threshold_reports ); 
					} else {
						update_option( $threshold_key, $threshold_reports );
					}

				}
			}

			// Apply Restrictions !
			yzm_apply_restrictions( $data['author'], $data['component'], 'temporary' );

			// Notify Admin On The New Hidden Item.
			if ( 'on' == yz_option( 'yz_notify_admin_on_hidden_item', 'on' ) ) {
				yzm_notify_admin( 'yz-admin-item-hidden', $report_id );
			}

			// Notify User On The New Hidden Item.
			if ( 'on' == yz_option( 'yz_notify_user_on_hidden_item', 'on' ) ) {
				yzm_send_email( $data['author'], 'yz-user-item-hidden', $report_id );
			}

			// Mark Item As Hidden.
			$query->mark_report_item_as_hidden( $data['item_id'], $data['component'] );

		}
	
	}

	/**
	 * Get Report Form.
	 */
	function get_user_report_form() {

	    // Get Data.
	    $options = array();
	    $options['component'] = isset( $_POST['component'] ) ? $_POST['component'] : null; 
	    $options['item_id'] = isset( $_POST['item_id'] ) ? $_POST['item_id'] : null; 

	    // Args
	    $modal_args = array(
	        'show_close' => false,
	        'id'        => 'yz-report-form',
	        'button_id' => 'yz-add-report',
	        'operation' => 'add'
	    );

	    $modal_args['title_icon'] = 'far fa-flag';
	    // $modal_args['icon'] = 'far fa-flag';
	    $modal_args['title'] = sprintf( __( 'Report %s', 'youzer-moderation' ), yzm_get_report_item_type( $options['component'] ) );
	    $modal_args['button_title'] = __( 'submit report', 'youzer-moderation' );

	    // Get User Review Form.
	    yz_modal( $modal_args, array( $this, 'user_report_form' ), $options );

	}

	/**
	 * User Review Form
	 */
	function user_report_form( $args = null ) {

	    global $Yz_Settings;

	    $Yz_Settings->get_field(
	        array(
	            'type'  => 'openDiv',
	            'class' => 'yz-report-form'
	        )
	    );

	    $subjects = yz_option( 'yz_' . $args['component'] . '_subjects', yzm_default_reports_subject() );

	    if ( ! empty( $subjects ) ) {

	        $Yz_Settings->get_field(
	            array(
	                'desc'         => __( 'How would you describe it?', 'youzer-moderation' ),
	                'opts'         => array_combine( $subjects, $subjects ),
	                'title'        => __( 'Subject', 'youzer-moderation' ),
	                'id'           => 'category',
	                'type'         => 'select',
	                'no_options'   => true,
	            )
	        );
	    
	    }

	    // Show Only For Visitors.
	    if ( ! is_user_logged_in() && 'on' == yz_option( 'yz_enable_visitors_reports', 'off' ) ) {

	    	echo '<div class="yz-modal-2rows">';

	        if ( 'on' == yz_option( 'yz_visitors_reports_show_fullname', 'on' ) ) {
	            $Yz_Settings->get_field(
	                array(
	                    'title'        => __( 'Full name', 'youzer-moderation' ),
	                    'desc'         => __( 'type your full name', 'youzer-moderation' ),
	                    'id'           => 'fullname',
	                    'type'         => 'text',
	                    'no_options'   => true,
	                )
	            );
	        }

	        if ( 'on' == yz_option( 'yz_visitors_reports_show_email', 'on' ) ) {
	            $Yz_Settings->get_field(
	                array(
	                    'title'        => __( 'E-mail', 'youzer-moderation' ),
	                    'desc'         => __( 'type your email', 'youzer-moderation' ),
	                    'id'           => 'email',
	                    'type'         => 'email',
	                    'no_options'   => true,
	                )
	            );
	        }

	        echo '</div>';
	    }

	    // SET AS required.
	    $Yz_Settings->get_field(
	        array(
	            'title'        => __( 'Description', 'youzer-moderation' ),
	            'desc'         => __( 'Please Let us know more about that !', 'youzer-moderation' ),
	            'id'           => 'description',
	            'type'         => 'textarea',
	            'no_options'   => true,
	        )
	    );

	    ?>

	    <input type="hidden" name="component" value="<?php echo $args['component']; ?>">
	    <input type="hidden" name="item_id" value="<?php echo $args['item_id']; ?>">
	    
	    <?php
	    
	    $Yz_Settings->get_field( array( 'type' => 'closeDiv' ) );

	}

}