<?php

class YZM_Query {

	public $reports_table;

	function __construct() {

		$this->reports_table  = 'yz_reports';
		$this->restrictions_table  = 'yz_mod_restrictions';

	}

	/**
	 * Get Report.
	 */
	function get_report( $report_id ) {

        global $wpdb;

        $report = $wpdb->get_row( "SELECT * FROM " . $wpdb->prefix. $this->reports_table.  " WHERE id = '$report_id'", ARRAY_A );

        return $report;
	}

	/**
	 * Get Reporters By Item ID.
	 */
	function get_reporters_by_item_id( $item_id, $component ) {

        global $wpdb;

        // Get Reporters.
        $reporters = $wpdb->get_results( $wpdb->prepare( "SELECT DISTINCT( reporter ) FROM " . $wpdb->prefix. $this->reports_table. " WHERE item_id = %d AND component = '%s' ", $item_id, $component ), ARRAY_A );

        // Get ID's
        $reporters = wp_list_pluck( $reporters, 'reporter' );

        // Get Unique ID's
        return $reporters;

	}

	/**
	 * Get Restriction Data !
	 */
	function get_restriction( $restriction_id ) {
		
		global $wpdb;

		$result = $wpdb->get_row( "SELECT * FROM " . $wpdb->prefix. $this->restrictions_table . " WHERE id = $restriction_id", ARRAY_A );

		return $result;

	}

	/**
	 * Get Restrictions Data !
	 */
	function get_restrictions( $restriction_id ) {
		
		global $wpdb;

		// Get Result.
		$result = $wpdb->get_var( "SELECT restrictions FROM " . $wpdb->prefix. $this->restrictions_table . " WHERE id = $restriction_id" );

		// Unserialize Result.
		$result = maybe_unserialize( $result );

		return $result;

	}
	
	/**
	 * Add Restriction.
	 */
	function add_restriction( $data = array() ) {

		global $wpdb;

		$restriction = $this->is_restriction_exist( $data );
		$data['restrictions'] = maybe_serialize( $data['restrictions'] );

		if ( $restriction ) {
			$wpdb->query( $wpdb->prepare( "UPDATE " . $wpdb->prefix . $this->restrictions_table . " SET time = '%s', restrictions = '%s' WHERE id = %d", $data['time'], $data['restrictions'] , $restriction['id'] ) );
		} else {

			// Get Current Time.
			$data['status'] = 'active';
			
			// Insert Review.
			$result = $wpdb->insert(  $wpdb->prefix . $this->restrictions_table, $data );

			if ( $result ) {
				
				// Get Restriction ID.
				$restriction_id = $wpdb->insert_id;

				// Update User Restrictions.
				yzm_update_user_restrictions( $data['user_id'], $data['type'] );

				// Notify On Temporary Restrictions.
				if ( $data['type'] == 'temporary' && 'on' == yz_option( 'yz_notify_user_on_temporary_restrictions', 'on' ) ) {
					yzm_send_email( $data['user_id'], 'yz-temporary-restrictions', $restriction_id, 'restriction' );
				}

				// Notify On Official Restrictions.
				if ( $data['type'] == 'official' && 'on' == yz_option( 'yz_notify_user_on_official_restrictions', 'on' ) ) {
					yzm_send_email( $data['user_id'], 'yz-official-restrictions', $restriction_id, 'restriction' );
				}

				// Return ID.
				return $restriction_id;
			}

		}

		return false;

	}

	/**
	 * Is Restriction Exist.
	 */
	function is_restriction_exist( $data ) {
		global $wpdb;
		$result = $wpdb->get_row( $wpdb->prepare("SELECT id FROM " . $wpdb->prefix . $this->restrictions_table . " WHERE user_id = %d AND component = '%s' AND type = '%s' AND status='active'" , $data['user_id'], $data['component'], $data['type'] ), ARRAY_A );
		return $result;
	}

	/**
	 * End Restriction.
	 */
	function end_restriction( $user_id, $component, $type = false ) {

		global $wpdb;

		$type = ! empty( $type ) ? $type : 'official';

        // Change Status.
        $result = $wpdb->query( "UPDATE " . $wpdb->prefix . $this->restrictions_table . " SET status = 'ended' WHERE user_id = $user_id AND component = '$component' AND type = '$type' AND status = 'active'" );

        if ( $result ) {

			// Update User Restrictions.
            yzm_update_user_restrictions( $user_id, $type );
        }

        return $result;

	}

	/**
	 * Get Report Item Hidden.
	 */
	function is_report_item_hidden( $item_id, $component ) {

	    global $wpdb;
		
		$is_hidden = (int) $wpdb->get_var( $wpdb->prepare(
			'SELECT is_hidden FROM ' . $wpdb->prefix . $this->reports_table . ' WHERE item_id = %d AND component = %s AND status = "open"', $item_id, $component
		) );

		return $is_hidden == 0 ? false : true;
	}

	/**
	 * Is Item Already Reported.
	 */
	function is_item_already_reported( $item_id, $component ) {
		
		global $wpdb;

		$report = $wpdb->get_row( "SELECT * FROM " . $wpdb->prefix . $this->reports_table . " WHERE item_id = $item_id AND component = '$component' AND status = 'open'" , ARRAY_A );
		
		return ! empty( $report ) ? true : false;
	}

	/**
	 * Is User Already Reported Item.
	 */
	function is_user_already_reported_item( $reporter, $item_id, $component ) {
		
		global $wpdb;

		$report = $wpdb->get_row( "SELECT * FROM " . $wpdb->prefix . $this->reports_table . " WHERE reporter = $reporter AND item_id = $item_id AND component = '$component' AND status = 'open' " , ARRAY_A );

		return ! empty( $report ) ? true : false;

	}
	
	/**
	 * Get Reports Count.
	 */
	function get_item_reports_count( $item_id, $component ) {

	    global $wpdb;
		
		$count = $wpdb->get_var( $wpdb->prepare(
			'SELECT COUNT(*) FROM ' . $wpdb->prefix . $this->reports_table . ' WHERE item_id = %d AND component = %s AND status = "open"', $item_id, $component
		) );

		return $count;
	}

	/**
	 * Mark Reported Item As Hidden.
	 */
	function mark_report_item_as_hidden( $item_id, $component ) {

		global $wpdb;

        $result = $wpdb->query( "UPDATE " . $wpdb->prefix . $this->reports_table . " SET is_hidden = 1 WHERE item_id = $item_id AND component = '$component' AND status = 'open'" );

        return $result;

	}

	/**
	 * Get User Restrictions.
	 */
	function get_user_restrictions( $user_id, $type ) {

        global $wpdb;

        $result = array();

        // Get Reporters.
        $restrictions = $wpdb->get_results( $wpdb->prepare( "SELECT restrictions FROM " . $wpdb->prefix . $this->restrictions_table . " WHERE user_id = %d AND type = '%s' AND status = 'active'", $user_id, $type ), ARRAY_A );

        if ( $restrictions ) {

	        $restrictions = wp_list_pluck( $restrictions, 'restrictions' );

	        foreach ( $restrictions as $restriction ) {
	        	$result = array_merge( $result, maybe_unserialize( $restriction ) );
	        }

        }

        return ! empty( $result ) ? array_unique( $result ) : false;

	}

	/**
	 * Get Active Restriction
	 */
	function get_active_official_restrictions() {

	    global $wpdb;
	    
	    // Get Reporters.
	    $restrictions = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . $this->restrictions_table . ' WHERE status = "active" AND type = "official"', ARRAY_A );

	    return $restrictions;

	}


	/**
	 * Add Report.
	 */
	function add_report( $data = array() ) {

		global $wpdb;

		// Get Current Time.
		$data['time'] = current_time( 'mysql' );
		
		// Insert Review.
		$result = $wpdb->insert(  $wpdb->prefix . 'yz_reports', $data );

		if ( $result ) {
			// Return ID.
			return $wpdb->insert_id;
		}

		return false;

	}
}