<?php

/**
 * Moderation Restrictions Functions.
 */
class YZM_Restrictions {
	
	function __construct() {

		// Init Restrictions.
		$this->init();

	}

	/**
	 * Init Restrictions.
	 */
	function init() {
		// return;
		if ( ! is_user_logged_in() ) {
			return;
		}

		// Init Vars.
		$restrictions = array();

		// Get User Restrictions.
		$user_restrictions = get_the_author_meta( 'yz_reports_restrictions', bp_loggedin_user_id() );

		if ( empty( $user_restrictions )  ) {
			return;
		}

		foreach ( $user_restrictions as $user_restriction) {
			$restrictions = array_merge( $restrictions, $user_restriction );
		}

		if ( empty( $restrictions )  ) {
			return;
		}

		// Switch Key with values.
		$restrictions = array_flip( $restrictions );

		if ( isset( $restrictions['groups'] ) ) {
			// Disabe Groups Join & Request Membership Buttons.
			add_filter( 'bp_get_group_join_button', '__return_false' );
			// Disable Groups Creation.
			add_filter( 'bp_user_can_create_groups', '__return_false' );
		}
		
		if ( isset( $restrictions['posts'] ) ) {
			// Posting Form.
			add_filter( 'yz_is_wall_posting_form_active', '__return_false' );
			// Disable Posts Delete.
			add_filter( 'bp_activity_user_can_delete', '__return_false' );
		}
		
		if ( isset( $restrictions['comments'] ) ) {
			// Disable Posts Comments.
			add_filter( 'bp_activity_can_comment', '__return_false' );
			// Disable Comments Reply.
			add_filter( 'bp_activity_can_comment_reply', '__return_false' );
		}

		if ( isset( $restrictions['reviews'] ) ) {
			// Disable Reviews.
			add_filter( 'yz_display_user_review_tool', '__return_false');
		}
		
		if ( isset( $restrictions['follows'] ) ) {
			// Remove Follows System.
			add_filter( 'bp_follow_get_add_follow_button', '__return_false' );
		}

		if ( isset( $restrictions['messages'] ) ) {
			// Disable Send Message Button.
			add_filter('yz_get_send_private_message_button', '__return_false' );
			// Remove Compose Message Tab.
			bp_core_remove_subnav_item( 'messages', 'compose' );
			// Hide Sending Messgaes Replies Form.
			add_filter( 'yz_display_send_message_reply_form', '__return_false' );
		}

		if ( isset( $restrictions['friends'] ) ) {
			// Disable Add Friend Button.
			add_filter( 'bp_get_add_friend_button', '__return_false' );
		}

		do_action( 'yzm_after_restrictions', $restrictions );
	}

}