<?php

class YZBM_Setup {

	/**
	 * # Install Options .
	 */
	function install_options() {

        // Install Default Options.
        if ( ! get_option( 'yzpm_installed' ) ) {

        	if ( ! wp_next_scheduled( 'yzm_update_restrictions' ) ) {
			   wp_schedule_event( time(), 'daily', 'yzm_update_restrictions' );
			}
			
            update_option( 'yzpm_installed', '1' );
        
        }

	}

	/**
	 * Build DataBase Table.
	 */
	public function build_database_table() {

        global $wpdb;

        $reports_table = $wpdb->prefix . 'yz_reports';
        $yz_mod_restrictions = $wpdb->prefix . 'yz_mod_restrictions';

        // Set Variables
        $charset_collate = $wpdb->get_charset_collate();

		// Include Files.
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		if ( $wpdb->get_var( "SHOW TABLES LIKE '$reports_table'" ) != $reports_table ) {

	        // Table SQL Code.
			$reports_sql = "CREATE TABLE $reports_table (
				id int(11) NOT NULL AUTO_INCREMENT,
				item_id int(11) NOT NULL,
				is_hidden tinyint(1) NOT NULL DEFAULT 0,
				component VARCHAR(10) NOT NULL,
				reporter int(11) NOT NULL,
				author LONGTEXT NOT NULL,
				category VARCHAR(255) NOT NULL,
				description LONGTEXT NOT NULL,
				data LONGTEXT NOT NULL,
			 	time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
				status VARCHAR(10) NOT NULL,
				PRIMARY KEY (id)
			) $charset_collate;";

			// Build Tables.
			dbDelta( $reports_sql );

		}

		if ( $wpdb->get_var( "SHOW TABLES LIKE '$yz_mod_restrictions'" ) != $yz_mod_restrictions ) {

	        // Table SQL Code.
			$restriction_sql = "CREATE TABLE $yz_mod_restrictions (
				id int(11) NOT NULL AUTO_INCREMENT,
				user_id int(11) NOT NULL,
				type VARCHAR(10) NOT NULL,
				component VARCHAR(10) NOT NULL,
				restrictions LONGTEXT NOT NULL,
			 	time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
				status VARCHAR(10) NOT NULL,
				PRIMARY KEY (id)
			) $charset_collate;";

			dbDelta( $restriction_sql );

		}

	}

	function install_emails() {
		$defaults = array(
			'post_status' => 'publish',
			'post_type'   => bp_get_email_post_type(),
		);

		$emails       = $this->get_moderation_emails();
		$descriptions = array(
			'yz-user-item-hidden' => __( 'Notify user when their item is hidden.', 'youzer-moderation' ),
			'yz-user-item-deleted' => __( 'Notify user when their item is deleted.', 'youzer-moderation' ),
			'yz-admin-new-report' => __( 'Notify admin when a new item is reported.', 'youzer-moderation' ),
			'yz-user-item-restored' => __( 'Notify user when their item is restored.', 'youzer-moderation' ),
			'yz-admin-item-hidden' => __( 'Notify admin when a new item is marked as hidden.', 'youzer-moderation' ),
			'yz-reporter-item-deleted' => __( 'Notify reporter when their reported item is deleted.', 'youzer-moderation' ),
			'yz-reporter-item-restored' => __( 'Notify reporter when their reported item is restored.', 'youzer-moderation' ),
			'yz-official-restrictions' => __( 'Notify user when an official restrictions applied on their account.', 'youzer-moderation' ),
			'yz-temporary-restrictions' => __( 'Notify user when an temporary restrictions applied on their account.', 'youzer-moderation' ),
		);

		// Add these emails to the database.
		foreach ( $emails as $id => $email ) {

			$post_id = wp_insert_post( bp_parse_args( $email, $defaults, 'install_email_' . $id ) );

			if ( ! $post_id ) {
				continue;
			}

			$tt_ids = wp_set_object_terms( $post_id, $id, bp_get_email_tax_type() );
			foreach ( $tt_ids as $tt_id ) {
				$term = get_term_by( 'term_taxonomy_id', (int) $tt_id, bp_get_email_tax_type() );
				wp_update_term( (int) $term->term_id, bp_get_email_tax_type(), array(
					'description' => $descriptions[ $id ],
				) );
			}
		}

	}

	/**
	 * Get a list of emails for populating the email post type.
	 *
	 */
	function get_moderation_emails() {
		

		return array(
			'yz-admin-new-report' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] New {{yz_report.item_type}} reported', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "A new {{yz_report.item_type}} has been reported :\n\n<blockquote>&quot;{{yz_report.item_content}}&quot;</blockquote>\n\n<a href=\"{{{yz_report.moderation_queue}}}\">View Moderation Queue</a> to take the appropriate action.", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "A new {{yz_report.item_type}} has been reported :\n\n\"{{yz_report.item_content}}\"\n\nGo to the moderation queue to take the appropriate action: {{{yz_report.moderation_queue}}}", 'youzer-moderation' ),
			),
			'yz-admin-item-hidden' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] New {{yz_report.item_type}} hidden', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "A new {{yz_report.item_type}} has been marked as hidden :\n\n<blockquote>&quot;{{yz_report.item_content}}&quot;</blockquote>\n\n<a href=\"{{{yz_report.moderation_queue}}}\">View Moderation Queue</a> to take the appropriate action.", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "A new {{yz_report.item_type}} has been marked as hidden :\n\n\"{{yz_report.item_content}}\"\n\nGo to the moderation queue to take the appropriate action: {{{yz_report.moderation_queue}}}", 'youzer-moderation' ),
			),
			'yz-user-item-hidden' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] Your {{yz_report.item_type}} is under moderation', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "Your {{yz_report.item_type}} has been reported and it's awaiting moderation :\n\n<blockquote>&quot;{{yz_report.item_content}}&quot;</blockquote>\n\nWe will check it and get back to you as soon as possible.", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "Your {{yz_report.item_type}} has been reported and it's awaiting moderation :\n\n\"{{yz_report.item_content}}\"\n\nWe will check it and get back to you as soon as possible.", 'youzer-moderation' ),
			),
			'yz-user-item-deleted' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] Your {{yz_report.item_type}} has been deleted', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "We removed your {{yz_report.item_type}} because it violates our community standards.", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "We removed your {{yz_report.item_type}} because it violates our community standards.", 'youzer-moderation' ),
			),
			'yz-user-item-restored' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] Your {{yz_report.item_type}} has been restored', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "Thank you for your patience. We restored your {{yz_report.item_type}} :\n\n<blockquote>&quot;{{yz_report.item_content}}&quot;</blockquote>", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "Thank you for your patience. We restored your {{yz_report.item_type}} :\n\n<blockquote>&quot;{{yz_report.item_content}}&quot;</blockquote>", 'youzer-moderation' ),
			),
			'yz-reporter-item-deleted' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] We removed the {{yz_report.item_type}} you reported', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "We reviewed the {{yz_report.item_type}} you reported. Since it violated our community standards, we removed it.\n\nThanks for your report !", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "We reviewed the {{yz_report.item_type}} you reported. Since it violated our community standards, we removed it.\n\nThanks for your report !", 'youzer-moderation' ),
			),
			'yz-reporter-item-restored' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] We restored the {{yz_report.item_type}} you reported', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "We reviewed the {{yz_report.item_type}} you reported. Since it didn't violated our community standards, we restored it.\n\nThanks for your report !", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "We reviewed the {{yz_report.item_type}} you reported. Since it didn't violated our community standards, we restored it.\n\nThanks for your report !", 'youzer-moderation' ),
			),
			'yz-temporary-restrictions' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] Temporary restrictions applied on your account', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "We applied the following restrictions on your account till we review your reported {{yz_report.item_type}} :\n\n{{yz_report.item_restrictions}}\n\nThanks for your understanding !", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "We applied the following restrictions on your account till we review your reported {{yz_report.item_type}} :\n\n{{yz_report.item_restrictions}}\n\nThanks for your understanding !", 'youzer-moderation' ),
			),
			'yz-official-restrictions' => array(
				/* translators: do not remove {} brackets or translate its contents. */
				'post_title'   => __( '[{{{site.name}}}] We applied restrictions on your account', 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_content' => __( "We applied the following restrictions on your account {{yz_report.restrictions_period}} :\n\n{{yz_report.item_restrictions}}.\n\nThanks for your understanding !", 'youzer-moderation' ),
				/* translators: do not remove {} brackets or translate its contents. */
				'post_excerpt' => __( "We applied a temporary restrictions on your account till we review your reported {{yz_report.item_type}}.\n\nThanks for your understanding !", 'youzer-moderation' ),
			),
		);
	}

}