<?php

/**
 * Notify Admin.
 */
function yzm_notify_admin( $email_type, $report ) {

    $admins = get_users( array( 'fields' => 'ID', 'role' => 'administrator' ) );

    if ( empty( $admins ) ) {
        return;
    }

    foreach ( $admins as $admin_id ) {
        yzm_send_email( $admin_id, $email_type, $report );
    }

}

/**
 * Send E-mail.
 */
function yzm_send_email( $user_id, $email_type, $report, $type = 'report' ) {
    $user_id = is_numeric( $user_id ) ? (int) $user_id : $user_id;
    bp_send_email( $email_type, $user_id, yzm_get_emails_args( $report, $type ) );
}

/**
 * Get E-mail Args.
 */
function yzm_get_emails_args( $item, $type = null ) {

    // Init Query Class
    $query = new YZM_Query();

    // Get Report ID.
    if ( $type == 'report' && ! is_array( $item ) ) {
        $item = $query->get_report( $item );
    } else if ( $type == 'restriction' ) {
        $item = $query->get_restriction( $item );
    }

    if ( empty( $item ) ) {
        return;
    }

    $args = array( 'tokens' => array( 'yz_report.moderation_queue' => bp_get_admin_url( 'admin.php?page=youzer-reports' ) ) );
    
    if ( isset( $item['component'] ) ) {
        $args['tokens']['yz_report.item_type'] = yzm_get_report_item_type( $item['component'] );
    }

    if ( isset( $item['item_id'] ) ) {
        $args['tokens']['yz_report.item_content'] = yzm_get_report_item_content( $item['component'], $item['item_id'] );
    }

    if ( $type == 'restriction' ) {
        $args['tokens']['yz_report.item_restrictions'] = yzm_get_email_item_restrictions( $item['id'] );
        $args['tokens']['yz_report.restrictions_period'] = yzm_get_email_item_restrictions_period( $item['component'] );
    }

    return $args;

}

/**
 * Get Email Item Content.
 */
function yzm_get_report_item_content( $component, $item_id )  {

    $content = '';

    switch ( $component ) {

        case 'activity':
        case 'comment':

            if ( bp_is_active( 'activity' ) ) {
                $activity = new BP_Activity_Activity( $item_id );

                if ( $activity->type == 'activity_comment' ) {
                    $content  = stripslashes_deep( $activity->content ) ;
                } else {
                    $content = bp_activity_get_permalink( $item_id );
                }
            }

            break;

        case 'message':

            if ( bp_is_active( 'messages' ) ) {
                $message = new BP_Messages_Message( $item_id );
                $content = $message->message;
            }

            break;

        case 'user':
            $content = bp_core_get_user_domain( $item_id );
            break; 
    
        case 'group':

            if ( bp_is_active( 'groups' ) ) {
                $group = groups_get_group( array( 'group_id' => $item_id ) );
                $content = bp_get_group_permalink( $group );
            }

            break;

        default:
            break;

    }

    // Delete Image From Content.
    $content = preg_replace( "/<img[^>]+\>/i", '', $content ); 

    return $content;

}

/**
 * Get Email Item Restrictions
 */
function yzm_get_email_item_restrictions_period( $component ) {

    // Get Restictions Period.
    $restriction_period = yz_option( 'yz_rgr_' . $component . '_period', 60 );
    
    if ( ! empty( $restriction_period ) && $restriction_period > 0 ) {
        return sprintf( _n( 'for %d day', 'for %d days', $restriction_period, 'youzer-moderation' ), $restriction_period );
    }

    return __( 'forever', 'youzer-moderation' );
}

/**
 * Get Email Item Restrictions
 */
function yzm_get_email_item_restrictions( $component ) {

	// Init Vars.   
    $list = '';
    $restrictions = yzm_get_component_restrictions( $component );

    if ( ! empty( $restrictions ) ) {
    	$list = "- " . implode( "\n\n- ", $restrictions );
    }

    return $list;

}

/**
 * Get Component Restrictions.
 */
function yzm_get_component_restrictions( $restriction_id ) {

    // Init Query Class.
    $query = new YZM_Query();

    // Get Component Restrictions.
    $component_restrictions = $query->get_restrictions( $restriction_id );

    // $component_restrictions = isset( $component_restrictions[ $component ] ) ? $component_restrictions[ $component ] : '';

    $restrictions = array();

    if ( ! empty( $component_restrictions ) ) {

        foreach ( $component_restrictions as $restriction ) {

            // if ( $restriction != 'on' ) {
            //     continue;
            // }

            switch ( $restriction ) {

                case 'posts':
                    $restrictions[] = __( "You can't add new activity posts.", 'youzer-moderation' );
                    break;

                  case 'friends':
                    $restrictions[] = __( "You can't add new friends.", 'youzer-moderation' );
                    break;
                
                  case 'follows':
                    $restrictions[] = __( "You can't follow new members.", 'youzer-moderation' );
                    break;
                
                  case 'comments':
                    $restrictions[] = __( "You can't add new comments or replies.", 'youzer-moderation' );
                    break;
                
                  case 'groups':
                    $restrictions[] = __( "You can't Join or Create New Groups.", 'youzer-moderation' );
                    break;

                  case 'messages':
                    $restrictions[] = __( "You can't send private messages.", 'youzer-moderation' );
                    break;
                
                  case 'reviews':
                    $restrictions[] = __( "You can't add new reviews.", 'youzer-moderation' );
                    break;
                
                default:
                    break;
            }
        }

    }

    return $restrictions;

}