<?php

/**
 * Call Scripts
 */
function yzm_scripts() {
    wp_enqueue_script( 'yz-moderation', YZBM_URL . 'assets/js/yz-moderation.js' ); 
}

add_action( 'wp_enqueue_scripts', 'yzm_scripts' );
/**
 * Polls Admin Settings.
 **/
function yzm_reports_settings() {
    do_action( 'yzm_reports_settings' );
}

/**
 * Default Options.
 */
function yzm_default_options( $options ) {

    // Options.
    $new_options = array(
        'yz_activity_subjects' => yzm_default_reports_subject(),
        'yz_comment_subjects' => yzm_default_reports_subject(),
        'yz_message_subjects' => yzm_default_reports_subject(),
        'yz_user_subjects' => yzm_default_reports_subject(),
        'yz_group_subjects' => yzm_default_reports_subject(),
        'yz_user_automatic_moderation' => 'on',
        'yz_group_automatic_moderation' => 'on',
        'yz_activity_automatic_moderation' => 'on',
        'yz_comment_automatic_moderation' => 'on',
        'yz_message_automatic_moderation' => 'on',
        'yz_enable_activity_reports' => 'on',
        'yz_enable_comment_reports' => 'on',
        'yz_enable_message_reports' => 'on',
        'yz_enable_group_reports' => 'on',
        'yz_enable_user_reports' => 'on',
        'yz_user_reports_threshold' => 5,
        'yz_group_reports_threshold' => 5,
        'yz_message_reports_threshold' => 5,
        'yz_comment_reports_threshold' => 5,
        'yz_activity_reports_threshold' => 5,
        'yz_notify_user_on_restored_item' => 'on',
        'yz_notify_user_on_hidden_item' => 'on',
        'yz_notify_user_on_deleted_item' => 'on',
        'yz_notify_reporter_on_restored_item' => 'on',
        'yz_notify_reporter_on_deleted_item' => 'on',
        'yz_notify_admin_on_new_reports' => 'on',
        'yz_notify_admin_on_hidden_item' => 'on',
        'yz_notify_user_on_temporary_restrictions' => 'on',
        'yz_notify_user_on_official_restrictions' => 'on',
        'yz_reports_moderation_roles' => array( 'administrator' => 'on' ),
        'yz_who_can_report_items' => array( 'administrator' => 'on', 'editor' => 'on', 'subscriber' => 'on', 'contributor' => 'on', 'author' => 'on' ),
        'yz_enable_visitors_reports' => 'off',
        'yz_visitors_reports_show_fullname' => 'on',
        'yz_visitors_reports_show_email' => 'on',
        'yz_reports_form_desc_required' => 'off',
        'yz_reports_form_fullname_required' => 'on',
        'yz_reports_form_email_required' => 'on',
        'yz_activity_am_disable_posting' => 'on',
        'yz_rgr_activity_period' => 60,
        'yz_rgr_comment_period' => 60,
        'yz_rgr_user_period' => 60,
        'yz_rgr_group_period' => 60,
        'yz_rgr_message_period' => 60,
        'yz_reporters_roles' => array( 'administrator', 'editor', 'subscriber', 'contributor', 'author' )
    );

    $options = array_merge( $options, $new_options );

    return $options;
}

add_filter( 'yz_default_options', 'yzm_default_options' );

/**
 * Default Subjects.
 */
function yzm_default_reports_subject() {
    
    $subjects = array(
        'sexually'      => __( 'sexually inappropriate', 'youzer-moderation' ),
        'prohibited'    => __( 'prohibited content', 'youzer-moderation' ),
        'scam'          => __( 'misleading or scam', 'youzer-moderation' ),
        'news'          => __( 'false news', 'youzer-moderation' ),
        'offensive'     => __( 'offensive', 'youzer-moderation' ),
        'violence'      => __( 'violence', 'youzer-moderation' ),
        'spam'          => __( 'spam', 'youzer-moderation' ),
        'nudity'        => __( 'nudity', 'youzer-moderation' ),
        'harassment'    => __( 'harassment', 'youzer-moderation' ),
        'hate'          => __( 'hate speech', 'youzer-moderation' ),
        'terrorism'     => __( 'terrorism', 'youzer-moderation' ),
        'other'         => __( 'other', 'youzer-moderation' )
    );

    return apply_filters( 'yzm_default_reports_subject', $subjects );
}

/**
 * Check if report description is required.
 */
function yz_is_user_report_description_required() {

    $required = false;

    if ( yz_option( 'yz_reports_form_desc_required', 'off' ) == 'on' ) {
        $required = true;
    }

    return apply_filters( 'yz_is_user_report_description_required', $required );
}

/**
 * Redirect Reported User & Group.
 */
function yzm_redirect_reported_users_and_groups() {
  
    if ( is_super_admin() ) {
        return;
    }

    // Init Var.
    $redirect = false;

    if ( bp_is_user() ) {
        // Get Hidden Users.
        $hidden_users = yzm_get_reported_items( 'user' );
        if ( ! empty( $hidden_users ) ) {
            if ( in_array( bp_displayed_user_id(), $hidden_users ) ) {
                $redirect = true;
            }
        }

    } else if ( bp_is_group() ) {
        // Get Hidden Groups.
        $hidden_groups = yzm_get_reported_items( 'group' );
        if ( ! empty( $hidden_groups ) ) {
            if ( in_array( bp_get_current_group_id(), $hidden_groups ) ) {
                $redirect = true;
            }
        }
    }
    
    if ( $redirect ) {
        global $wp_query;
        $wp_query->set_404();
        status_header( 404 );
        get_template_part( 404 );
        exit();
    }

}

add_action( 'bp_template_redirect', 'yzm_redirect_reported_users_and_groups' );

/**
 * Hide User Reported Elements.
 */
function yz_hide_user_reported_elements() {

    if ( is_super_admin() ) {
        return;
    }

    // Hide Reported Activities.
    add_filter( 'bp_after_has_activities_parse_args', 'yzm_exclude_activities_from_directories', 999 );
    // Hide Reported Comments.
    add_filter( 'bp_activity_comment_content', 'yzm_show_reported_comments_notice', 10, 1 );
    // Hide Reported Messages.
    add_action( 'bp_messages_thread_post_populate', 'yzm_hide_reported_messages' );
    // Hide Reported Goups.
    add_filter( 'bp_after_has_groups_parse_args', 'yzm_exclude_groups_from_directories', 999 );
    // Hide Reported Members.
    add_filter( 'bp_after_has_members_parse_args', 'yzm_exclude_users_from_directories', 999 );

}

add_action( 'bp_init', 'yz_hide_user_reported_elements' );

/**
 * Get Threshold Item.
 */
function yzm_get_reported_items( $component ) {

    // Get Rported Messages.
    $hidden_messages = array();

    if ( is_user_logged_in() ) {

        // Get User Reports.
        $user_reports = get_the_author_meta( 'yzm_' . $component . '_reports', bp_loggedin_user_id() );

        // Merge Hidden Messages.
        if ( ! empty( $user_reports ) ) {
            $hidden_messages = array_merge( $hidden_messages, $user_reports );
        }
    }

    // Get Threshold Reports.
    $threshold_reports = yzm_get_threshold_reports( $component );
    
    // Merge Hidden Messages.
    if ( ! empty( $threshold_reports ) ) {
        $hidden_messages = array_merge( $hidden_messages, $threshold_reports );
    }     

    // Remove Duplicate items & Return Items.
    return array_unique( $hidden_messages );
}

/**
 * Get Threshold Reports.
 */
function yzm_get_threshold_reports( $component ) {

    if ( $component == 'activity' || $component == 'comment' ) {
        return false;
    }

    // Theresold Items Key.
    $threshold_key = 'yz_' . $component . '_threshold_reports';

    // Get Threshold Items.
    if ( is_multisite() ) {
        return get_blog_option( BP_ROOT_BLOG, $threshold_key ); 
    } else {
        return get_option( $threshold_key );
    }

}

/**
  * Exclude Users from Directories and Buddypress Widgets 
  */
function yzm_exclude_users_from_directories( $args ) {

    // Do not exclude in admin.
    if ( ( is_admin() && ! defined( 'DOING_AJAX' ) ) || bp_is_user_friend_requests() ) {
        return $args;
    }

    // Get Hidden Users.
    $hidden_users = yzm_get_reported_items( 'user' );
    
    if ( ! empty( $hidden_users ) ) {

        $excluded = isset( $args['exclude'] )? $args['exclude'] : array();
     
        if ( ! is_array( $excluded ) ) {
            $excluded = explode( ',', $excluded );
        }
        
        $excluded = array_merge( $excluded, $hidden_users );
        
        $args['exclude'] = $excluded;
        
    }
 
    return $args;
}

/**
  * Exclude Groups from Directories and Buddypress Widgets.
  */
function yzm_exclude_groups_from_directories( $args ) {

    // Do not exclude in admin.
    if ( ( is_admin() && ! defined( 'DOING_AJAX' ) ) ) {
        return $args;
    }

    // Get Hidden Groups.
    $hidden_groups = yzm_get_reported_items( 'group' );

    if ( ! empty( $hidden_groups ) ) {

        $excluded = isset( $args['exclude'] )? $args['exclude'] : array();
     
        if ( ! is_array( $excluded ) ) {
            $excluded = explode( ',', $excluded );
        }
        
        $excluded = array_merge( $excluded, $hidden_groups );
        
        $args['exclude'] = $excluded;
        
    }
 
    return $args;

}


/**
  * Exclude Groups from Directories and Buddypress Widgets.
  */
function yzm_exclude_activities_from_directories( $args ) {

    // Do not exclude in admin.
    if ( ( is_admin() && ! defined( 'DOING_AJAX' ) ) ) {
        return $args;
    }

    // Get Hidden Groups.
    $hidden_activities = yzm_get_reported_items( 'activity' );
    // print_r( $hidden_activities );
    if ( ! empty( $hidden_activities ) ) {

        $excluded = isset( $args['exclude'] )? $args['exclude'] : array();
 
        if ( ! is_array( $excluded ) ) {
            $excluded = explode( ',', $excluded );
        }

        $excluded = array_merge( $excluded, $hidden_activities );

        $args['exclude'] = $excluded;

    }
 
    return $args;
}


/**
 * Change Comment Text.
 */
function yzm_show_reported_comments_notice( $content ) {
    
    $hidden_comments = yzm_get_reported_items( 'comment' );

    if ( ! empty( $hidden_comments ) && in_array( bp_get_activity_comment_id(), $hidden_comments ) ) {
        return '<span class="yzm-reported-comment-notice">' . __( 'This comment is pending review!', 'youzer-moderation' ) . '</span>';
    }

    return $content;
}


/**
 * Hide Reported Comments.
 */
function yzm_exclude_comments_from_activities( $comments = null ) {
    
    global $activities_template;

    $comments = ! empty( $comments ) ? $comments : $activities_template->activity;

    if ( is_array( $comments->children ) ) {

        $hidden_comments = yzm_get_reported_items( 'comment' );

        if ( ! empty( $hidden_comments ) ) {

            foreach ( $comments->children as $key => $comment ) {

                if ( in_array( $comment->id, $hidden_comments ) ) {
                    // unset( $activities_template->activity->children[ $key ] );
                    unset( $comments->children[ $key ] );
                }

                if ( isset( $comment->children ) ) {
                    yzm_exclude_comments_from_activities( $comment );
                }
            }
        }

    }

}

/**
 * Hide Reported Message.
 */
function yzm_hide_reported_messages( $threads ) {

    // Get Rported Messages.
    $hidden_messages = yzm_get_reported_items( 'message' );

    if ( ! empty( $hidden_messages ) ) {

        // Hide Reported Messages.
        foreach ( $threads->messages as $key => $message ) {
            if ( in_array( $message->id, $hidden_messages) ) {
                unset( $threads->messages[ $key ]);
            }
        }

        // Re-Index Messages.
        $threads->messages = array_values( $threads->messages );

    }

    return $threads;
}


/**
 * Get Report Type
 */
function yzm_get_report_item_type( $component ) {

    switch ( $component ) {

        case 'user':
            $component = __( 'account', 'youzer-moderation' );
            break;
        
        case 'group':
            $component = __( 'group', 'youzer-moderation' );
            break;
        
        case 'message':
            $component = __( 'message', 'youzer-moderation' );
            break;
        
        case 'activity':
            $component = __( 'activity', 'youzer-moderation' );
            break;
        
        case 'comment':
            $component = __( 'comment', 'youzer-moderation' );
            break;
        
        default:
            break;

    }

    return $component;
}

/**
 * Is Single User Reports.
 */
function yzm_is_single_user_reports() {
    
    if ( isset( $_GET['reports-type'] ) && isset( $_GET['author'] ) ) {
        return true;
    }

    return false;
}

/**
 * Clear Reported Elements !
 */
function yzm_clear_reported_elements( $item_id, $component ) {

    // Get All Users that reported that element !
    $reports_query = new YZM_Query();

    // Get Item Reporters.
    $item_reporters = $reports_query->get_reporters_by_item_id( $item_id, $component );

    if ( empty( $item_reporters ) ) {
        return;
    }

    // Get Users Reports Options Key.
    $user_reports_key = 'yzm_' . $component . '_reports';

    foreach ( $item_reporters as $reporter ) {

        // Get User Reports.
        $user_reports = get_the_author_meta( $user_reports_key, $reporter );

        if ( ! empty( $user_reports ) ) {

            // Delete Closed Report ID.
            foreach ( $user_reports as $key => $reported_item_id ) {
                if ( $reported_item_id == $item_id ) {
                    unset( $user_reports[ $key ] );
                }
            }

            if ( ! empty( $user_reports ) ) {
                // Save Reports.
                update_user_meta( $reporter, $user_reports_key, $user_reports );
            } else {
                // Delete Reports.
                delete_user_meta( $reporter, $user_reports_key );
            }

        }
    }

    if ( $component != 'activity' && $component != 'comment' ) {

        // Get Threshold Reports.
        $threshold_reports = yzm_get_threshold_reports( $component );

        if ( ! empty( $threshold_reports ) ) {

            foreach ( $threshold_reports as $key => $threshold_item_id ) {
                if ( $threshold_item_id == $item_id ) {
                    unset( $threshold_reports[ $key ] );
                }
            }       

            // Theresold Items Key.
            $threshold_key = 'yz_' . $component . '_threshold_reports';


            if ( ! empty( $threshold_reports ) ) {
                
                // Save Reports.
                if ( is_multisite() ) {
                    update_blog_option( BP_ROOT_BLOG, $threshold_key, $threshold_reports ); 
                } else {
                    update_option( $threshold_key, $threshold_reports );
                }

            } else {

                // Delete Reports.
                if ( is_multisite() ) {
                    delete_blog_option( BP_ROOT_BLOG, $threshold_key ); 
                } else {
                    delete_option( $threshold_key );
                }

            }
        }

    }

}

/**
 * Apply Restrictions.
 */
function yzm_apply_restrictions( $user_id, $component, $type ) {

    // Apply Global Restrictions.
    $new_restrictions = yzm_get_restrictions( $component, $type );

    if ( ! empty( $new_restrictions ) ) {
        // Add User Restriction.
        $query = new YZM_Query();
        $restriction_id = $query->add_restriction( array( 'user_id' => $user_id, 'component' => $component, 'type' => $type, 'restrictions' => $new_restrictions, 'time' => current_time( 'mysql' ) ) );
    }

}

/**
 * Get Restrictions.
 */
function yzm_get_restrictions( $component, $type ) {

    // Init Vars.
    $option_name = $type == 'temporary' ? 'yz_rtr' : 'yz_rgr';

    // Get Restrictions.
    $restrictions = yz_option( $option_name );

    if ( empty( $restrictions ) ) {
        return false;
    }

    if ( isset( $restrictions[ $component ] ) ) {

        $active_restrictions = array();

        foreach (  $restrictions[ $component ] as $item => $active ) {
            if ( $active == 'on' ) {
                $active_restrictions[] = $item;
            }
        }

        if ( ! empty( $active_restrictions ) ) {
            return $active_restrictions;
        } else {
            return false;
        }

    }

    return false;

}

/**
 * Flag User as Restricted.
 */
function yzm_update_user_restrictions( $user_id, $type ) {

    // Init Class.
    $query = new YZM_Query();

    // Get Flag Value.
    $flags = get_the_author_meta( 'yz_reports_restrictions', $user_id );
    $flags = ! empty( $flags ) ? $flags : array();

    // Get Restrictions.
    $restrictions = $query->get_user_restrictions( $user_id, $type );

    if ( ! empty( $restrictions ) ) {
        $flags[ $type ] = $restrictions;
    } else {
        if ( isset( $flags[ $type ] ) ) {
            unset( $flags[ $type ] );
        }
    }

    if ( empty( $flags ) ) {
        delete_user_meta( $user_id, 'yz_reports_restrictions' );
    } else {
        update_user_meta( $user_id, 'yz_reports_restrictions', $flags );
    }

}

/**
 * Show Report Button.
 */
function yzm_show_report_button_component( $component ) {

    $show = false;

    if ( is_user_logged_in() ) {
        if ( 'on' == yz_option( 'yz_enable_' . $component . '_reports', 'on' ) &&  yzm_is_user_can_report() ) {
            $show = true;
        }
    } else {
        if ( 'on' == yz_option( 'yz_enable_visitors_reports', 'off' ) && 'on' == yz_option( 'yz_enable_' . $component . '_reports', 'on' ) ) {
            $show = true;
        }
    }

    return apply_filters( 'yzm_show_report_button_component', $show, $component );

}

/**
 * Check if user can report Item.
 */
function yzm_is_user_can_report() {
    
    $can = false;

    // Get roles.
    $reporters = yz_option( 'yz_reporters_roles', array( 'administrator', 'editor', 'subscriber', 'contributor', 'author' ) );

    // echo $reporters;
    if ( $reporters == 'on' ) {
        $can = true;
    } else if ( $reporters != 'off' ) {
    
        // Get Current User Data.
        $user = get_userdata( bp_loggedin_user_id() );

        // Get User Roles.
        $user_roles = (array) $user->roles;

        foreach ( $reporters as $role ) {

            if ( in_array( $role, $user_roles ) ) {
                $can = true;
                break;
            }

        }

    }

    return apply_filters( 'yzm_is_user_can_report', $can );

}

/**
 * Update Restrictions Table.
 */
add_action( 'yzm_update_restrictions', 'yzm_update_restrictions_table' );

function yzm_update_restrictions_table() {

    // Init Query Class.
    $query = new YZM_Query();

    $restrictions = $query->get_active_official_restrictions();

    if ( empty( $restrictions ) ) {
        return;
    }

    foreach ( $restrictions as $restriction ) {
        // Get Restictions Period.
        $restriction_period = yz_option( 'yz_rgr_' . $restriction['component'] . '_period', 60 );
        if ( ! empty( $restriction_period ) && $restriction_period > 0 ) {
            if ( strtotime( $restriction['time'] ) < strtotime( "-$restriction_period day" ) ) {
                $query->end_restriction( $restriction['user_id'], $restriction['component'], 'official' );
            }
        }

    }

}