<?php
/**
 * Plugin Name: Youzer - Buddypress Moderation
 * Plugin URI:  http://youzer.kainelabs.com
 * Description: Advanced moderation tools to take the full control over your community components posts, comments, users, groups, messages.
 * Version:     1.0.3
 * Author:      Youssef Kaine
 * Author URI:  https://www.kainelabs.com
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: youzer-moderation
 * Domain Path: /languages/
 */
if ( ! defined( 'WPINC' ) ) {
    die;
}

/**
 * Check if Youzer Plugin is installed
 */
function yzbm_check_for_youzer_plugin() {

    if ( ! class_exists( 'Youzer' ) ) {

        function yzbm_extension_admin_notice() {

            ?>
            <div class="notice notice-warning is-dismissible">
                <p><?php echo sprintf( __( '<strong> Notice : </strong>Please install and activate <strong><a href="%1s">Youzer</strong></a> plugin to use the <strong>Youzer - Buddypress Moderation</strong> extension.', 'youzer-moderation' ), 'https://codecanyon.net/item/youzer-new-wordpress-user-profiles-era/19716647' ); ?></p>
            </div>
            <?php
        }

        // Show Notice.
        add_action( 'admin_notices', 'yzbm_extension_admin_notice' );

        // Deactivate The Plugin.
        deactivate_plugins( plugin_basename( __FILE__ ) );

        return;

    }
    
}

// Check For Youzer.
add_action( 'admin_init', 'yzbm_check_for_youzer_plugin' );

// Plugin Basename
define( 'YZBM_FILE', __FILE__ );
define( 'YZBM_VERSION', '1.0.3' );
define( 'YZBM_BASENAME', plugin_basename( __FILE__ ) );

// Plugin Path.
define( 'YZBM_PATH', plugin_dir_path( __FILE__ ) );
define( 'YZBM_URL', plugin_dir_url( __FILE__ ) );

/**
 * Init Functions
 */
function youzer_moderation_init() {
    
    // Include Files.
    include YZBM_PATH . 'public/functions/yz-general-functions.php';
    include YZBM_PATH . 'public/functions/yz-email-functions.php';

    // Include Classes
    include YZBM_PATH . 'public/classes/yz-class-query.php';
    include YZBM_PATH . 'public/classes/yz-class-form.php';

    // Init Class
    $form = new YZBM_Form();

    if ( is_admin() ) {
        include YZBM_PATH . 'admin/yz-class-admin.php';
        $admin = new Youzer_Moderation_Admin();
    }

}

add_action( 'bp_include', 'youzer_moderation_init' );

/**
 * Init 
 */
function yzm_init() {

    // Classes.
    include YZBM_PATH . 'public/classes/yz-class-restrictions.php';

    // Init Classes.
    $restrictions = new YZM_Restrictions();

}

add_action( 'bp_init', 'yzm_init' );

/**
 * On Youzer Moderation Activation.
 */
function yzbm_activation() {

    // Include Setup File.    
    require_once YZBM_PATH . 'public/classes/yz-class-setup.php';

    // Init Setup Class.
    $Setup = new YZBM_Setup();

    // Install Youzer Options
    $Setup->install_options();
    $Setup->install_emails();

    // Build Database.
    $Setup->build_database_table();

}

register_activation_hook( __FILE__, 'yzbm_activation' );

/**
 * On Youzer Moderation Deactivation.
 */
function yzbm_deactivation() {
    // Delete Restrictions Cron.
    $timestamp = wp_next_scheduled( 'yzm_update_restrictions' );
    wp_unschedule_event( $timestamp, 'yzm_update_restrictions' );
}

register_deactivation_hook( __FILE__, 'yzbm_deactivation' );

/**
 * Action Links
 */
function yzbm_plugin_action_links( $links ) {
    // Get Youzer Plugin Pages. 
    $panel_url = esc_url( add_query_arg( array( 'page' => 'youzer-panel&tab=moderation' ), admin_url( 'admin.php' ) ) );
    $plugin_url = "https://www.kainelabs.com/downloads/buddypress-moderation-plugin/";
    $documentation_url = 'https://kainelabs.ticksy.com/articles/100015981';
    // Add a few links to the existing links array.
    return array_merge( $links, array(
        'settings' => '<a href="' . $panel_url . '">' . esc_html__( 'Settings', 'youzer-moderation' ) . '</a>',
        'documentation' => '<a href="' . $documentation_url . '">' . esc_html__( 'Documentation',    'youzer-moderation' ) . '</a>',
        'about'    => '<a href="' . $plugin_url . '">' . esc_html__( 'About',    'youzer-moderation' ) . '</a>'
    ) );
}

// Add Plugin Links.
add_filter( 'plugin_action_links_' . YZBM_BASENAME, 'yzbm_plugin_action_links' );

// Add Plugin Links in Multisite..
add_filter( 'network_admin_plugin_action_links_' . YZBM_BASENAME, 'yzbm_plugin_action_links' );


/**
 * Load plugin text domain.
 */
add_action( 'plugins_loaded', 'yzbm_setup_textdomain' );

function yzbm_setup_textdomain() {

    // Get Plugin Domain.
    $domain = 'youzer-moderation';
    
    $locale = apply_filters( 'plugin_locale', get_locale(), $domain );
    
    // Load Translation from the wordprss Languages Directory First.
    load_textdomain( $domain, WP_LANG_DIR . '/plugins/' . $domain . '-' . $locale . '.mo' );
    
    // Load The Current Plugin Translation.
    load_plugin_textdomain( $domain, false, 'youzer-moderation/languages' );

}
