<?php
/**
 * myCRED Youzer Bookmarks - Hook.
 *
 */
class Youzer_Bookmarks_Hook extends myCRED_Hook {

	/**
	 * Construct
	 * Used to set the hook id and default settings.
	 */
	function __construct( $hook_prefs, $type ) {

		parent::__construct( array(
			'id'       => 'youzer_bookmarks',
			'defaults' => array(
				'new_bookmark'   => array(
					'creds' => 0,
					'title' => __( 'New Bookmark', 'youzer' ),
					'log'   => '%plural% for Bookmarking a new post'
				)
			)
		), $hook_prefs, $type );

	}

	/**
	 * Run
	 * Fires by myCRED when the hook is loaded.
	 * Used to hook into any instance needed for this hook
	 * to work.
	 */
	public function run() {

		if ( $this->prefs['new_bookmark']['creds'] != 0 ) {
			add_action( 'yz_after_bookmark_save', array( $this, 'handle_points' ), 10, 2 );
		}

		add_action( 'yz_before_bookmark_delete', array( $this, 'delete_points' ), 20, 2 );

	}

	/**
	 * Add Points.
	 */
	function handle_points( $bookmark_id = null, $user_id  = null ) {

		// Check if follow completed
		if ( $this->core->exclude_user( $user_id ) ) return;

		// Make sure this is unique event
		if ( $this->core->has_entry( 'new_bookmark', $bookmark_id, $user_id ) ) return;

		// Points to initiator
		$this->core->add_creds(
			'new_bookmark',
			$user_id,
			$this->prefs['new_bookmark']['creds'],
			$this->prefs['new_bookmark']['log'],
			$bookmark_id,
			array( 'ref_type' => 'bookmark_id' ),
			$this->mycred_type
		);

	}

	/**
	 * Remove Points.
	 */
	function delete_points( $bookmark_id = null, $user_id = null ) {

		$has_entry = $this->core->has_entry( 'new_bookmark', $bookmark_id, $user_id );

		// Delete Points on Removing Data
		if ( $has_entry ) {
			
			// Get Removed Log Cred
			$removed_cred = yz_mycred_get_log_creds( $user_id, 'new_bookmark', $bookmark_id );
			
			// Delete Log.
			yz_mycred_delete_log( $user_id, 'new_bookmark', $bookmark_id );
			
			// Update balance
			$this->core->update_users_balance( $user_id, - $removed_cred, $this->mycred_type );
			
			return;

		}

	}

	/**
	 * Hook Settings
	 * Needs to be set if the hook has settings.
	 */
	public function preferences() {
		global $Youzer_Mycred;
		$Youzer_Mycred->settings( $this );
	}

}