<?php
/**
 * myCRED Youzer Followers - Hook.
 *
 */
class Youzer_Follows_Hook extends myCRED_Hook {

	/**
	 * Construct
	 * Used to set the hook id and default settings.
	 */
	function __construct( $hook_prefs, $type ) {

		parent::__construct( array(
			'id'       => 'youzer_follows',
			'defaults' => array(
				'add_follow'   => array(
					'creds' => 0,
					'title' => __( 'New Follow', 'youzer' ),
					'log'   => '%plural% for Following'
				),
				'new_follower' => array(
					'creds' => 0,

					'title' => __( 'New Follower', 'youzer' ),
					'log'   => '%plural% for a New Follower'
				)
			)
		), $hook_prefs, $type );

	}

	/**
	 * Run
	 * Fires by myCRED when the hook is loaded.
	 * Used to hook into any instance needed for this hook
	 * to work.
	 */
	public function run() {

		// After Saving Options Action.

		// Follow/Follower
		if ( $this->prefs['add_follow']['creds'] != 0 || $this->prefs['new_follower']['creds'] != 0 ) {
			add_action( 'bp_follow_start_following', array( $this, 'handle_points' ), 10 );
		}

		add_action( 'bp_follow_stop_following', array( $this, 'delete_points' ), 20, 1 );

	}

	/**
	 * Add Points.
	 */
	function handle_points( $follow = null ) {


		$follower_id = $follow->follower_id;
		$leader_id   = $follow->leader_id;

		// Check if follow completed
		if ( $this->core->exclude_user( $follower_id ) ) return;

		// Check if friend is excluded
		if ( $this->core->exclude_user( $leader_id ) ) return;

		// Make sure this is unique event
		if ( $this->core->has_entry( 'add_follow', $leader_id, $follower_id ) ) return;

		// Points to initiator
		$this->core->add_creds(
			'add_follow',
			$follower_id,
			$this->prefs['add_follow']['creds'],
			$this->prefs['add_follow']['log'],
			$leader_id,
			array( 'ref_type' => 'user' ),
			$this->mycred_type
		);

		// Points to friend (ignored if we are deducting points for new friendships)
		if ( $this->prefs['new_follower']['creds'] > 0 ) {

			$this->core->add_creds(
				'new_follower',
				$leader_id,
				$this->prefs['new_follower']['creds'],
				$this->prefs['new_follower']['log'],
				$follower_id,
				array( 'ref_type' => 'user' ),
				$this->mycred_type
			);

		}

	}

	/**
	 * Remove Points.
	 */
	function delete_points( $follow = null ) {


		$follower_id = $follow->follower_id;
		$leader_id   = $follow->leader_id;

		// Delete Points on Removing Data
		if ( $this->core->has_entry( 'add_follow', $leader_id, $follower_id ) ) {
			
			// Get Removed Log Cred
			$removed_cred = yz_mycred_get_log_creds( $follower_id, 'add_follow', $leader_id );
			
			// Delete Log.
			yz_mycred_delete_log( $follower_id, 'add_follow', $leader_id );
			
			// Update balance
			$this->core->update_users_balance( $follower_id, - $removed_cred, $this->mycred_type );
			
		}

		// Delete Points on Removing Data
		if ( $this->core->has_entry( 'new_follower', $follower_id, $leader_id ) ) {
			
			// Get Removed Log Cred
			$removed_cred = yz_mycred_get_log_creds( $leader_id, 'new_follower', $follower_id );
			// Delete Log.
			yz_mycred_delete_log( $leader_id, 'new_follower', $follower_id );
			
			// Update balance
			$this->core->update_users_balance( $leader_id, - $removed_cred, $this->mycred_type );
			
			return;		
		}

	}

	/**
	 * Hook Settings
	 * Needs to be set if the hook has settings.
	 */
	public function preferences() {
		global $Youzer_Mycred;
		$Youzer_Mycred->settings( $this );
	}

}