<?php
/**
 * myCRED Youzer Wall - Hook
 *
 */
class Youzer_Wall_Posts_Hooks extends myCRED_Hook {
	/**
	 * Construct
	 * Used to set the hook id and default settings.
	 */
	function __construct( $hook_prefs, $type ) {

		parent::__construct( array(
			'id'       => 'youzer_wall_posts',
			'defaults' => array(
				'activity_status' => array(
					'creds'         => 1,
					'title' 		=> __( 'New Status Post', 'youzer' ),
					'log'           => '%plural% for new wall status post',
					'limit'         => '0/x'
				),
				'remove_activity_status' => array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete Status Post', 'youzer' ),
					'log'           => '%singular% deduction for removing status post'
				),
				'activity_photo' => array(
					'creds'         => 1,
					'title' 		=> __( 'New Photo Post', 'youzer' ),
					'log'           => '%plural% for new wall photo post',
					'limit'         => '0/x'
				),
				'remove_activity_photo'	=> array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete Photo Post', 'youzer' ),
					'log'           => '%singular% deduction for removing photo post'
				),
				'activity_video' => array(
					'creds'         => 1,
					'title' 		=> __( 'New Video Post', 'youzer' ),
					'log'           => '%plural% for new wall video post',
					'limit'         => '0/x'
				),
				'remove_activity_video'	=> array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete Video Post', 'youzer' ),
					'log'           => '%singular% deduction for removing video post'
				),
				'activity_file' => array(
					'creds'         => 1,
					'title' 		=> __( 'New File Post', 'youzer' ),
					'log'           => '%plural% for new wall file post',
					'limit'         => '0/x'
				),
				'remove_activity_file' => array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete File Post', 'youzer' ),
					'log'           => '%singular% deduction for removing file post'
				),
				'activity_slideshow' => array(
					'creds'         => 1,
					'title' 		=> __( 'New Slideshow Post', 'youzer' ),
					'log'           => '%plural% for new wall slideshow post',
					'limit'         => '0/x'
				),
				'remove_activity_slideshow'	=> array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete Slideshow Post', 'youzer' ),
					'log'           => '%singular% deduction for removing slideshow post'
				),
				'activity_link' => array(
					'creds'         => 1,
					'title' 		=> __( 'New Link Post', 'youzer' ),
					'log'           => '%plural% for new wall link post',
					'limit'         => '0/x'
				),
				'remove_activity_link' => array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete Link Post', 'youzer' ),
					'log'           => '%singular% deduction for removing link post'
				),
				'activity_quote' => array(
					'creds'         => 1,
					'title' 		=> __( 'New Quote Post', 'youzer' ),
					'log'           => '%plural% for new wall quote post',
					'limit'         => '0/x'
				),
				'remove_activity_quote'	=> array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete Quote Post', 'youzer' ),
					'log'           => '%singular% deduction for removing quote post'
				),
				'activity_audio' => array(
					'creds'         => 1,
					'title' 		=> __( 'New Audio Post', 'youzer' ),
					'log'           => '%plural% for new wall audio post',
					'limit'         => '0/x'
				),
				'remove_activity_audio'	=> array(
					'creds'         => '-1',
					'title' 		=> __( 'Delete Audio Post', 'youzer' ),
					'log'           => '%singular% deduction for removing audio post'
				)
			)
		), $hook_prefs, $type );
	
	}

	/**
	 * Run
	 * Fires by myCRED when the hook is loaded.
	 * Used to hook into any instance needed for this hook
	 * to work.
	 */
	public function run() {

		// On Post Addition.
		add_action( 'yz_activity_posted_update', array( $this, 'post_addition' ), 10, 3 );
		
		// On Post Deletion.
		add_action( 'bp_before_activity_delete', array( $this, 'post_deletion' ), 10, 1 );

	}

	/**
	 * Wall Post Addition function.
	 */
	function post_addition( $content = null, $user_id, $activity_id ) {

		// Check if user is excluded (required)
		if ( $this->core->exclude_user( $user_id ) ) return;

		// Get Post Type
		$post_type = $_POST['post_type'];

		if ( ! isset( $this->prefs[ $post_type ] ) ) {
			return;
		}

		$cred_id = 'yz_wall_' . $post_type;

		// Limit
		if ( $this->over_hook_limit( $post_type, $cred_id, $user_id ) ) return;

		// Execute
		$this->core->add_creds(
			$cred_id,
			$user_id,
			$this->prefs[ $post_type ]['creds'],
			$this->prefs[ $post_type ]['log'],
			$activity_id,
			'bp_activity',
			$this->mycred_type
		);

	}

	/**
	 * Wall Post Deletion function.
	 */
	function post_deletion( $args ) {

		if ( ! isset( $args['user_id'] ) || $args['user_id'] === false ) return;

		$user_id = absint( $args['user_id'] );

		// Check if user is excluded (required)
		if ( $this->core->exclude_user( $user_id ) ) return;

		// Get Activity.
		$activity = new BP_Activity_Activity( $args['id'] );

		// Get Post Type
		$post_type = 'remove_' . $activity->type;

		if ( ! isset( $this->prefs[ $post_type ] ) ) {
			return;
		}

		$cred_id = 'yz_wall_' . $post_type;

		// Limit
		if ( $this->over_hook_limit( $post_type, $cred_id, $user_id ) ) return;

		// Execute
		$this->core->add_creds(
			$cred_id,
			$user_id,
			$this->prefs[ $post_type ]['creds'],
			$this->prefs[ $post_type ]['log'],
			0,
			$args,
			$this->mycred_type
		);

	}

	/**
	 * Hook Settings
	 * Needs to be set if the hook has settings.
	 */
	 public function preferences() {

		// Our settings are available under $this->prefs
		$prefs = $this->prefs;

		?>

		<?php foreach ( $prefs as $key => $value ) : ?>
		
		<div class="hook-instance">
			<h3><?php echo $prefs[ $key ]['title']; ?></h3>
			<div class="row">
				<div class="col-lg-2 col-md-6 col-sm-12 col-xs-12">
					<div class="form-group">
						<label for="<?php echo $this->field_id( array( $key, 'creds' ) ); ?>"><?php echo $this->core->plural(); ?></label>
						<input type="text" name="<?php echo $this->field_name( array( $key, 'creds' ) ); ?>" id="<?php echo $this->field_id( array( $key, 'creds' ) ); ?>" value="<?php echo $this->core->number( $prefs[ $key ]['creds'] ); ?>" class="form-control" />
					</div>
				</div>
				<?php if ( isset( $prefs[ $key ]['limit'] ) ) : ?>
				<div class="col-lg-4 col-md-6 col-sm-12 col-xs-12">
					<div class="form-group">
						<label for="<?php echo $this->field_id( array(  $key, 'limit' ) ); ?>"><?php _e( 'Limit', 'mycred' ); ?></label>
						<?php echo $this->hook_limit_setting( $this->field_name( array( $key, 'limit' ) ), $this->field_id( array( $key, 'limit' ) ), $prefs[ $key ]['limit'] ); ?>
					</div>
				</div>
				<?php endif; ?>
				<div class="col-lg-6 col-md-6 col-sm-12 col-xs-12">
					<div class="form-group">
						<label for="<?php echo $this->field_id( array( $key, 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
						<input type="text" name="<?php echo $this->field_name( array( $key, 'log' ) ); ?>" id="<?php echo $this->field_id( array( $key, 'log' ) ); ?>" placeholder="<?php _e( 'required', 'mycred' ); ?>" value="<?php echo esc_attr( $prefs[ $key ]['log'] ); ?>" class="form-control" />
						<span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
					</div>
				</div>
			</div>
		</div>
		
		<?php endforeach; ?>

		<?php 
	}

}