<?php
/**
 * myCRED Youzer Reviews - Hook.
 *
 */
class Youzer_Reactions_Hook extends myCRED_Hook {

	/**
	 * Construct
	 * Used to set the hook id and default settings.
	 */
	function __construct( $hook_prefs, $type ) {

		parent::__construct( array(
			'id'       => 'youzer_reactions',
			'defaults' => array(
				'new_reaction'   => array(
					'creds' => 0,
					'title' => __( 'New Reaction', 'youzer' ),
					'log'   => '%plural% for reacting to a new post'
				)
			)
		), $hook_prefs, $type );

	}

	/**
	 * Run
	 * Fires by myCRED when the hook is loaded.
	 * Used to hook into any instance needed for this hook
	 * to work.
	 */
	public function run() {

		if ( $this->prefs['new_reaction']['creds'] != 0 ) {
			add_action( 'yzpr_after_adding_post_reaction', array( $this, 'add_points' ), 10, 2 );
		}

		add_action( 'yzpr_after_delete_post_reaction', array( $this, 'delete_points' ), 20, 2 );

	}

	/**
	 * Add Points.
	 */
	function add_points( $reaction_id = null, $data  = null ) {

		$user_id = isset( $data['user_id'] ) ? $data['user_id'] : null;
		
		if ( empty( $user_id ) ) {
			return;
		}

		// Check if follow completed
		if ( $this->core->exclude_user( $user_id ) ) return;

		// Make sure this is unique event
		if ( $this->core->has_entry( 'new_reaction', $reaction_id, $user_id ) ) return;

		// Points to initiator
		$this->core->add_creds(
			'new_reaction',
			$user_id,
			$this->prefs['new_reaction']['creds'],
			$this->prefs['new_reaction']['log'],
			$reaction_id,
			array( 'ref_type' => 'reaction_id' ),
			$this->mycred_type
		);

	}

	/**
	 * Remove Points.
	 */
	function delete_points( $reaction = null, $activity_id = null ) {

		$user_id = bp_loggedin_user_id();

		$reaction_id = isset( $reaction['id'] ) ?  $reaction['id'] : null;

		if ( empty( $user_id ) || empty( $reaction_id ) ) {
			return;
		}

		$has_entry = $this->core->has_entry( 'new_reaction', $reaction_id, $user_id );

		// Delete Points on Removing Data
		if ( $has_entry ) {
			
			// Get Removed Log Cred
			$removed_cred = yz_mycred_get_log_creds( $user_id, 'new_reaction', $reaction_id );
			
			// Delete Log.
			yz_mycred_delete_log( $user_id, 'new_reaction', $reaction_id );
			
			// Update balance
			$this->core->update_users_balance( $user_id, - $removed_cred, $this->mycred_type );
			
			return;

		}

	}

	/**
	 * Hook Settings
	 * Needs to be set if the hook has settings.
	 */
	public function preferences() {
		global $Youzer_Mycred;
		$Youzer_Mycred->settings( $this );
	}

}