<?php

/**
 * Profile Completeness Redirect Functions.
 */
class YZPC_Redirects {
	
	function __construct() {
		
		add_action( 'bp_template_redirect', array( &$this, 'redirect_user' ), 1 );

	}

	/**
	 * Check if the user should be redirected or not.
	 */
	function redirect_user() {

		// If user is not logged-in or the current user is an admin stop.
		if ( ! is_user_logged_in() ) {
			return;
		}

		// Get User ID.
		$user_id = get_current_user_id();


		// // Check if the user profile Marked As Complete.
		// if ( yzpc_is_profile_complete( $user_id ) ) {
		// 	return;
		// }

		// Get The First Forced Fields.
		$first_field = yzpc_get_first_field_data( 'forced', $user_id );

		if ( ! $first_field ) {
			return;
		}

		// Shpw Field Message.
		$message =$this->get_field_message( $first_field, $user_id );

		// Add Notice Title
		add_filter( 'bp_core_render_message_content', 'yzpc_add_account_page_notice_title');

		bp_core_add_message( $message, 'success' );

		$redirect_data = $this->get_redirect_page( $first_field, $user_id );

		// if Is Account Page Stop.
		if ( $redirect_data['allow_page'] === 'true' ) {
			return;
		}

		// Redirect User.
		bp_core_redirect( $redirect_data['url'] );

	}

	/**
	 * Get Redirect Page.
	 */
	function get_redirect_page( $field_data, $user_id ) {

		// Init Vars.
		$redirect_data = array();

		if ( is_numeric( $field_data['parent'] ) ) {
			// Get Profile Settings Fields Redirect Data.
			$redirect_data = array(
				'allow_page' => bp_is_current_component( 'xprofile' ) && bp_get_current_profile_group_id() == $field_data['parent']? 'true' : 'false',
				'url' => yz_get_profile_settings_url( 'edit/group/' . $field_data['parent'], $user_id )
			);
		} elseif ( 'images' == $field_data['parent'] ) {
			
			// Get Element Data.
			$redirect_data = $this->get_images_redirect_data( $field_data['id'], $user_id );

		} elseif( is_string( $field_data['parent'] ) ) {

			// Get Redirect Data.
			$allow_page = bp_is_current_component( 'widgets-settings' ) && bp_current_action() == $field_data['parent'] ? 'true' : 'false';
			$redirect_url = yz_get_widgets_settings_url( $field_data['parent'], $user_id );
 
            if ( 'social_networks' == $field_data['parent'] ) {
				$allow_page = bp_is_current_component( 'profile' ) && bp_current_action() == 'social-networks' ? 'true' : 'false';
                $redirect_url = yz_get_profile_settings_url( 'social-networks' );
            }

			$redirect_data = array( 'allow_page' => $allow_page, 'url' => $redirect_url );

		}

		return apply_filters( 'yzpc_get_redirect_page', $redirect_data, $field_data );
	}

	/**
	 * Get Redirect Page.
	 */
	function get_field_message( $field_data, $user_id ) {

		// Init Vars.
		$message = '';
		$titles = array();
		
		// Get Unfilled Fields
        $unfilled_fields = yzpc_get_user_unfilled_fields( 'forced', $user_id );

        // Get Fields By Type.
		$fields = yzpc_get_fields_sorted_by_types( $unfilled_fields );

		if ( is_numeric( $field_data['parent'] ) ) {
			
			// Get Group ID.
			$group_id = $field_data['parent'];

			// Get Group.
			$group = new BP_XProfile_Group( $group_id );

			// Get The current Group.
        	$current_group = isset( $fields['xprofile'][ $group_id ] ) ? $fields['xprofile'][ $group_id ] : null;

        	if ( empty( $current_group ) ) {
        		return;
        	}

        	foreach ( $current_group as $field_id => $field_title ) {
            	// Get Field Title.
        		$titles[] = $field_title;
        	}

        	// Get Field Word
        	$field_word = _n( 'field', 'fields', count( $titles ), 'youzer-profile-completeness' );

        	// Get Message.
        	$message = sprintf( __( 'Please make sure to fill the %1s group "%2s" %3s.', 'youzer-profile-completeness' ), $group->name, implode( ', ', $titles ), $field_word );

		} elseif( 'images' == $field_data['parent'] ) {

			// Get Element Data.
			$data = $this->get_images_redirect_data( $field_data['id'], $user_id );

			// Get The Message.
			$message = $data['message'];

		} elseif( is_string( $field_data['parent'] ) ) {

			// Get Widget Name.
			$widget_name = $field_data['parent'];

            // Get Widget Data.
            $widget_data = yz_get_profile_widget_args( $widget_name );

            if ( isset( $youzer_widgets[ $widget_name ]['id'] ) ) {
            	$message = sprintf( __( 'Please make sure to fill the "%s" fields.', 'youzer-profile-completeness' ), $widget_data['widget_title'] );
            } else {
            	
            	$current_widget = isset( $fields['widgets'][ $widget_name ] ) ? $fields['widgets'][ $widget_name ] : null;

            	if ( empty( $current_widget ) ) {
            		return;
            	}
            	
            	foreach ( $current_widget as $field_key => $field_title ) {
            		$titles[] = $field_title;
            	}

            	$field_word = _n( 'field', 'fields', count( $titles ), 'youzer-profile-completeness' );

            	$message = sprintf( __( 'Please make sure to fill the %1s widget "%2s" %3s.', 'youzer-profile-completeness' ), $widget_data['widget_title'], implode( ', ', $titles ), $field_word );
            }

		}

		return apply_filters( 'yzpc_field_message', $message, $field_data );
	}

	/**
	 * Get Images Elements Data.
	 **/
	function get_images_redirect_data( $field_id, $user_id ) {

		$data = array();

		if ( 'change-avatar' == $field_id ) {

			// Get Profile Avatar Data.
			$data = array(
				'message' =>__( "Please upload your profile avatar.", 'youzer-profile-completeness' ),
				'allow_page' => bp_is_my_profile() && bp_is_user_change_avatar() ? 'true' : 'false',
				'url' => yz_get_profile_settings_url( 'change-avatar', $user_id )
			);

		} elseif ( 'change-cover-image' == $field_id ) {

			// Get Profile Cover Data.
			$data = array(
				'message' =>__( "Please upload your profile cover image.", 'youzer-profile-completeness' ),
				'allow_page' => bp_is_my_profile() && bp_is_user_change_cover_image() ? 'true' : 'false',
				'url' => yz_get_profile_settings_url( 'change-cover-image', $user_id )
			);
		}

		return apply_filters( 'yzpc_images_redirect_data', $data, $field_id, $user_id );
	}

}