<?php

/**
 * Profile Completeness Restrictions Functions.
 */
class YZPC_Restrictions {
	
	function __construct() {

		// Init Restrictions.
		$this->init();

	}

	/**
	 * Init Restrictions.
	 */
	function init() {

		// Get Restrictions.
		$restrictions = get_option( 'yzpc_restrictions' );

		if ( empty( $restrictions ) ) {
			return;
		}
		
		if ( isset( $restrictions['groups'] ) ) {
			// Disabe Groups Join & Request Membership Buttons.
			add_filter( 'bp_get_group_join_button', '__return_false' );

		}
		
		if ( isset( $restrictions['posts'] ) ) {
			// Posting Form.
			add_filter( 'yz_is_wall_posting_form_active', '__return_false' );
		}

		if ( isset( $restrictions['likes'] ) ) {
			// Disable Posts Likes.
			add_filter( 'bp_activity_can_favorite', '__return_false' );
		}
		
		if ( isset( $restrictions['comments'] ) ) {
			// Disable Posts Comments.
			add_filter( 'bp_activity_can_comment', '__return_false' );
		}

		if ( isset( $restrictions['replies'] ) ) {
			// Disable Comments Reply.
			add_filter( 'bp_activity_can_comment_reply', '__return_false' );
		}

		if ( isset( $restrictions['delete_posts'] ) ) {
			// Disable Posts Delete.
			add_filter( 'bp_activity_user_can_delete', '__return_false' );
		}

		if ( isset( $restrictions['reviews'] ) ) {
			// Disable Reviews.
			add_filter( 'yz_display_user_review_tool', '__return_false');
		}

		if ( isset( $restrictions['bookmarks'] ) ) {
			// Disable Bookmarks.
			add_filter( 'yz_is_bookmarks_active', '__return_false' );
		}
		
		if ( isset( $restrictions['follows'] ) ) {
			// Remove Follows System.
			add_filter( 'bp_follow_get_add_follow_button', '__return_false' );
		}

		if ( isset( $restrictions['messages'] ) ) {
			// Disable Send Message Button.
			add_filter('yz_get_send_private_message_button', '__return_false' );
			// Remove Compose Message Tab.
			bp_core_remove_subnav_item( 'messages', 'compose' );
			// Hide Sending Messgaes Replies Form.
			add_filter( 'yz_display_send_message_reply_form', '__return_false' );
		}

		if ( isset( $restrictions['friends'] ) ) {
			// Disable Add Friend Button.
			add_filter( 'bp_get_add_friend_button', '__return_false' );
		}

		do_action( 'yzpc_after_restrictions' );
	}

}