<?php

/**
 * Profile Completeness User Functions.
 */
class YZPC_User {
	
	function __construct() {
		
		// Update Options After Upload / Delete Cover Image
		add_action( 'xprofile_cover_image_uploaded', array( &$this, 'update_user_fields' ) );
		add_action( 'xprofile_cover_image_deleted', array( &$this, 'update_user_fields' ) );
		
		// Update Options After Upload / Delete Avatar Image
		add_action( 'bp_core_delete_existing_avatar', array( &$this, 'update_user_fields' ) );
		add_action( 'xprofile_avatar_uploaded', array( &$this, 'update_user_fields' ) );

		// Actions
		add_action( 'yz_account_after_delete_photo', array( &$this, 'update_user_fields' ) );
		add_action( 'youzer_after_save_user_settings', array( &$this, 'update_user_fields' ) );
		add_action( 'xprofile_profile_field_data_updated', array( &$this, 'update_user_fields' ) );
		add_action( 'xprofile_updated_profile', array( &$this, 'check_after_xprofile_data_save' ) );

		// Check Fields After Updating Settings.
		add_action( 'yzpc_is_profile_complete_after_updating_settings', array( &$this, 'check_user_necessary_field' ) );
		
	}

	/**
	 * Check User Fields After Saving Xprofile fields.
	 */
	function check_after_xprofile_data_save( $data = null ) {

		// Check User Necessary Fields.
		$this->check_user_necessary_field( $data );

	}

	/**
	 *  On Saving Elements
	 */
	function update_user_fields( $data = null ) {

		// Get User ID.
		$user_id = bp_displayed_user_id();

		// Check User Necessary Fields.
		$this->check_user_necessary_field( $user_id );

	}

	/**
	 * Check if all the forced fields are still filled after user updating fields.
	 */
	function check_user_necessary_field( $user_id = null ) {

		if ( empty( $user_id ) ) {
			return;
		}

	    // Init Var.
	    $update_count = false;
	    $is_complete = false;

	    // Fields Status to save.
	    $fields_status = array( 'forced', 'required' );
	    
	    // Check Fields.
	    foreach ( $fields_status as $status ) {

	        // Get User Unfilled Fields
	        $unfilled = yzpc_get_first_field_data( $status, $user_id, false );

	        if ( ! empty( $unfilled ) ) {
	            delete_user_meta( $user_id, 'yzpc_' . $status . '_fields_completed' );
	        }

	    }

	    // Get User Filled Fields.
	    $filled_fields = $this->get_user_filled_fields( $user_id );
	    
	    // Get Fields Count.
	    $filled_fields_count = count( $filled_fields );
	    
	    // Update Fields Count. 
	    // update_user_meta( $user_id, 'yzpc_filled_fields_count2', $filled_fields );
	    update_user_meta( $user_id, 'yzpc_filled_fields_count', $filled_fields_count );

	    // If All Fields Are Complete Mark Account as Complete.
	    if ( $filled_fields_count == yzpc_get_total_fields_number() ) {

	    	// Set Flag.
	    	$is_complete = true;

	        update_user_meta( $user_id, 'yzpc_profile_complete', 1 );

	       	// Mark Account As Verified
	       	if ( 'on' == yz_option( 'yzpc_verify_complete_profiles', 'off' ) ) {
				update_user_meta( $user_id, 'yz_account_verified', 'on' );
	       	}

	        // Save Last Time Profile Was Marked As Complete.
	        update_user_meta( $user_id, 'yzpc_all_fields_completed', current_time( 'timestamp' ) );

	    } else {

	       	// Mark Account As Verified
	       	if ( 'on' == yz_option( 'yzpc_verify_complete_profiles', 'off' ) ) {
				delete_user_meta( $user_id, 'yz_account_verified' );
	       	}

	       	// Reset Completeness Widget Apperance.
			delete_user_meta( $user_id, 'yzpc_remove_completeness_widget' );

	        // Remove Complete Profile FLAG.
	        delete_user_meta( $user_id, 'yzpc_profile_complete' );

	        // Remove Last Time Profile Was Marked As Complete.
	        delete_user_meta( $user_id, 'yzpc_all_fields_completed' );

	    }

        // Save Last Time Profile Was Marked As Complete.
        update_user_meta( $user_id, 'yzpc_last_time_fields_updated', current_time( 'timestamp' ) );

	    // Remove Incomplete Profiles Ids Transient if the options were updated.
	    delete_transient( 'yzpc_incomplete_profiles' );

	    if ( $is_complete ) {
	    	do_action( 'yz_after_account_marked_as_complete', $user_id );
	    }
	}

	/**
	 * Get User Filled Fields.
	 */
	function get_user_filled_fields( $user_id ) {

	    // Get Completeness Fields.
	    $forced_fields = yzpc_get_fields( 'forced' );
	    $required_fields = yzpc_get_fields( 'required' );

	    // Completeness Fields.
	    $completeness_fields = array_merge_recursive( $forced_fields , $required_fields );

	    if ( empty( $completeness_fields ) ) {
	        return;
	    }

	    $filled = array();

	    foreach ( $completeness_fields as $parent => $field ) {

	    	if ( ! is_array( $field ) ) {
	    		continue;
	    	}

	        foreach ( $field as $key => $field_id ) {

	            if ( is_numeric( $parent ) ) {

	                if ( yzpc_is_field_available_for_current_member_type( $user_id, $field_id ) ) {
		                // Get Field Value.
		                $field_value = bp_get_profile_field_data( array( 'user_id' => $user_id, 'field' => $field_id ) );
	                } else {
	                    $field_value = 'filled';
	                }

	            } elseif ( 'images' == $parent ) {
	                
	                if ( $field_id == 'change-cover-image' ) {
	                    $field_value = bp_attachments_get_user_has_cover_image( $user_id );
	                } elseif ( $field_id == 'change-avatar' ) {
	                    $field_value = yzpc_get_user_has_avatar( $user_id );
	                }

	            } elseif ( is_string( $parent ) ) {

	                // Get Field Value.
	                $field_value = yz_data( $field_id, $user_id );

	                if ( 'post' == $parent && ! user_can( $user_id, 'edit_posts' ) ) {
	                    $field_value = 'filled';
	                }

	            }

	            if ( ! empty( $field_value ) ) {
	                $filled[] = $field_id;
	            }

	        }
	    }

	    return apply_filters( 'yzpc_get_user_filled_fields', $filled, $user_id );

	}

}