<?php

/**
 * Profile Completeness Widget Functions.
 */
class YZPC_Widget {
	
	function __construct() {

		// Actions
		add_action( 'wp_ajax_yz_get_profile_completeness_widget', array( &$this, 'get_widget_content' ) );
		add_action( 'wp_ajax_yz_remove_user_completeness_widget', array( &$this, 'remove_user_completeness_widget' ) );
		add_action( 'yz_profile_sidebar', array( &$this, 'get_widget' ),  1 );
		
		// Profile Completeness Shortcode.
		add_shortcode( 'youzer_profile_completeness', array( &$this, 'shortcode' ) );

	}

	/**
	 * Profile Completeness Shortcode
	 */
	function shortcode( $atts = null ) {

	    if ( 'on' != yzpc_is_profile_completeness_active( bp_loggedin_user_id() ) ) {
	        return;
	    }

	    // Get Args.
	    $args = shortcode_atts(
	        array(
	            'user_id' => bp_loggedin_user_id(),
	        ), $atts, 'yz_profile_completeness_shortcode_args' );

	    ob_start();

	    // Get Shortcode Content.
	    $this->get_widget( $args );

	    return ob_get_clean();

	}

	/**
	 * Get Profile Completeness Widget.
	 */
	function get_widget( $args = null )  {
		
	    // Only Site Admin and Profile Owner Can See Their Profile Completeness.
	    if ( bp_is_user() && ! bp_core_can_edit_settings() ) {
	        return;
	    }

		// Get User ID.
		$user_id = isset( $args['user_id'] ) ? $args['user_id'] : bp_displayed_user_id();

	    if ( 'on' != yzpc_is_profile_completeness_active( $user_id ) ) {
	    	return;
	    }

		// Check Widget Appearance.
		if ( get_the_author_meta( 'yzpc_remove_completeness_widget', $user_id ) ) {
			return;
		}

	    // Call CSS.
	    wp_enqueue_style( 'yz-profile-completeness', YZPC_URL . 'assets/yz-profile-completeness.min.css' ); 

	    // Call JS.
	    wp_enqueue_script( 'yz-profile-completeness', YZPC_URL . 'assets/yz-profile-completeness.min.js' ); 

	    // Get Scripts.
	    wp_enqueue_script( 'yz-circle-progress', YZ_PA . 'js/circle-progress.min.js', array( 'jquery' ), false, true );

	    $elements = get_option( 'yzpc_box_items' );

	    ?>

	    <div class="yzpc-widget-container" data-user-id="<?php echo $user_id; ?>">

	        <div class="yz-loader-wrapper">

		        <div class="yz-loader-pc-header yz-loader-wrapper-padding" style="text-align: center;">
		            <div class="yz-loader-pcimage yz-loader-image-radius" style="margin-bottom: 30px;"></div>
		            
		            <div class="yz-loader-text">
		              <div class="yz-loader-text-line"></div>
		              <div class="yz-loader-text-line"></div>
		              <div class="yz-loader-text-line"></div>
		            </div>

		        </div>

		        <?php if ( ! empty( $elements ) ) : ?>
		        <div class="yz-loader-wrapper-padding yz-loader-items-margin" style="border-top: 1px solid #f4f4f4;">
		        	<?php foreach ( $elements as $element ) : ?>
				         <div class="yz-loader-wrapper-cell" >
			                <div class="yz-loader-image yz-loader-image-radius"></div>
			                <div class="yz-loader-text">
			                  <div class="yz-loader-text-line"></div>
			                  <div class="yz-loader-text-line"></div>
			                  <div class="yz-loader-text-line"></div>
			                  <div class="yz-loader-text-line"></div>
			                </div>
			            </div>
		        	<?php endforeach; ?>

		        </div>
	        <?php endif; ?>
	        </div>

	    </div>
	    <?php
	}

	/**
	 * Get Profile Widget Content.
	 */
	function get_widget_content() {

		if ( ! isset( $_POST['user_id'] ) || empty( $_POST['user_id'] ) ) {
			return;
		}

	    ob_start();

	    $this->get_content( array( 'user_id' => $_POST['user_id'] ) );

	    $content = ob_get_clean();

	    echo $content;

	    wp_die();
	}

	/**
	 * Get profile completeness content.
	 */
	function get_content( $args = null ) {
	    
	    // Get User ID
	    $user_id = isset( $args['user_id'] ) ? $args['user_id'] : bp_displayed_user_id();

	    // Get Required Fields.
	    $required_fields = yzpc_get_user_unfilled_fields( 'required', $user_id );

	    // Get Profile Completeness Value.
	    $completeness_percent = $this->get_profile_completeness_percent( $user_id );

	    $box_elements = get_option( 'yzpc_box_items' );


	    ?>

	    <div class="yzpc-widget">
	        <div class="yzpc-widget-head">
	            
	            <div class="yzpc-head-circle">
	                        
	                <div class="yzpc-circle" data-value="<?php echo $completeness_percent / 100; ?>" data-percent="<?php echo $completeness_percent . '%'; ?>" data-size="120" data-line-cap="round" data-thickness="10" data-animation-start-value="1.0" data-fill='{"gradient": [ "#ff2871", "#ffeb3b"] }'><span class="yzpc-circle-percent"></span></div>                
	            </div>

	            <div class="yzpc-head-content">
	                <?php

	                // Get Widget DATA.                
	                if ( $completeness_percent == 100 ) {
	                    $widget_icon = 'fas fa-check';
	                    $widget_title = __( 'Your profile is complete now !', 'youzer-profile-completeness' );
	                    $widget_description = __( 'Thank you for filling all the details. your profile looks great now.', 'youzer-profile-completeness' );
	                } else {
	                    $widget_icon = 'fas fa-tasks';
	                    $widget_title = __( 'Complete your profile', 'youzer-profile-completeness' );
	                    $widget_description = __( 'Filling your profile details will help you to meet the right people.', 'youzer-profile-completeness' );
	                }

	                ?>

	                <div class="yzpc-widget-title"><i class="fas fa-<?php echo $widget_icon; ?>"></i><?php echo $widget_title; ?></div>
	                <div class="yzpc-widget-description"><?php echo $widget_description; ?></div>
	            </div>
	        </div>

	        <?php
	            // Get Fields By type.
	            $fields = yzpc_get_fields_sorted_by_types( $required_fields );
	        ?>

	        <?php if ( ! empty( $box_elements ) ) : ?>
	        
	        <div class="yzpc-tasks">

	            <?php if ( isset( $box_elements['xprofile'] ) ) : ?>
            
            	<?php $xprofile_icon = ! empty( $fields['xprofile'] ) ? 'fas fa-globe-asia' : 'fas fa-check'; ?>
            	<?php $xprofile_description = ! empty( $fields['xprofile'] ) ? __( 'Please fill your profile information.', 'youzer-profile-completeness' ) : __( 'All your required profile information fields are completed. ', 'youzer-profile-completeness' ); ?>

	            <div class="yzpc-task yzpc-public-info">
	                <div class="yzpc-task-head">
	                    <div class="yzpc-item-icon"><i class="<?php echo $xprofile_icon ?>"></i></div>
	                    <div class="yzpc-item-content">
	                        <div class="yzpc-item-title"><?php _e( 'Profile Information', 'youzer-profile-completeness' ); ?></div>
	                        <div class="yzpc-item-description"><?php echo $xprofile_description; ?></div>
	                    </div>
	                    <?php if ( ! empty( $fields['xprofile'] ) ) echo '<div class="yzpc-arrow-right yzpc-show-fields"></div>'; ?>
	                </div>

	                <?php 

	                	if ( isset( $fields['xprofile'] ) && ! empty( $fields['xprofile'] ) ) {

		                    echo '<div class="yzpc-fields yzpc-profile-info-fields"><div class="yzpc-fields-content">';
		                    
		                    foreach ( $fields['xprofile'] as $group_id => $field ) {

		                        // Get Fields Group.
		                        $group = new BP_XProfile_Group( $group_id );
		                        
		                        // Get Group Icon.                        
		                        $group_icon = yz_get_xprofile_group_icon( $group_id );

		                        // Get Group Url.
		                        $field_url = yz_get_profile_settings_url( 'edit/group/' . $group_id, $user_id );

		                        echo '<div class="yzpc-fields-parent-item"><i class="' . $group_icon . '"></i>' . $group->name . '<div class="yzpc-arrow-bottom"></div></div>';
		                        
		                        echo '<div class="yzpc-parent-fields-content">';
		                        
		                        foreach ( $field as $field_key => $field_title ) {
		                            echo '<a class="yzpc-field-item" href="' . $field_url . '/#yz_field_' . $field_key . '"><i class="far fa-edit"></i>' . $field_title . '<div class="yzpc-arrow-right"></div></a>';
		                        }

		                        echo '</div>';
		                    }

		                    echo '</div></div>';
	                	}

	                ?>

	            </div>
	            
	            <?php endif; ?>

	            <?php if ( isset( $box_elements['images'] ) ) : ?>

	            <div class="yzpc-task yzpc-profile-images">

                	<?php $image_icon = ! empty( $fields['images'] ) ? 'fas fa-camera' : 'fas fa-check'; ?>
                	<?php $image_description = ! empty( $fields['images'] ) ? __( 'Please upload an avatar and a cover for your account.', 'youzer-profile-completeness' ) : __( 'All your profile required images are uploaded successfuly.', 'youzer-profile-completeness' ); ?>
	                <div class="yzpc-task-head">
	                    <div class="yzpc-item-icon"><i class="<?php echo $image_icon; ?>"></i></div>
	                    <div class="yzpc-item-content">
	                        <div class="yzpc-item-title"><?php _e( 'Profile Images', 'youzer-profile-completeness' ); ?></div>
	                        <div class="yzpc-item-description"><?php echo $image_description; ?></div>
	                    </div>
	                    <?php if ( ! empty( $fields['images'] ) ) echo '<div class="yzpc-arrow-right yzpc-show-fields"></div>'; ?>
	                </div>

	                <?php
	                    
	                    if ( isset( $fields['images'] ) && ! empty( $fields['images'] ) ) {

	                    	echo '<div class="yzpc-fields yzpc-profile-images-fields"><div class="yzpc-fields-content">';

		                    foreach ( $fields['images'] as $element => $title ) {

		                        if ( $element == 'change-avatar' ) {

		                            // Get Group Url.
		                            $field_url = yz_get_profile_settings_url( 'change-avatar' );

		                            echo '<a class="yzpc-fields-parent-item" href="' . $field_url . '"><i class="fas fa-user-circle"></i>' . $title . '<div class="yzpc-arrow-right"></div></a>';

		                        }

		                        if ( $element == 'change-cover-image' ) {

		                            // Get Group Url.
		                            $field_url = yz_get_profile_settings_url( 'change-cover-image' );

		                            echo '<a class="yzpc-fields-parent-item" href="' . $field_url . '"><i class="fas fa-image"></i>' . $title . '<div class="yzpc-arrow-right"></div></a>';

		                        }

		                    }

		                    echo '</div></div>';

	                    }

	                ?>

	            </div>

	            <?php endif; ?>
	            
	            <?php if ( isset( $box_elements['widgets'] ) ) : ?>

	            <div class="yzpc-task yzpc-profile-widgets">
	            
                	<?php $widget_icon = ! empty( $fields['widgets'] ) ? 'fas fa-th-list' : 'fas fa-check'; ?>
                	<?php $widget_description = ! empty( $fields['widgets'] ) ? __( 'Please fill your profile widgets.', 'youzer-profile-completeness' ) : __( 'All your required profile widgets fields are completed.', 'youzer-profile-completeness' ); ?>
	                <div class="yzpc-task-head">
	                    <div class="yzpc-item-icon"><i class="<?php echo $widget_icon; ?>"></i></div>
	                    <div class="yzpc-item-content">
	                        <div class="yzpc-item-title"><?php _e( 'Profile Widgets', 'youzer-profile-completeness' ); ?></div>
	                        <div class="yzpc-item-description"><?php echo $widget_description; ?></div>
	                    </div>
	                    <?php if ( ! empty( $fields['widgets'] ) ) echo '<div class="yzpc-arrow-right yzpc-show-fields"></div>'; ?>
	                </div>

	                <?php

	                	if ( ! empty( $fields['widgets'] ) ) {

		                    echo '<div class="yzpc-fields yzpc-profile-widgets-fields"><div class="yzpc-fields-content">';

		                    foreach ( $fields['widgets'] as $widget_name => $field ) {
		                        
		                        // Get Youzer Widgets.
		                        $youzer_widgets = yz_user_widgets_fields();

		                        // Get Widget Settings Url.
		                        $field_url = yz_get_widgets_settings_url( $widget_name, $user_id );

		                        if ( 'social_networks' == $widget_name ) {
		                            $field_url = yz_get_profile_settings_url( 'social-networks' );
		                        }

		                        // Get Widget Data.
		                        $widget_data = yz_get_profile_widget_args( $widget_name );

		                        $widget_title = apply_filters( 'yzpc_profile_widget_name', $widget_data['widget_title'] );

		                        if ( isset( $youzer_widgets[ $widget_name ]['id'] ) ) {

		                            echo '<a class="yzpc-fields-parent-item" href="' . $field_url . '"><i class="' . $widget_data['widget_icon'] . '"></i>' . $widget_title . '<div class="yzpc-arrow-right"></div></a>';

		                        } else {

		                            echo '<div class="yzpc-fields-parent-item"><i class="' . $widget_data['widget_icon'] . '"></i>' . $widget_title . '<div class="yzpc-arrow-bottom"></div></div>';

		                            echo '<div class="yzpc-parent-fields-content">';

		                            foreach ( $field as $field_key => $field_title ) {

		                                echo '<a class="yzpc-field-item" href="' . $field_url . '"><i class="far fa-edit"></i>' . sprintf( __( '%1s - %2s', 'youzer-profile-completeness' ), $widget_title, $field_title ) . '<div class="yzpc-arrow-right"></div></a>';
		                            }

		                            echo '</div>';

		                        }
		                    }

		                    echo '</div></div>';

	                	}
	                ?>

	                </div>

	                <?php endif; ?>

			        <?php if ( isset( $box_elements['restrictions'] ) ) :  ?>
			        
			    	<div class="yzpc-task yzpc-restrictions">

			        	<?php $restrictions_icon = $completeness_percent != 100 ? 'fas fa-lock' : 'fas fa-check'; ?>
			        	<?php $restrictions_description = $completeness_percent != 100 ? __( 'Forbidden actions until you complete your profile.', 'youzer-profile-completeness' ) : __( 'No more restrictions are applied on your account.', 'youzer-profile-completeness' ); ?>
			            	    
				        <div class="yzpc-task-head">
				            <div class="yzpc-item-icon"><i class="<?php echo $restrictions_icon; ?>"></i></div>
				            <div class="yzpc-item-content">
				                <div class="yzpc-item-title"><?php _e( 'Account restrictions', 'youzer-profile-completeness' ); ?></div>
				                <div class="yzpc-item-description"><?php echo $restrictions_description; ?></div>
				            </div>
							
							<?php if ( $completeness_percent != 100 ) echo '<div class="yzpc-arrow-right yzpc-show-fields"></div>'; ?>
				            
				        </div>

				        <?php

					    // Get Restrictions.
					    $restrictions = get_option( 'yzpc_restrictions' );

					    if ( $completeness_percent != 100 && ! empty( $restrictions ) ) {
					
						    // Get restricted data.
						    $restricted_data = yzpc_get_restricted_fields_data();

				            echo '<div class="yzpc-fields yzpc-profile-widgets-fields"><div class="yzpc-fields-content">';

				            foreach ( $restrictions as $restriction => $value ) {
				                echo '<div class="yzpc-field-item"><i class="fas fa-lock"></i>' . $restricted_data[ $restriction ]['msg'] . '</div>';
				            }

				            echo '</div></div>';

					    }

				        ?>

				    </div>

				    <?php endif; ?>
				    
				    <?php endif; ?>

	                <?php do_action( 'yzpc_widget_tasks_list', $completeness_percent ); ?>

	        </div>
	        	<?php if ( $completeness_percent == 100 ) echo '<div class="yzpc-remove-box" data-user-id="' . $user_id . '"><i class="fas fa-trash"></i>' . __( "Don't show this again", 'youzer-profile-completeness' )  . '</div>'; ?>
		    </div>

	    <?php

	}

	/**
	 * Get User Profile Percent Value
	 */
	function get_profile_completeness_percent( $user_id ) {

	    // Get Total Fields
	    $total_fields = yzpc_get_total_fields_number();

	    // echo $total_fields;
	    if ( $total_fields < 1 ) {
	        return 0;
	    }

	    // Get User Filled Fields Count.
	    $filled_fields_count = (int) get_the_author_meta( 'yzpc_filled_fields_count', $user_id );
	    
	    /* For Future Debuging Purpose */
        // Get User Unfilled Fields
        // $unfilled = yzpc_get_first_field_data( 'required', $user_id, false );
	    // echo '<pre>';
	    // print_r( $unfilled );
	    // print_r( get_option( 'yzpc_total_fields1' ) );
	    // print_r( get_option( 'yzpc_total_fields_plus' ) );
	    // print_r( get_option( 'yzpc_total_forced_fields' ) );
	    // print_r( get_option( 'yzpc_total_required_fields' ) );
	    // print_r( get_user_meta( $user_id, 'yzpc_filled_fields_count2') );
	    // echo '</pre>';
	    // echo $total_fields;
	    // echo $filled_fields_count;
	    /* End Testing Area. */

	    // Get Profile Completeness Value.
	    $percent = round( ( $filled_fields_count / $total_fields ) * 100 );

	    if ( $percent > 100 ) {
	    	$percent = 100;
	    }

	    return apply_filters( 'yzpc_get_user_profile_comleteness_percent', $percent );
	}

	/**
	 * Get Completeness Status
	 */
	function get_level_status( $percent ) {

	    if ( $percent <= 30 ) {
	        $status = array( 'level' => 'low', 'title' => __( 'Low', 'youzer-profile-completeness' ) );
	    } else if( $percent > 30 && $percent <= 70 ) {
	        $status = array( 'level' => 'medium', 'title' => __( 'Medium', 'youzer-profile-completeness' ) );
	    } else if ( $percent > 70 && $percent < 100 ) {
	        $status = array( 'level' => 'high', 'title' => __( 'High', 'youzer-profile-completeness' ) );
	    } else {
	        $status = array( 'level' => 'complete', 'title' => __( 'Complete', 'youzer-profile-completeness' ) );
	    }

	    return apply_filters( 'yzpc_profile_completeness_level_status', $status, $percent );
	}

	/**
	 * Remove User Completeness Box
	 */
	function remove_user_completeness_widget() {

		if ( ! isset( $_POST['user_id'] ) || empty( $_POST['user_id'] ) ) {
			return;
		}

		if ( yzpc_is_profile_complete( $_POST['user_id'] ) ) {
			update_user_meta( $_POST['user_id'], 'yzpc_remove_completeness_widget', 1 );
		}

		wp_die();

	}

}