<?php

/**
 * Get Forced Fields
 */
function yzpc_get_fields( $status ) {
    // Get Fields By status.
    $fields = get_option( 'yzpc_' . $status . '_fields' );
    return apply_filters( 'yzpc_get_' . $status . '_fields', (array) $fields, $status );
}

/**
 * Is User Profile Complete
 */
function yzpc_is_profile_complete( $user_id = null ) {

    if ( empty( $user_id ) ) {
        return;
    }
    
    $is_complete = false;
    
    // Get Last Time all Fields Updated from the admin.
    $last_time_updated = get_option( 'yzpc_fields_updated' );

    if ( ! empty( $last_time_updated ) ) {

        // Get Last Time fields updated.
        $last_time_checked = get_the_author_meta( 'yzpc_last_time_fields_updated', $user_id );
        
        // Get Completeness Option.
        if ( $last_time_updated > $last_time_checked ) {

            // Hook..
            do_action( 'yzpc_is_profile_complete_after_updating_settings' , $user_id );
    
        }

        $is_complete = get_the_author_meta( 'yzpc_profile_complete', $user_id );

    }

    // Filter & Return.
    return apply_filters( 'yzpc_is_profile_complete', $is_complete, $user_id );

}

/**
 * Get User Fields By status.
 */
function yzpc_get_user_fields( $user_id, $status ) {

    // Get Last Time the forced fields marked as complete.
    $last_time_checked = get_the_author_meta( 'yzpc_' . $status . '_fields_completed', $user_id );

    if ( ! empty( $last_time_checked ) ) {

        // Get Last Time The Forced Fields Updated from the admin.
        $last_time_updated = get_option( 'yzpc_' . $status . '_fields_updated' );

        if ( $last_time_updated < $last_time_checked ) {
            return;
        }

    }

    return yzpc_get_fields( $status );
}

/**
 * Get Unfilled Fields By Status & Type.
 */
function yzpc_get_fields_sorted_by_types( $fields ) {
    
    if ( empty( $fields) ) {
        return;
    }

    $items = array();

    foreach ( $fields as $parent => $field ) {

        if ( is_numeric( $parent ) ) {
            $items['xprofile'][ $parent ] = $field;
        } elseif ( 'images' == $parent ) {
            $items['images'] = $field;
        } elseif( is_string( $parent ) ) {
            $items['widgets'][ $parent ] = $field;
        }

    }
    
    return apply_filters( 'yzpc_get_fields_sorted_by_types', $items );
}

/**
 * Get User Unfilled Fields.
 */
function yzpc_get_user_unfilled_fields( $status, $user_id, $cache = true ) {

    // Get Fields.
    $fields = $cache == true ? yzpc_get_user_fields( $user_id, $status ) : yzpc_get_fields( $status );

    if ( empty( $fields ) ) {
        return;
    }

    $unfilled = array();

    foreach ( $fields as $parent => $field ) {

        if ( empty( $field ) || ! is_array( $field ) ) {
            continue;
        }

        foreach ( $field as $key => $field_id ) {

            if ( is_numeric( $parent ) ) {

                $field_data = new BP_XProfile_Field( $field_id );
                
                if ( ! yzpc_is_field_available_for_current_member_type( $user_id, $field_id, $field_data ) ) {
                    continue;
                }

                // Get Field Value.
                $field_value = bp_get_profile_field_data( array( 'user_id' => $user_id,'field' => $field_id ) );

                if ( empty( $field_value ) ) {
                    $unfilled[ $parent ][ $field_id ] = $field_data->name;
                    continue;
                }

            } elseif ( 'images' == $parent ) {
                
                if ( $field_id == 'change-cover-image' ) {
                    $field_value = bp_attachments_get_user_has_cover_image( $user_id );
                    $field_name = __( 'Upload Profile Cover Image', 'youzer-profile-completeness' ) ;
                } elseif ( $field_id == 'change-avatar' ) {
                    $field_value = yzpc_get_user_has_avatar( $user_id );
                    $field_name = __( 'Upload Profile Avatar', 'youzer-profile-completeness' ) ;
                }

                if ( empty( $field_value ) ) {
                    $unfilled[ $parent ][ $field_id ] = $field_name;
                    continue;
                }

            } elseif ( is_string( $parent ) ) {
                
                if ( 'post' == $parent && ! current_user_can( 'edit_posts' ) ) {
                    continue;
                }

                // Get Youzer Widgets.
                $youzer_widgets = yz_user_widgets_fields();

                // Get Widget Data.
                $widget_data = isset( $youzer_widgets[ $parent ] ) ? $youzer_widgets[ $parent ] : null;

                if ( empty( $widget_data ) ) {
                    continue;
                }

                // Get Field Value.
                $field_value = yz_data( $field_id, $user_id );

                if ( isset( $widget_data['fields'][ $field_id ]['type'] ) && $widget_data['fields'][ $field_id ]['type'] == 'image' ) {
                }

                if ( empty( $field_value ) ) {
                    
                    if ( isset( $widget_data['id'] ) ) {
                        $unfilled[ $parent ][ $field_id ] = $widget_data['title'];
                    } else {
                        $unfilled[ (string) $parent ][ $field_id ] = $widget_data['fields'][ $field_id ]['title'];
                    }

                    continue;
                }

            }

        }
    }

    return apply_filters( 'yzpc_get_user_unfilled_fields', $unfilled, $status, $user_id );
}

/**
 * Check if Field Is Available For the Current Member Type.
 **/
function yzpc_is_field_available_for_current_member_type( $user_id, $field_id, $field_data = null ) {

    // if ( empty( bp_get_member_types() ) ) {
    //     return true;
    // }

    // Get Field Data.
    $field_data = ! empty( $field_data ) ? $field_data : new BP_XProfile_Field( $field_id );
                
    // Get Field Member Types.
    $member_types = $field_data->get_member_types();

    if ( empty( $member_types ) ) {
        return true;
    }

    $member_type = bp_get_member_type( $user_id );
    
    if ( empty( $member_type ) ) {
        $member_type = 'null';
    }

    if ( in_array( $member_type, $member_types ) ) {
        return true;
    }
        
    return false;

}

/**
 * Get First Field Data.
 */
function yzpc_get_first_field_data( $status, $user_id, $cache = true ) {

    // Get Fields.
    $fields = $cache == true ? yzpc_get_user_fields( $user_id, $status ) : yzpc_get_fields( $status );

    if ( empty( $fields ) ) {
        return false;
    }

    foreach ( $fields as $field_parent => $field ) {
        
        if ( ! is_array( $field ) ) {
            continue;
        }

        foreach ( $field as $key => $field_id ) {

            if ( is_numeric( $field_parent ) ) {

                if ( ! yzpc_is_field_available_for_current_member_type( $user_id, $field_id ) ) {
                    continue;
                }

                // Get Field Value.
                $field_value = bp_get_profile_field_data( array( 'user_id' => $user_id,'field' => $field_id ) );

            } elseif ( 'images' == $field_parent ) {

                if ( $field_id == 'change-cover-image' ) {
                    $field_value = bp_attachments_get_user_has_cover_image( $user_id );
                } elseif ( $field_id == 'change-avatar' ) {
                    $field_value = yzpc_get_user_has_avatar( $user_id );
                }

            } elseif ( is_string( $field_parent ) ) {
                
                if ( 'post' == $field_parent && ! user_can( $user_id, 'edit_posts' ) ) {
                    continue;
                }

                $field_value = yz_data( $field_id );
            }

            if ( empty( $field_value ) ) {
                return array( 'parent' => $field_parent, 'id' => $field_id );
            }

        }
    }

    // Set Last Time The Profile Was Checked as Updates.
    update_user_meta( $user_id, 'yzpc_' . $status . '_fields_completed', current_time( 'timestamp' ) );

}

/**
 * Add account page Notice Title.
 */
function yzpc_add_account_page_notice_title( $message ) {
    $message = '<div class="yzpc-notice"><i class="fas fa-tasks"></i>' . __( 'Complete Your Profile', 'youzer-profile-completeness' ) . '</div></br>'.$message;
    return $message;
}

/**
 * Get Total Fields Number 
 */
function yzpc_get_total_fields_number() {
    
    // Total Of ( Forced + Required ) Fields.
    $total_fields = get_option( 'yzpc_total_fields' );

    return apply_filters( 'yzpc_get_total_fields_number', $total_fields );

}

/**
 * Is profile Completeness Active
 */
function yzpc_is_profile_completeness_active( $user_id ) {

    // Init Var.
    $is_active = 'off';

    if ( is_user_logged_in() ) {

        $transient_id = 'yzpc_is_profile_completeness_active_' . $user_id;

        $is_active = apply_filters( 'yzpc_is_profile_completeness_active_transient', get_transient( $transient_id ) );

        if ( false === $is_active ) {

            // Get Profile Completeness roles.
            $completeness_roles = yz_get_multicheckbox_options( 'yzpc_profile_completeness_roles' );

            if ( ! empty( $completeness_roles ) ) {
                
                // Get Current User Data.
                $user = get_userdata( $user_id );

                // Get User Roles.
                $user_roles = (array) $user->roles;

                foreach ( $completeness_roles as $role ) {

                    if ( in_array( $role, $user_roles ) ) {
                        $is_active = 'on';
                        break;
                    }

                }

            }

            set_transient( $transient_id, $is_active, HOUR_IN_SECONDS );

        }

    }

    // Get Is Active Value.
    $is_active = $is_active == 'on' ? 'on' : 'off';

    return apply_filters( 'yzpc_is_profile_completeness_active', $is_active );

}


/**
 * Get restriction fields data
 */
function yzpc_get_restricted_fields_data() {
    $data = array(
        'friends' => array(
            'id' => 'yzpc_enable_friendship',
            'msg' => __( "You can't add or remove friends.", 'youzer-profile-completeness' )
        ),
        'follows' => array(
            'id' => 'yzpc_enable_follows',
            'msg' => __( "You can't follow or unfollow users.", 'youzer-profile-completeness' )
        ),
        'groups' => array(
            'id' => 'yzpc_enable_groups',
            'msg' => __( "You can't join or leave groups.", 'youzer-profile-completeness' )
        ),
        'messages' => array(
            'id' => 'yzpc_enable_messages',
            'msg' => __( "You can't send new messages.", 'youzer-profile-completeness' )
        ),
        'posts' => array(
            'id' => 'yzpc_enable_wall_posts',
            'msg' => __( "You can't add new wall posts.", 'youzer-profile-completeness' )
        ),
        'likes' => array(
            'id' => 'yzpc_enable_wall_likes',
            'msg' => __( "You can't like wall posts.", 'youzer-profile-completeness' )
        ),
        'comments' => array(
            'id' => 'yzpc_enable_wall_comments',
            'msg' => __( "You can't comment on wall posts.", 'youzer-profile-completeness' )
        ),
        'replies' => array(
            'id' => 'yzpc_enable_wall_replies',
            'msg' => __( "You can't reply to posts comments.", 'youzer-profile-completeness' )
        ),
        'delete_posts' => array(
            'id' => 'yzpc_enable_wall_posts_delete',
            'msg' => __( "You can't delete wall posts.", 'youzer-profile-completeness' )
        ),
        'reviews' => array(
            'id' => 'yzpc_enable_reviews',
            'msg' => __( "You can't add or remove reviews.", 'youzer-profile-completeness' )
        ),
        'bookmarks' => array(
            'id' => 'yzpc_enable_bookmarks',
            'msg' => __( "You can't bookmark activity posts.", 'youzer-profile-completeness' )
        ),
    );

    return apply_filters( 'yzpc_get_restricted_fields_data', $data );
}

/**
 * Default Options.
 */
function yzpc_default_options( $options ) {

    // Options.
    $new_options = array(
        'yzpc_hide_md_incomplete_profiles' => 'off',
        'yzpc_verify_complete_profiles' => 'off',
        'yz_msgbox_profile_completeness_roles_cache' => 'on',
    );
    
    $options = array_merge( $options, $new_options );

    return $options;
}

add_filter( 'yz_default_options', 'yzpc_default_options' );

/**
 * Members Directory - Exclude Incomplete Profile Users.
 */

add_filter( 'bp_after_has_members_parse_args', 'yzpc_exclude_directory_users' );

function yzpc_exclude_directory_users( $loop ) {

    if ( ! bp_is_members_directory() || 'off' == yz_option( 'yzpc_hide_md_incomplete_profiles', 'off' ) ) {
        return $loop;
    }

    // Get Incomplete Profiles.
    $incomplete_profiles = yzpc_get_incomplete_profiles();

    // if all the profiles are complete exit.
    if ( empty( $incomplete_profiles ) ) {
        return $loop;
    }
    
    $excluded = isset( $loop['exclude'] )? $loop['exclude'] : array();
 
    if ( ! is_array( $excluded ) ) {
        $excluded = explode( ',', $excluded );
    }

    $excluded = array_merge( $excluded, $incomplete_profiles );

    // Get Incomplete Profiles.
    $loop['exclude'] = $excluded;
        
    return $loop;

}

/**
 * Get Incomplete Profiles Ids.
 */
function yzpc_get_incomplete_profiles() {

    if ( false === ( $incomplete_profiles = get_transient( 'yzpc_incomplete_profiles' ) ) ) {

        // Get Excluded Roles.
        $exclude_roles = yz_get_multicheckbox_options( 'yzpc_profile_completeness_roles', 'off' );

        // Query Args.
        $query_args = apply_filters( 'yzpc_incomplete_profiles_query_args' , array(
            'meta_key' => 'yzpc_profile_complete',
            'meta_value' => 1,
            'meta_compare' => 'NOT EXISTS',
            'role__not_in' => $exclude_roles,
            'fields' => 'ID'
        ) );

        // Get Users ID's
        $incomplete_profiles = get_users( $query_args );

        set_transient( 'yzpc_incomplete_profiles', $incomplete_profiles, DAY_IN_SECONDS );

    }

    return apply_filters( 'yzpc_incomplete_profiles', $incomplete_profiles );

}

/** 
 * Get User Avatar
 */
function yzpc_get_user_has_avatar( $user_id ) {

    remove_filter( 'bp_core_default_avatar_user', 'yz_set_default_profile_avatar', 10, 2 );

    $avatar = bp_get_user_has_avatar( $user_id );
    
    add_filter( 'bp_core_default_avatar_user', 'yz_set_default_profile_avatar', 10, 2 );

    if ( empty( $avatar ) && function_exists( 'yz_get_user_social_avatar' ) ) {
        $avatar = yz_get_user_social_avatar( $user_id );
    }
    
    return $avatar;

}