<?php
/**
 * Plugin Name: Youzer - Profile Completeness
 * Plugin URI:  http://youzer.kainelabs.com
 * Description: Youzer - Profile Completeness to prevent blank profiles on your site.
 * Version:     1.0.4
 * Author:      Youssef Kaine
 * Author URI:  https://www.kainelabs.com
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: youzer-profile-completeness
 * Domain Path: /languages/
 */
if ( ! defined( 'WPINC' ) ) {
    die;
}

// Youzer File
define( 'YZPC_FILE', __FILE__ );

// Version.
define( 'YZPC_VERSION', '1.0.4' );

// Youzer Basename
define( 'YZPC_BASENAME', plugin_basename( __FILE__ ) );

// Plugin Path.
define( 'YZPC_PATH', plugin_dir_path( __FILE__ ) );
define( 'YZPC_URL', plugin_dir_url( __FILE__ ) );

/**
 * Plugin Class.
 */
class Youzer_Profile_Completeness {


  /**
   * The single instance of the class.
   *
   * @var Youzer_Profile_Completeness
   * @since 1.0.0
   */
    static $basename = null;

    /**
     * A dummy constructor to prevent BuddyPress from being loaded more than once.
     *
     */
    private function __construct() {
        add_filter( 'plugin_action_links_' . YZPC_BASENAME,  array( $this, 'plugin_action_links' ) );
        add_filter( 'network_admin_plugin_action_links_' . YZPC_BASENAME, array( $this, 'plugin_action_links' ) );
    }

    /**
     * Main Youzer_Profile_Completeness Instance.
     *
     */
    public static function instance() {

        // Store the instance locally to avoid private static replication
        static $instance = null;

        if ( is_null( $instance ) ) {

          $instance = new Youzer_Profile_Completeness();

            if ( ! $instance->have_required_plugins()) {
                return;
            }

            // Init
            add_action( 'init', array( $instance, 'init' ) );

            $instance->setup_textdomain();

        }

        return $instance;

    }  
        

    /**
     * Init Method.
     */

    public function init() {

        // Include General Files.
        include YZPC_PATH . 'functions/yz-general-functions.php';
        
        $user_id = bp_loggedin_user_id();

        // Check is the profile compleness system is enabled for the current user.
        $is_active = yzpc_is_profile_completeness_active( $user_id );

        if ( 'on' == $is_active || is_admin() ) {
            include YZPC_PATH . 'classes/yz-class-user.php';
            $user = new YZPC_User();
        }

        if ( 'on' == $is_active ) {

            // Disable Redirections & Restrictions For Complete Profiles.
            if ( ! yzpc_is_profile_complete( $user_id ) ) {

                // Classes.
                include YZPC_PATH . 'classes/yz-class-restrictions.php';
                include YZPC_PATH . 'classes/yz-class-redirect.php';

                // Init Classes.
                $restrictions = new YZPC_Restrictions();
                $redirects = new YZPC_Redirects();

            }

        }
        
        // Call Widget. 
        include YZPC_PATH . 'classes/yz-class-widget.php';
        $widget  = new YZPC_Widget();

        // Init Admin
        if ( is_admin() || wp_doing_ajax() ) {
            include YZPC_PATH . 'functions/yz-admin-functions.php';
            require_once YZPC_PATH . 'classes/yz-class-admin.php';
            $admin = new YZPC_Admin();
        }


    }  

    /**
     * Check For Required Plugins.
     */
    public function have_required_plugins() {

        // Get Required Fields.
        $required_plugins = array( 'youzer' => 'youzer' ); 

        // Get Active Plugins List.
        $active_plugins = (array) get_option( 'active_plugins', array() );

        // Check is Multisite.
        if ( is_multisite() ) {
            $active_plugins = array_merge( $active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
        }

        // Check if plugin exist.
        foreach ( $required_plugins as $key => $required ) {
            
            $required = ( ! is_numeric( $key ) ) ? "{$key}/{$required}.php" : "{$required}/{$required}.php";
            
            if ( ! in_array( $required, $active_plugins ) && ! array_key_exists( $required, $active_plugins ) ) {
                // Show Notice.
                add_action( 'admin_notices', array( $this, 'activate_youzer_notice' ) );
                return false;
            }

        }
     
        return true;
    
    }

    /**
     * Load plugin text domain.
     */
    public function setup_textdomain() {

        // Get Plugin Domain.
        $domain = 'youzer-profile-completeness';
        
        $locale = apply_filters( 'plugin_locale', get_locale(), $domain );
        
        // Load Translation from the wordprss Languages Directory First.
        load_textdomain( $domain, WP_LANG_DIR . '/plugins/' . $domain . '-' . $locale . '.mo' );
        
        // Load The Current Plugin Translation.
        load_plugin_textdomain( $domain, false, 'youzer-profile-completeness/languages' );

    }

    /**
     * Action Links
     */
    function plugin_action_links( $links ) {
        // Get Youzer Plugin Pages. 
        $panel_url = esc_url( add_query_arg( array( 'page' => 'yz-extensions-settings&tab=profile-completeness' ), admin_url( 'admin.php' ) ) );
        $plugin_url = "https://www.kainelabs.com/downloads/buddypress-profile-completeness/";
        $documentation_url = 'https://kainelabs.ticksy.com/articles/100015163/';
        // Add a few links to the existing links array.
        return array_merge( $links, array(
            'settings' => '<a href="' . $panel_url . '">' . esc_html__( 'Settings', 'youzer-profile-completeness' ) . '</a>',
            'documentation' => '<a href="' . $documentation_url . '">' . esc_html__( 'Documentation',    'youzer-profile-completeness' ) . '</a>',
            'about'    => '<a href="' . $plugin_url . '">' . esc_html__( 'About',    'youzer-profile-completeness' ) . '</a>'
        ) );
    }

    /**
     * Activate Youzer Notice.
     */
    function activate_youzer_notice() {

        ?>
        <div class="notice notice-warning is-dismissible">
            <p><?php echo sprintf( __( '<strong> Notice : </strong>Please install and activate <strong><a href="%1s">Youzer</strong></a> plugin to use the <strong>Youzer - Profile Completeness</strong> extension.', 'youzer-profile-completeness' ), 'https://codecanyon.net/item/youzer-new-wordpress-user-profiles-era/19716647' ); ?></p>
        </div>
        <?php
    }
    
}

// Init.
function youzer_profile_completeness() {
    return Youzer_Profile_Completeness::instance();
}

$GLOBALS['youzer_profile_completeness'] = youzer_profile_completeness();