<?php
/**
 * Plugin Name: Youzer - Social Share
 * Plugin URI:  http://youzer.kainelabs.com
 * Description: Allow users and visitors to share activities, profiles and groups and allow your content to reach a wider audience and gain more exposure for your brand.
 * Version:     1.0.6
 * Author:      Youssef Kaine
 * Author URI:  https://www.kainelabs.com
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: youzer-social-share
 * Domain Path: /languages/
 */

if ( ! defined( 'WPINC' ) ) {
    die;
}

/**
 * Check if Youzer Plugin is installed
 */
function yzss_check_for_youzer_plugin() {

    if ( ! class_exists( 'Youzer' ) ) {

        function yzss_extension_admin_notice() {

            ?>
            <div class="notice notice-warning is-dismissible">
                <p><?php echo sprintf( __( '<strong> Notice : </strong>Please install and activate <strong><a href="%1s">Youzer</strong></a> plugin to use the <strong>Youzer - Social Share</strong> extension.', 'youzer-social-share' ), 'https://codecanyon.net/item/youzer-new-wordpress-user-profiles-era/19716647' ); ?></p>
            </div>
            <?php
        }

        // Show Notice.
        add_action( 'admin_notices', 'yzss_extension_admin_notice' );

        // Deactivate The Plugin.
        deactivate_plugins( plugin_basename( __FILE__ ) );

        return;

    }
    
}

// Check For Youzer.
add_action( 'admin_init', 'yzss_check_for_youzer_plugin' );

// Version.
define( 'YZSS_VERSION', '1.0.6' );

// File
define( 'YZSS_FILE', __FILE__ );

// Basename
define( 'YZSS_BASENAME', plugin_basename( __FILE__ ) );

// Path.
define( 'YZ_SOCIAL_SHARE_PATH', plugin_dir_path( __FILE__ ) );
define( 'YZ_SOCIAL_SHARE_URL', plugin_dir_url( __FILE__ ) );

/**
 * Init Functions
 */
function youzer_social_share_init() {
    
    // Include Files.
    include YZ_SOCIAL_SHARE_PATH . 'yz-general-functions.php';

    include YZ_SOCIAL_SHARE_PATH . 'yz-open-graph-functions.php';

    if ( ! yzss_is_social_share_active() ) {
        return;
    }

    if ( is_user_logged_in() || yzss_allow_nonloggedin_users_to_share() ) {
        
        // Add Body Class Filter.
        add_filter( 'body_class','yzss_social_share_body_class' );

        if ( yzss_is_posts_sharable() ) {
            include YZ_SOCIAL_SHARE_PATH . 'yz-activity-functions.php';
        }

        if ( yzss_is_profiles_sharable() ) {
            include YZ_SOCIAL_SHARE_PATH . 'yz-profile-functions.php';
        }

        if ( yzss_is_groups_sharable() ) {
            include YZ_SOCIAL_SHARE_PATH . 'yz-group-functions.php';
        }

    }

    if ( is_admin() ) {
        include YZ_SOCIAL_SHARE_PATH . 'yz-admin-functions.php';
    }

}

add_action( 'youzer_init', 'youzer_social_share_init' );

// Load Text Domain
add_action( 'plugins_loaded', 'yzss_load_youzer_textdomain' );

function yzss_load_youzer_textdomain() {
    load_plugin_textdomain( 'youzer-social-share', FALSE, dirname( YZSS_BASENAME ) . '/languages' );        
}
/**
 * Action Links
 */
function yzss_plugin_action_links( $links ) {
    // Get Youzer Plugin Pages. 
    $panel_url = esc_url( add_query_arg( array( 'page' => 'youzer-panel&tab=social-share' ), admin_url( 'admin.php' ) ) );
    $plugin_url = "https://www.kainelabs.com/downloads/social-share/";
    $documentation_url = 'https://kainelabs.ticksy.com/articles/100012977';
    // Add a few links to the existing links array.
    return array_merge( $links, array(
        'settings' => '<a href="' . $panel_url . '">' . esc_html__( 'Settings', 'youzer-social-share' ) . '</a>',
        'documentation' => '<a href="' . $documentation_url . '">' . esc_html__( 'Documentation',    'youzer-social-share' ) . '</a>',
        'about'    => '<a href="' . $plugin_url . '">' . esc_html__( 'About',    'youzer-social-share' ) . '</a>'
    ) );
}

// Add Plugin Links.
add_filter( 'plugin_action_links_' . YZSS_BASENAME, 'yzss_plugin_action_links' );

// Add Plugin Links in Multisite..
add_filter( 'network_admin_plugin_action_links_' . YZSS_BASENAME, 'yzss_plugin_action_links' );