<?php

/***
 * Get Wall Post Opengraph
 */
function yz_get_wall_post_open_graph() {

	if ( ! bp_is_user_activity() ) {
		return false;
	}
	
	global $bp;

	$activity = yz_get_activity_by_id( $bp->current_action );

	if ( empty( $activity ) ) {
		return false;
	}

	// Init Vars.
	$title = null;
	$image = null;
	$audio = null;
	$video = null;
	$type = 'profile';
	$description = null;
	$url = yz_get_current_page_url();

	$post_type = bp_activity_get_meta( $activity->id, 'post-type' );

	// Get Attachments.
	$attachments = yz_get_activity_attachments( $activity->id );

	switch ( $activity->type ) {

		case 'new_avatar':
		case 'new_cover':
		case 'activity_slideshow':
		case 'activity_photo':

			if ( ! empty( $attachments ) ) {
				$image = yz_get_media_url( $attachments[0] );
			}

		break;
		 
        case 'created_group': 
        case 'joined_group': 
			$image = yz_options( 'yzss_default_thumb_group_created' );
		break;
		
        case 'activity_status': 

			// Get Url Data.
			$url_data = bp_activity_get_meta( $activity->id, 'url_preview' );

			if ( ! empty( $url_data ) ) {
				
				// Unserialize data.
				$url_data = is_serialized( $url_data ) ? unserialize( $url_data ) : maybe_unserialize( base64_decode( $url_data ) );
				
				if ( isset( $url_data['image'] ) && ! empty( $url_data['image'] ) ) {
					$image = $url_data['image'];
				}
				
				if ( isset( $url_data['title'] ) && ! empty( $url_data['title'] ) ) {
					$title = $url_data['title'];
				}

				if ( empty( $activity->content) && isset( $url_data['description'] ) && ! empty( $url_data['description'] ) ) {
					$description = $url_data['description'];
				}

			}

			if ( empty( $image ) ) {
				$image = yz_options( 'yzss_default_thumb_activity_status' );
			}

		break;
		
        case 'friendship_accepted': 
        case 'friendship_created': 
			$image = yz_options( 'yzss_default_thumb_friendship' );
		break;
		
		case 'activity_link':

			if ( ! empty( $attachments ) ) {
				$image = yz_get_wall_file_url( $attachments[0] );
			}

			$description = bp_activity_get_meta( $activity->id, 'yz-link-desc' );
			$title = bp_activity_get_meta( $activity->id, 'yz-link-title' );

			// Get Default Image.
			if ( empty( $image ) ) {
				$image = yz_options( 'yzss_default_thumb_activity_link' );
			}

		break;

		case 'activity_quote':

			$image = ! empty( $attachments ) ? yz_get_wall_file_url( $attachments[0] ): false;
			$description = bp_activity_get_meta( $activity->id, 'yz-quote-text' );
			$title = bp_activity_get_meta( $activity->id, 'yz-quote-owner' );

			// Get Default Image.
			if ( empty( $image ) ) {
				$image = yz_options( 'yzss_default_thumb_activity_quote' );
			}

		break;

		case 'activity_video':
			$image = yz_options( 'yzss_default_thumb_activity_video' );
		break;

		case 'activity_audio':
			$image = yz_options( 'yzss_default_thumb_activity_audio' );
		break;

		case 'activity_comment':
		case 'new_blog_comment':
			
			if ( empty( $image ) ) {
				$image = yz_options( 'yzss_default_thumb_new_blog_comment' );
			}

		break;

		case 'new_blog_post':

			$blogs_ids = is_multisite() ? get_sites() : array( (object) array( 'blog_id' => 1 ) );

			foreach( $blogs_ids as $b ) {

		    	switch_to_blog( $b->blog_id );

			    // Get Post Data.
			    $post = get_post( $activity->secondary_item_id );

			    $title = $post->post_title;

			    $description = get_the_excerpt() ? get_the_excerpt() : yz_get_excerpt( $post->post_content, 40 );

		    	// Get Image ID.
				$img_id = get_post_thumbnail_id( $activity->secondary_item_id );

				// Get Image Url.
			    $image = wp_get_attachment_image_src( $img_id , 'large' );
			    
			    restore_current_blog();

			    if ( $post ) {
			    	break;
			    }
			}

			// Get Permalink.
			$image = isset( $image[0] ) && !empty( $image[0] ) ? $image[0] : null;

			if ( empty( $image ) ) {
				$image = yz_options( 'yzss_default_thumb_new_blog_post' );
			}

		break;

	}
	
	if ( empty( $description ) && ! empty( $activity->content ) ) {
		// Remove html tags.
		$description = wp_strip_all_tags( $activity->content );
		// Delete Slashes.
		$description = stripslashes_deep( $description );
	}

	if ( empty( $description ) ) {
		$description =  apply_filters( 'yzss_open_graph_default_description', $activity->action );
	}

	if ( empty( $title ) && ! empty( $activity->display_name ) ) {
		$title = apply_filters( 'yzss_open_graph_default_title', $activity->display_name );
	}

    // Get Open Graph Tags.
    yz_get_open_graph_tags( $type, $url, $title, $description, $image );

}

add_action( 'bp_head', 'yz_get_wall_post_open_graph' );

/**
 * Set Profile Default Thumbnail.
 */
function yzss_set_og_profile_default_thumbnail( $profile_avatar = null ) {
    
    // Get Profile Photo.
    $default_thumb = yz_options( 'yzss_default_thumb_profile' );

    if ( ! empty( $default_thumb ) ) {
        return $default_thumb;
    }

    return $profile_avatar;
}

add_filter( 'yz_og_profile_default_thumbnail', 'yzss_set_og_profile_default_thumbnail' );

/**
 * Set Group Default Thumbnail.
 */
function yzss_set_og_group_default_thumbnail( $group_avatar = null ) {
    
    // Get Profile Photo.
    $default_thumb = yz_options( 'yzss_default_thumb_group' );

    if ( ! empty( $default_thumb ) ) {
        return $default_thumb;
    }

    return $group_avatar;
}

add_filter( 'yz_og_group_default_thumbnail', 'yzss_set_og_group_default_thumbnail' );
